const paramsDefault = {
	title: '',
	fileNum: '',
	publishPerson: '',
	category: '',
	categoryName: '',
	isOversee: 2,
	isOverseeName: '全部',
	isSign: 2,
	isSignName: '全部',
	state: '',
	stateName: '全部',
	startTime: '',
	endTime: '',
	
}
Vue.component('search', {
	data() {
		return {

			// 类型
			showCate: false,
			cateText: '',
			categorys: [
				{ name: '类型1' , value: 1}, 
				{ name: '类型2' , value: 2}, 
				{ name: '类型3' , value: 3},
			],
			// 督办
			showOversee: false,
			overseeText: '',
			oversees: overseeOptions,
			// 签收
			showSign: false,
			signText: '',
			signs: signOptions,
			// 状态
			showState: false,
			stateText: '',
			states: stateOptions,
			
			defaultDate: new Date(),
			showStartDate: false,
			showEndDate: false
			
		}
	},
	props: {
		// 页面类型，发送、接收
		isSend:{
			type: Boolean,
			default: true
		},
		
		// 查询参数
		params: {
			type: Object,
			default: () => {
				return Object.assign({}, paramsDefault)
			}
		}
		
	},
	computed:{
		pageTitle() {
			return `调度通知-${this.isSend ? '发送' : '接收'}管理-查询条件`;
		}
	},
	created() {
		
		this.queryCategory()
		
		
	},
	mounted() {
		
	},
	methods: {
		
		// 获取通知类型
		queryCategory() {
			queryCategory().then(res => {
				const { data } = res
				this.categorys = formatMsgData(data).map(item => {
					return {
						name: item.categoryName,
						value: item.category,
					}
				})
				this.categorys.unshift({
					name: '全部',
					value: ''
				})
				console.log(this.categorys)
				
			}) 
		},
		
		// 取消搜索
		cancel() {
			this.$emit('close')
		},
		
		// 重置
		reset() {
			console.log(this.params)
			
			this.params = Object.assign({}, this.params, paramsDefault)
			this.params.startTime = this.formatDate(new Date, 3)
			this.params.endTime = this.formatDate(new Date, 4)
			
		},
		
		// 确认搜索
		confirm() {
			
			if(this.params.startTime == ''){
				this.params.startTime = this.formatDate(new Date, 3)
			}
			
			if(this.params.endTime == ''){
				this.params.endTime = this.formatDate(new Date, 4)
			}
			
			
			const getTime = (str) => {
				return (new Date(str)).getTime()
			}
			
			if(getTime(this.params.startTime) >= getTime(this.params.endTime)) {
				vant.Toast('开始时间不能大于结束时间');
				return false;
			}
		
			console.log('查询参数',this.params)
			this.$emit('confirm', this.params)
		},
		
		// 选择分类
		chooseCate(item) {
			this.showCate = false
			this.params.category = item.value
			this.params.categoryName = item.name
		},
		
		// 选择是否督办
		chooseOnlook(item) {
			this.showOversee = false
			this.params.isOversee = item.value
			this.params.isOverseeName = item.name
		},
		
		// 选择是否签收
		chooseSign(item) {
			this.showSign = false
			this.params.isSign = item.value
			this.params.isSignName = item.name
		},
		
		// 选择状态
		chooseState(item) {
			console.log(item)
			
			this.showState = false
			this.params.state = item.value
			this.params.stateName = item.name
		},
		
		// 选择查询时间
		chooseTime(date) {
		  const [start, end] = date;
		  
		  this.params.startTime = this.formatDate(start, 3)
		  this.params.endTime = this.formatDate(end, 4)
		  
		  this.showTime = false;
		  this.date = `${this.formatDate(start)} / ${this.formatDate(end)}`;
		},
		
		// 格式化日期
		formatDate(date, type = 1) {
			
			if(type == 1) {
				// 月-日
				return `${date.getMonth() + 1}-${date.getDate()}`
			} else if(type == 2) {
				// 年-月-日
				return `${date.getFullYear()}-${date.getMonth() + 1}-${date.getDate()}`
			} else if(type == 3) {
				// 年-月-日 00:00:00
				return `${date.getFullYear()}-${date.getMonth() + 1}-${date.getDate()} 00:00:00`
			}  else if(type == 4) {
				// 年-月-日 23:59:59
				return `${date.getFullYear()}-${date.getMonth() + 1}-${date.getDate()} 23:59:59`
			}
			
		},
		
		// confirmStart
		confirmStart(date) {
			this.showStartDate = false;
			this.params.startTime = this.formatDate(date, 3)
		},
		
		confirmEnd(date) {
			this.showEndDate = false;
			this.params.endTime = this.formatDate(date, 4)
		}
		
		
		
	},
	template: `
		<div>
			<van-cell :title="pageTitle" />
			
			<van-field v-model="params.title" label="通知标题" placeholder="请输入通知标题" />
		
			<van-field v-model="params.fileNum" label="通知文号" placeholder="请输入通知文号" />
			
			<van-field v-model="params.publishPerson" label="发布人姓名" placeholder="请输入发布人姓名" />
			
			<van-cell is-link title="通知类型" :value="params.categoryName ? params.categoryName : '全部' " @click="showCate = true" />
			<van-action-sheet v-model="showCate" :actions="categorys" @select="chooseCate" />
			
			<van-cell is-link title="是否督办" :value="params.isOverseeName" @click="showOversee = true" />
			<van-action-sheet v-model="showOversee" :actions="oversees" @select="chooseOnlook" />
			
			<van-cell v-if="!isSend" is-link title="是否签收" :value="params.isSignName" @click="showSign = true" />
			<van-action-sheet v-model="showSign" :actions="signs" @select="chooseSign" />
			
			<van-cell is-link title="通知状态" :value="params.stateName" @click="showState = true" />
			<van-action-sheet v-model="showState" :actions="states" @select="chooseState" />
		
			<van-cell is-link title="开始时间" :value="this.params.startTime" @click="showStartDate = true" />
			<van-calendar
				v-model="showStartDate" 
				:default-date="defaultDate"
				:min-date="new Date(2020, 0, 1)"
				:max-date="new Date()"
				@confirm="confirmStart" />
		
			<van-cell is-link title="结束时间" :value="this.params.endTime" @click="showEndDate = true" />
			<van-calendar 
				v-model="showEndDate" 
				:default-date="defaultDate"
				:min-date="new Date(2020, 0, 1)"
				:max-date="new Date()"
				@confirm="confirmEnd" />
		
			<div style="margin-top:50px; display:flex;">
				<van-button round type="warning" size="small" @click="reset" style="flex:1;margin:0 10px;">重置</van-button>
				<van-button round type="info" size="small" @click="confirm" style="flex:1;margin:0 10px;">提交</van-button>
			</div>
		
		</div>
	
	`
})