Vue.component('table-list',{
	data() {
		return {
			
		}
	},
	props:{
		// 是否是发送列表
		isSend:{
			type: Boolean,
			default: true
		},
		// 列表数据
		list: {
			type: Array,
			defalut:() => {
				return [] 
			}
		},
		// 是否可以加载下一页
		isLoadMore: {
			type: Boolean,
			default: false
		},
		
		tableHeight: {
			type: String,
			default: () => {
				// 获取页面高度
				const h = document.documentElement.clientHeight || document.body.clientHeight
				// 减去上方区域
				
				// alert(h)
				
				return h - 40 - 60;
			}
		},
		
	},
	created(){
		
	},
	mounted() {
	},
	filters: {
		
	},
	watch:{
		// 监听数据变化
		list() {
			// 重新渲染list,解决错行问题
			this.$refs['table'].doLayout()
		},
		
	},
	computed:{
		
	},
	methods:{
		
		// 查看详情
		showDetail(item, index) {
			this.$emit('show-detail', {
				item: item,
				index: index
			})
		},
		
		// 查看签约率
		showSignRate(item) {
			console.log(item)
			this.$emit('show-sign-rate', item)
		},
		
		// 反馈
		showFeedback(item, index) {
			this.$emit('show-feedback', {
				item: item,
				index: index
			})
		},
		
		// 签收
		sign(item,index) {
			console.log(index)
			const _this = this
			vant.Dialog.confirm({
			  message: '确定签收此通知?',
			  className: 'inexa'
			}).then(() => {
			    // on confirm
				_this.$emit('sign', {
					item: item,
					index: index
				})
				
			}).catch(() => {
				// on cancel
				vant.Toast('已取消签收');
			});
		},
		
		// 显示反馈按钮
		showfeedbackBtn(item){
			// 以下情况,不能进行反馈,即不显示反馈按钮
			// 非督办
			if(item.isOversee == 0) return false;
			// 督办,已反馈
			if(item.isFeedback == 1) return false;
			// 被抄送的数据 0-接收,1-抄送
			if(item.receiveFlag != 0) return false;
			
			
			// 否则,显示
			return true;
		},
		
		// 显示签收按钮
		showSignBtn(item) {
			// 以下情况,不能进行签收,即不显示签收按钮
			// 已签收
			if(item.isSign == 1) return false;
			// 被抄送的数据,0-接收,1-抄送
			if(item.receiveFlag != 0) return false;
			// 否则,显示
			return true
		},
		
		// 加载更多
		load () {
			
			if(this.isLoadMore) {
				this.$emit('load-more')
			} else {
				vant.Toast({
				  message: '没有更多数据了',
				  position: 'bottom',
				})
			}
		},
		
		
		
	},
	template: `
		<div class="tableDataList">
			<el-table
				ref="table"
				:data="list"
				border
				stripe
				height="100%"
				v-loadmore="load"
				style="width: 100%;">
				
				<el-table-column
				  label="序号"
				   type="index"
				   width="50"
				   align="center"
				   fixed
				></el-table-column>
				
				<el-table-column
					column-key="receiveFlagName"
					prop="title"
					label="通知标题"
					align="center"
					width="100"
					type="index"
					fixed
				>
					<template slot-scope="scope">
						<div @click="showDetail(scope.row, scope.$index)" style="color:blue;">{{ scope.row.title }}</div>
					</template>
				</el-table-column>
				
				
				<el-table-column
					column-key="receiveFlagName"
					label="通知类型"
					align="center"
				>
					<template slot-scope="scope">
						<div>{{ scope.row.categoryName }}</div>
					</template>
				</el-table-column>
				
				<el-table-column
					column-key="fileNum"
					prop="fileNum"
					label="文号"
					align="center"
				></el-table-column>
				
				<el-table-column
					column-key="publishUnit"
					prop="publishUnit"
					label="发文单位"
					align="center"
				></el-table-column>
				
				<el-table-column
					column-key="publishTime"
					prop="publishTime"
					label="发布/草稿时间"
					align="center"
					width="120"
				>
					<template slot-scope="scope">
						<div>{{ scope.row.publishTime | formatTime }}</div>
					</template>
				</el-table-column>
				
				
				
				<el-table-column
					column-key="publishPerson"
					prop="publishPerson"
					label="发布人姓名"
					align="center"
					width="120"
				></el-table-column>
				
				<el-table-column
					column-key="isOverseeName"
					label="是否督办"
					align="center"
				>
					<template slot-scope="scope">
						<div>{{ scope.row.isOverseeName}}</div>
					</template>
				</el-table-column>
				
				<el-table-column
					column-key="stateName"
					v-show="isSend"
					label="通知状态"
					align="center"
				>
					<template slot-scope="scope">
						<div>{{ scope.row.stateName }}</div>
					</template>
				</el-table-column>
				<el-table-column
					column-key="isFeedbackName"
					v-if="!isSend"
					label="是否反馈"
					align="center"
				>
					<template slot-scope="scope">
						<div>{{ scope.row.isFeedbackName}}</div>
					</template>
				</el-table-column>
				
				<el-table-column
					column-key="isSignName"
					v-if="!isSend"
					label="是否签收"
					align="center"
				>
					<template slot-scope="scope">
						<div>{{ scope.row.isSignName }}</div>
					</template>
				</el-table-column>
				
				<el-table-column
					v-if="0 && !isSend"
					column-key="receiveFlagName"
					label="接收类型"
					align="center"
				>
					<template slot-scope="scope">
						<div>{{ scope.row.receiveFlagName }}</div>
					</template>
				</el-table-column>
				
				<el-table-column
					column-key="isSignOverName"
					v-if="isSend"
					label="是否签收完毕"
					align="center"
					width="120"
				>
					<template slot-scope="scope">
						<div>{{ scope.row.isSignOverName }}</div>
					</template>
				</el-table-column>
				
				<el-table-column
					column-key="signRate"
					v-if="isSend"
					label="签收率"
					align="center"
				>
					<template slot-scope="scope">
						<div @click="showSignRate(scope.row)" style="color:blue;">{{ scope.row.signRate }}</div>
					</template>
				</el-table-column>
				
				
				<el-table-column
					label="操作"
					align="center"
					width="80"
					type="index"
				>
					<template slot-scope="scope">
						<div>
							<el-button v-show="!isSend && showfeedbackBtn(scope.row)" type="text" style="color: #008000;" @click="showFeedback(scope.row, scope.$index)">反馈</el-button>
							<el-button v-if="0" v-show="!isSend && showSignBtn(scope.row)" type="text" @click="sign(scope.row,scope.$index)">签收</el-button>
							<el-button type="text" style="color: #e6a23c;" @click="showDetail(scope.row, scope.$index)">查看</el-button>
						</div>
					</template>
				</el-table-column>
				
			</el-table>
			
		</div>
	`
})