// 公共方法

// 格式化调度通知数据
function formatMsgData(data) {
	if(data == '' || !data)return false	
	
	// 状态
	const getStateName = (value) => {
		let name = blankMark
		stateOptions.forEach(item => {
			if(value === item.value){
				name = item.name;
			}
		})
		return name
	}
	
	const getOverseeName = (value) => {
		let name = blankMark
		overseeOptions.forEach(item => {
			if(value == item.value) name = item.name;
		})
		return name
	}
	
	const getSignName = (value, isNeedSign) => {
		let name = blankMark
		if(isNeedSign == 1) return NONEEDSIGN;
		signOptions.forEach(item => {
			if(value == item.value) name = item.name;
		})
		return name
	}
	
	const getReceiveName = (value) => {
		let name = blankMark
		receiveOptions.forEach(item => {
			if(value == item.value) name = item.name;
		})
		return name
	}
	
	const getFeekbackName = (value, isOversee = 1) => {
		let name = blankMark
		if(isOversee == 0) return NONEEDFEEDBACK;
		feedbackOptions.forEach(item => {
			if(value == item.value) name = item.name;
		})
		return name
	}
	
	
	// 可对对象/数组 进行操作
	let arr = []
	let isArray = true
	if(typeof data == 'object' && !Array.isArray(data)){
		arr = [data]
		isArray = false
	}else{
		arr = data
	}
	
	const newData = arr.filter(item => {
		// 过滤部分数据
		
		return true	
	}).map(item => {
		return {
			title: item.messageTitle,
			fileNum: item.messageNumber,
			category: item.messageTypeCode,
			categoryName: item.messageTypeName,
			publishUnit: item.sendOrgName,
			publishTime: item.sendTime,
			publishPerson: item.sendPeople,
			state: item.messageState,
			stateName: getStateName(item.messageState),
			isOversee: item.dbFlag,
			isOverseeName: getOverseeName(item.dbFlag),
			isSign: item.qsFlag,
			isSignName: getSignName(item.qsFlag, item.receiveFlag),
			isSignOver: 1,
			isSignOverName: item.alReadRate != '100%' ? '否' : '是',
			signRate: item.alReadRate,
			fileList: item.fileList,
			needSignOrgNum: item.allNum,
			hadSignOrgNum: item.alreadyQsNum,
			isFeedback: item.fkFlag,
			isFeedbackName: getFeekbackName(item.fkFlag, item.dbFlag),
			feedbackContent: item.fkInfo,
			receiveFlag: item.receiveFlag,
			receiveFlagName: getReceiveName(item.receiveFlag),
			endTime: item.endTime,
			startTime: item.beginTime,
			
		}  
	})
	
	
	return isArray ? newData : newData[0];
}

// 格式化签收数据
function formatSignData(data) {
	return data.map(item => {
		return {
			needSignOrgName: item.receiveOrgName,
			needSignJob: item.postName,
			realSignOrgName: item.qsFlag == 0 ? blankMark : item.receiveOrgName,
			isSign: item.qsFlag,
			realSignPerson: item.qsFlag == 0 ? blankMark : item.readPeople,
			realSignTime: item.qsFlag == 0 ? blankMark : item.readTime,
			needSignTime: item.gdReadTime,
			isFeedback: item.fkFlag,
			feedbackPerson: item.fkFlag == 0 ? blankMark : item.fkPeople,
			feedbackInfo: item.fkFlag == 0 ? blankMark : item.fkInfo,
			feedbackTime: item.fkFlag == 0 ? blankMark : item.fkTime,
			needFeedbackTime: item.gdFkTime
		}
	})
}



// 时间戳转时间格式
function formatTime(value){
	if(!value || value == blankMark)return blankMark;
	const time = 1 * value
	const date = new Date(time);
	const YY = date.getFullYear();
	const MM = (date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1) ;
	const DD = (date.getDate() < 10 ? '0' + (date.getDate()) : date.getDate());
	const hh = (date.getHours() < 10 ? '0' + date.getHours() : date.getHours());
	const mm = (date.getMinutes() < 10 ? '0' + date.getMinutes() : date.getMinutes());
	const ss = (date.getSeconds() < 10 ? '0' + date.getSeconds() : date.getSeconds());
	
	const mark1 = '-'
	const mark2 = ':'
	return `${YY}${mark1}${MM}${mark1}${DD} ${hh}${mark2}${mm}${mark2}${ss}`;
}
