var secondaryPage = {
	props: ['noData','endSign', 'tableColumnList', 'tableHeight', 'yName', 'dataList'],
	data() {
		return {
			tipShow: false,
			msg: '当前日期的数据暂未更新呢！',
			tableData: []
		}
	},
	template: `
		<div>
			<div v-show="!noData">
				<div class="echart" ref="echart"></div>
				<table-box
					ref="tableBox"
					:table-column-list="tableColumnList"
					:table-data="tableData"
					:table-height="tableHeight"
				>
				</table-box>
			</div>
			<!-- 暂无数据 -->
			<div v-show="noData">
				<run-text img-url="../../" :msg="msg" :is-show="tipShow" @close="close"></run-text>
				<div class="noData">
					<img src="../../image/nodata.png" alt="暂无数据" />
					<h3>暂无数据</h3>
				</div>
			</div>
		</div>
	`,
	watch: {
		noData(val) {
			this.tipShow = val;
		},
		dataList(val) {
			if (val) {
				this.setData();
			}
		}
	},
	methods: {
		// 数据处理
		setData() {
			// echart相关
			let average = 0;
			let barJson = {
				endSign : this.endSign,
				yName: this.yName,
				xValue: [],
				barValue: [],
				lineValue: []
			};
			// 数据判空
			let data = JSON.parse(this.dataList);
			data.forEach((item, index) => {
				this.tableColumnList.forEach(columnItem => {
					let prop = columnItem.prop;
					// 填充数据
					if(prop == 'areaName') {
						item[prop] = item[prop] ? item[prop] : '其它';
					} else {
						item[prop] = item[prop] === null ? '' : ((item[prop] ? item[prop] : 0)).toFixed(2);
					}
					
				})
				if (index == 0) {
					barJson.title = item.areaName;
					//全国全年平均直线
					barJson.average = item.yearComValue;
				} 
				//x轴名字
				barJson.xValue.push(item.areaName);
				//年平均值
				barJson.barValue.push(item.yearComValue);
				//全国全年平均直线
				barJson.lineValue.push(barJson.average);
			}) 
			this.renderPage(data, barJson);
		},
		// 渲染页面
		renderPage(data, barJson) {
			// 表格
			this.tableData = data;
			this.$refs.tableBox.$refs.table.clearSort();
			// 柱状图
			this.$nextTick(() => {
				this.getBarChart(barJson);
			});
		},
		// 柱状图
        getBarChart(data) {
			let json = {
				legendData: [
				{
					name: '全国平均值'+data.endSign
				}, {
					name: '当年累计值' +data.endSign,
					icon: 'image://data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAAoAQMAAABTru9CAAAABlBMVEUAxIL3RidNALHZAAAAE0lEQVQY02NgAIH/IMAwyhw6TABNs8c5rOzZTgAAAABJRU5ErkJggg=='
				}],
				yName: data.yName,
				average: 0,
				xValue: data.xValue,
				barName: '当年累计值' + data.endSign,
				barValue: data.barValue,
				lineName: '全国平均值' + data.endSign,
				lineValue: data.lineValue
			};
			let myChart = echarts.init(this.$refs.echart);
			let option = averageBarOption(json);

            myChart.setOption(option, true);
            myChart.on('legendselectchanged', function (params) {
				let option = this.getOption();
				let name = params.name;
                if (!params.selected[name]) {
                    // false 的时候
                    let isTure = [];
                    for(var item in params.selected){
                        if (params.selected[item]) {
                            isTure.push(item)
                        };
                    }
                    if (isTure.length > 0) {
                        option.legend[0].selected[name] = false;
                    } else {
                        option.legend[0].selected[name] = true;
                    }
                } else {
                    // true 的时候
                    option.legend[0].selected[name] = true;
				}
				if (name == ('当年累计值'+data.endSign) && option.legend[0].selected['当年累计值'+data.endSign]) {
					option.legend[0].data[1].icon = 'image://data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAAoAQMAAABTru9CAAAABlBMVEUAxIL3RidNALHZAAAAE0lEQVQY02NgAIH/IMAwyhw6TABNs8c5rOzZTgAAAABJRU5ErkJggg==';
				} else if (name == ('当年累计值'+data.endSign) && !option.legend[0].selected['当年累计值'+data.endSign]) {
					option.legend[0].data[1].icon = 'image://data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAAoAQMAAABTru9CAAAABlBMVEXMzMzv7++Y3rQzAAAAE0lEQVQY02P4DwL2IIJhlDl0mADDfHCAiQlelgAAAABJRU5ErkJggg==';
				}
				console.log(data.endSign+'***');
                this.setOption(option)
            });
		},
		// 关闭提示
		close() {
			this.tipShow = false;
		}
	}

};