var secondaryPage = {
	props: ['noData', 'tableColumnList', 'tableHeight', 'yName', 'dataList'],
	data() {
		return {
			tipShow: false,
			msg: '当前日期的数据暂未更新呢！',
			tableData: []
		}
	},
	template: `
		<div>
			<div v-show="!noData">
				<div class="echart" ref="echart"></div>
				<table-box
					ref="tableBox"
					:table-column-list="tableColumnList"
					:table-data="tableData"
					:table-height="tableHeight"
					@sort-list="sortTableData"
				>
				</table-box>
			</div>
			<!-- 暂无数据 -->
			<div v-show="noData">
				<run-text img-url="../../" :msg="msg" :is-show="tipShow" @close="close"></run-text>
				<div class="noData">
					<img src="../../image/nodata.png" alt="暂无数据" />
					<h3>暂无数据</h3>
				</div>
			</div>
		</div>
	`,
	watch: {
		noData(val) {
			this.tipShow=false;
			this.tipShow = val;
		},
		dataList(val) {
			if (val) {
				this.setData();
			}
		}
	},
	methods: {
		// 数据处理
		setData() {
			// echart相关
			let average = 0;
			let barJson = {
				yName: this.yName,
				xValue: [],
				barValue: [],
				lineValue: []
			};
			// 数据判空
			let data = JSON.parse(this.dataList);
			data.forEach((item, index) => {
				this.tableColumnList.forEach(columnItem => {
					let prop = columnItem.prop;
					// 填充数据
					if(prop == 'areaName') {
						item[prop] = item[prop] ? item[prop] : '其它';
					} else {
						item[prop] = item[prop] === null ? '' : ((item[prop] ? item[prop] : 0) * 1).toFixed(2);
					}
					
				})
				if (item.areaName === '全国') {
					//平均值直线
					barJson.average = item.target;
					//x轴
					barJson.xValue.push(item.areaName);
					//年平均值
					barJson.barValue.push(item.achievements);
					
					barJson.lineValue.push(barJson.average);
				} else {
					//平均值直线
					barJson.average = item.target;
					//x轴
					barJson.xValue.push(item.areaName);
					//年平均值
					barJson.barValue.push(item.achievements);
					
					barJson.lineValue.push(barJson.average);
				}
			})
			this.renderPage(data, barJson);
		},
		// 渲染页面
		renderPage(data, barJson) {
			// 表格
			this.tableData = data;
			this.$refs.tableBox.$refs.table.clearSort();
			// 柱状图
			this.$nextTick(() => {
				this.getBarChart(barJson);
			});
		},
		// 表格数据排序
		sortTableData(data) {
			this.tableData = data;
		},
		// 柱状图
        getBarChart(data) {
			let json = {
				legendData: [
				{
					name: '目标值%'
				}, {
					name: '实绩%',
					icon: 'image://data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAAoAQMAAABTru9CAAAABlBMVEUAxIL3RidNALHZAAAAE0lEQVQY02NgAIH/IMAwyhw6TABNs8c5rOzZTgAAAABJRU5ErkJggg=='
				}],
				yName: data.yName,
				average: 0,
				xValue: data.xValue,
				barName: '实绩%',
				barValue: data.barValue,
				lineName: '目标值%',
				lineValue: data.lineValue
			};
			let myChart = echarts.init(this.$refs.echart);
			let option = averageBarOption(json);

            myChart.setOption(option, true);
            myChart.on('legendselectchanged', function (params) {
				let option = this.getOption();
				let name = params.name;
                if (!params.selected[name]) {
                    // false 的时候
                    let isTure = [];
                    for(var item in params.selected){
                        if (params.selected[item]) {
                            isTure.push(item)
                        };
                    }
                    if (isTure.length > 0) {
                        option.legend[0].selected[name] = false;
                    } else {
                        option.legend[0].selected[name] = true;
                    }
                } else {
                    // true 的时候
                    option.legend[0].selected[name] = true;
				}
				if (name == '实绩%' && option.legend[0].selected['实绩%']) {
					option.legend[0].data[1].icon = 'image://data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAAoAQMAAABTru9CAAAABlBMVEUAxIL3RidNALHZAAAAE0lEQVQY02NgAIH/IMAwyhw6TABNs8c5rOzZTgAAAABJRU5ErkJggg==';
				} else if (name == '实绩%' && !option.legend[0].selected['实绩%']) {
					option.legend[0].data[1].icon = 'image://data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAAoAQMAAABTru9CAAAABlBMVEXMzMzv7++Y3rQzAAAAE0lEQVQY02P4DwL2IIJhlDl0mADDfHCAiQlelgAAAABJRU5ErkJggg==';
				}
                this.setOption(option)
            });
		},
		// 关闭提示
		close() {
			this.tipShow = false;
		}
	}

};