/**
 * 表
 * isNo: 是否显示序号列
 * redBy: 是否红图模式[min,max]
 * notReverse: 红绿色显示逻辑是否反转
 * specialName: 不参与排序的特殊行
 * 列
 * subByZero: true数字显示红绿色根据0分割为2段 绿-红
 * subByTarget: key数字显示红绿色根据字段分割为2段 绿-红
 * subByKey: 数字显示红绿色根据0和字段分割为3段 绿-黑-红
 * subDown: 比给定值小的显示红色
 * subUp: 比给定值大的显示绿色
 * reverse: 单列的颜色设置是否反转，支持subByZero、subByTarget
 * isRate: 一般在表头显示%，isRate时单元格显示%
 * isNumber: 表示这一列是数字，需要粗体显示
 * align: 值靠左靠右
 * paddingRight: 值右边距，和align=right组合使用
 */

Vue.component('drillDownBox', {
	data() {
		return {
			wholeRate: '',
			sendCode: '',
			recvProvCode: '',
			sendName: '',
			recvProvName: '',
			img: '',
			// show_a: '',
			// show_b: '',
			activeNames: [],
			accordionList: [{
				img: '../../image/out.png',
				title: '省际出口段达成率',
				index: '1',
				progress: '50',
				table: [],
				table_copy: [],
				worseList: [],
				name: '出口单位'
			}, {
				img: '../../image/in.png',
				title: '省际进口段达成率',
				index: '2',
				progress: '70',
				table: [],
				table_copy: [],
				worseList: [],
				name: '进口单位'
			}, {
				img: '../../image/transport.png',
				title: '省际运输段达成率',
				index: '3',
				progress: '20',
				table: [],
				table_copy: [],
				worseList: [],
				name: '运输单位'
			}, {
				img: '../../image/transfer.png',
				title: '省际经转段达成率',
				index: '4',
				progress: '35',
				table: [],
				table_copy: [],
				worseList: [],
				name: '经转单位'
			}],
			normalColor: '#333333',
			drillColor: '#3377FF',
			upColor: '#009900',
			downColor: '#FA2525',
			toastId: null,
			drawer: false,
			direction: 'btt',
			len: 0,
			sortList1: [
				{ name: '时限达成率', up: false, down: false, order: 0 },
			],
			clickCount: 0,
			index: 0
		}
	},
	props: {
		initSendCode: {
			String,
			default: '-1'
		},
		businessType: {
			String,
			default: () => {
				return '';
			}
		},
		dateType: {
			String,
			default: () => {
				return '';
			}
		},
		dataDate: {
			String,
			default: () => {
				return '';
			}
		},
		sumLevel: {
			String,
			default: () => {
				return '';
			}
		},
		defaultColor: {
			String,
			default: () => {
				return '';
			}
		},
		tablecolumn: {
			Array,
			default: () => {
				return [{
					label: '封发量',
					key: 'value',
				}]
			}
		},
		tableHeight: {
			Number,
			default: null
		},
		list: {
			Array,
			default: () => {
				return [{
					name: '北京市',
					value: '36',
					zrtb: 0
				}]
			}
		},
		isNo: {
			Boolean,
			default: false
		},
		isLoadMore: {
			Boolean,
			default: false
		},
		isBorder: {
			Boolean,
			default: false
		},
		notReverse: {
			Boolean,
			default: true
		},
		subByZero: {
			Boolean,
			default: false
		},
		specialName: {
			Array,
			default: () => {
				return []
			}
		},
		redBy: {
			Object,
			default: null
		},
	},
	watch: {
		activeNames(val, oldVal) {
			if(val == oldVal) return;
			else {
				this.sortList1 = [{ name: '时限达成率', up: false, down: false, order: 0 }]
				this.sortDefault(this.clickCount, this.index)
			}
		}
	},
	computed: {
		rowLen: function() {
			return this.list ? this.list.length : 0;
		},
		colLen: function() {
			return this.tablecolumn ? this.tablecolumn.length : 0;
		},
	},
	methods: {
		getColor(row, item) {
			if (this.redBy) {
				//红图模式，样式自定
				return;
			}
			if (item.isDrillDown && this.filterDrillDown(row, item)) {
				if (!row.notDrill && row[item.key] != 0) {
					if (this.defaultColor) {
						//如果设置有主色调颜色，下钻单元格问题颜色用主色调,否则用默认
						return this.defaultColor;
					}
					return this.drillColor;
				}
			}

			if (item.compareKey) {
				if (row[item.compareKey] != 0) {
					if (this.notReverse) {
						if (row[item.compareKey] > 0) return this.upColor;
						if (row[item.compareKey] < 0) return this.downColor;
					} else {
						if (row[item.compareKey] < 0) return this.upColor;
						if (row[item.compareKey] > 0) return this.downColor;
					}
				}
			}

			if (item.subByZero) {
				//以0分为2段
				let val = row[item.key];
				if (val != '-' && parseFloat(val) != 0) {
					if (this.notReverse && !item.reverse) {
						if (parseFloat(val) < 0) return this.downColor;
						if (parseFloat(val) > 0) return this.upColor;
					} else {
						if (parseFloat(val) < 0) return this.upColor;
						if (parseFloat(val) > 0) return this.downColor;
					}
				}
			}

			if (item.subByTarget) {
				//以key分为2段
				let val = row[item.key];
				let sub = row[item.subByTarget];
				if (val != '-' && parseFloat(val) != 0) {
					if (this.notReverse && !item.reverse) {
						if (parseFloat(val) < sub) return this.downColor;
						if (parseFloat(val) > sub) return this.upColor;
					} else {
						if (parseFloat(val) < sub) return this.upColor;
						if (parseFloat(val) > sub) return this.downColor;
					}
				}
			}

			if (item.subByKey) {
				//以0和key分为3段
				let sub = row[item.subByKey];
				let val = row[item.key];
				if (val != '-' && parseFloat(val) != 0) {
					if (val <= 0) {
						return this.downColor;
					} else if (val > sub) {
						return this.upColor;
					} else {
						return this.normalColor;
					}
				}
			}

			if (item.subDown || parseFloat(item.subDown) === 0) {
				let val = row[item.key];
				let sub = item.subDown;
				if (val != '-' && parseFloat(val) != 0) {
					if (this.notReverse) {
						if (parseFloat(val) < sub) return this.downColor;
					} else {
						if (parseFloat(val) < sub) return this.upColor;
					}
				}
			}
			if (item.subUp || parseFloat(item.subUp) === 0) {
				let val = row[item.key];
				let sub = item.subUp;
				if (val != '-' && parseFloat(val) != 0) {
					if (this.notReverse) {
						if (parseFloat(val) > sub) return this.upColor;
					} else {
						if (parseFloat(val) > sub) return this.downColor;
					}
				}
			}
			return this.normalColor;
		},
		getValue(val, compareKey, isRate, is10Thousand) {
			if (val && val.color) {
				//重点区域提速-红图使用
				val = val.value;
			}
			let res;
			if (val === undefined || val === '' || val == null) {
				res = '-'
			} else if (compareKey && compareKey < 0) {
				res = "-" + val;
			} else {
				res = val;
			}
			if (isRate && res != '-') {
				res = res + "%";
			} else if (is10Thousand && res != '-') {
				res = (res / 10000).toFixed(2);
			}
			return res;
		},
		
		redWindow() {
			// if(this.sumLevel >= 2) return
			vant.Toast.loading({
				message: '加载中...',
				forbidClick: true,
				duration: 10000
			})
			var timestamp = dayjs().format('YYYY-MM-DD HH:mm:ss');
			const path = '/dpkServer/getRedFigureInfoDetail';
			// let num = 0;
			// if (this.level === '1' || this.level === '2') num += this.curr;
			// else num = Number(this.level) + this.curr - 2;
			let params = {
				sendProvCode: this.sendCode,
				recvProvCode: this.recvProvCode,
				sumLevel: this.sumLevel,
				dataDate: this.dataDate.split('-').join(''),
				dateType: this.dateType,
				businessType: this.businessType,
				// partType:'1'
			};
			// console.log(params, '红图弹窗参数');
			this.accordionList[0].worseList = []
			this.accordionList[1].worseList = []
			this.accordionList[2].worseList = []
			this.accordionList[3].worseList = []
			const msgbody1 = JSON.stringify(params);
			var interface = axios.create({
				'Access-Control-Allow-Origin': '*',
				baseURL: board_url,
				timeout: 10000,
			})
			interface.get(path, {
				params: {
					'sendID': '00000001',
					'timestamp': timestamp,
					'msgBody': msgbody1,
					'dataDigest': base64.encode(hex_md5(msgbody1 + data_key + timestamp))
				}
			}).then(({ data }) => {
				// console.log(data, "红图弹窗数据"); // 外层指标弹窗数据
				if (data.data.length === 0) return
				else {
					console.log(data.data, '红图弹窗数据');
					data.data.forEach(i => {
						if (i.partType == 1) {
							this.accordionList[0].title = i.partName
							this.accordionList[0].progress = i.rate;
							this.accordionList[0].worseList = i.worstCitys !== undefined ? (i.worstCitys) : []	
						} else if (i.partType == 2) {
							this.accordionList[1].title = i.partName
							this.accordionList[1].progress =   i.rate;
							this.accordionList[1].worseList = i.worstCitys !== undefined ? (i.worstCitys) : []
						} else if (i.partType == 3) {
							this.accordionList[2].title = i.partName
							this.accordionList[2].progress =  i.rate;
							// this.accordionList[2].worseList = i.worstCitys !== undefined ? (i.worstCitys) : [] // 运输段最差
						} else {
							this.accordionList[3].title = i.partName
							this.accordionList[3].progress =  i.rate;
							// this.accordionList[3].worseList = i.worstCitys !== undefined ? (i.worstCitys) : [] // 经传段最差
						}
					})
					// this.wholeRate = data.data[0].rate
				}
			}).catch(err => {
				this.list = [];
				console.log(err);
			}).finally(() => {
				this.$nextTick(() => {
					vant.Toast.clear();
					// this.$refs.echarts.initDefault();
				})
			});
		},
		redWindowList(param) {
			this.accordionList[param - 1].table = []; 
			this.accordionList[param - 1].table_copy = [];
			// if(this.sumLevel > 2) return
			// if(this.sumLevel >= 2) return
			vant.Toast.loading({
				message: '加载中...',
				forbidClick: true,
				duration: 10000
			})
			var timestamp = dayjs().format('YYYY-MM-DD HH:mm:ss');
			const path = '/dpkServer/getRedFigureInfoDetailDown';
			// let num = 0;
			// if (this.level === '1' || this.level === '2') num += this.curr;
			// else num = Number(this.level) + this.curr - 2;
			let params = {
				sendProvCode: this.sendCode,
				recvProvCode: this.recvProvCode,
				sumLevel: Number(this.sumLevel) + 1,
				dataDate: this.dataDate.split('-').join(''),
				dateType: this.dateType,
				businessType: this.businessType,
				partType: param
			};
			const msgbody1 = JSON.stringify(params);
			var interface = axios.create({
				'Access-Control-Allow-Origin': '*',
				baseURL: board_url,
				timeout: 10000,
			})
			
			interface.get(path, {
				params: {
					'sendID': '00000001',
					'timestamp': timestamp,
					'msgBody': msgbody1,
					'dataDigest': base64.encode(hex_md5(msgbody1 + data_key + timestamp))
				}
			}).then(({ data }) => {
				// console.log(data.data, "红图弹窗----明细数据"); // 指标明细数据
				if (data.data.length === 0) return
				else {
					data.data.forEach((i, n) => {
						i.index = n * 1 + 1
						i.rate += '%'
						this.accordionList[param - 1].table.push(i);
						this.accordionList[param - 1].table_copy.push(i)
					})
				}
			}).catch(err => {
				this.list = [];
				console.log(err);
			}).finally(() => {
				this.$nextTick(() => {
					vant.Toast.clear();
					// this.$refs.echarts.initDefault();
				})
			});
		},
		// 排序方法
		sortFun(arr) {
			return arr.sort((b, a) => {
				return a.rate - b.rate;
			})
		},
		xiazuan(row, item, index) {
			// console.log(row,item,index)
			// console.log(index, '下标---------');
			// console.log(JSON.stringify(row), '行数据');
			// console.log(item, '列配置');
			// console.log(Object.keys(row), 'hhhhhhhhhhhhhhhh');
			this.sendCode = this.list[index].code
			this.recvProvCode = item.key
			// 当点击的是进口汇总或者出口汇总时，不弹出弹层
			if(this.sendCode == '99999999' || this.recvProvCode == '99999999') return

			// 出口城市和进口城市一样时，不弹出下钻弹层
			if(this.sendCode == this.recvProvCode) return;
			if (
				this.sumLevel != 1 && item.key === this.initSendCode
			) {
				// 例：点击太原市-山西，不弹出下钻弹层
				return;
			}
			//原寄省名称
			this.sendName = row.name
			//寄达省名称
			this.recvProvName = item.label
			//整体达成率
			this.wholeRate = row[item.key].value + '%'
			// console.log(this.recvProvCode, this.sendCode, 'klklkl');
			// 红图弹窗接口
			this.redWindow()
			this.redWindowList(1)
			this.redWindowList(2)
			// this.redWindowList(3)   数据问题暂时关闭运输段、经转段下钻
			// this.redWindowList(4)
			row[item.key].value ? this.drawer = true : this.drawer = false;

			// console.log(row, item, 'ooooooooooooo');
			if (!item.isDrillDown || !this.filterDrillDown(row, item)) return;
			if (row.notDrill) return;
			this.$emit('drilldown', {
				row: row,
				item: item
			});
		},
		sortMethod(a, b, key, compareKey) {
			let l = a[key];
			let r = b[key];
			if (l == undefined || l == null || l == '') {
				l = -100000000;
			} else {
				if (a[compareKey] < 0) {
					l *= -1;
				}
			}
			if (r == undefined || r == null || r == '') {
				r = -100000000;
			} else {
				if (b[compareKey] < 0) {
					r *= -1;
				}
			}
			return r - l;
		},
		changeTableSort({
			column,
			prop,
			order
		}) {
			if (column.sortable !== 'custom') {
				return;
			}
			let fieldName = prop;
			let sortingType = order;
			let list = this.list;
			let orderList = [];
			let freeList = [];
			list.map(it => this.specialName.indexOf(it.name) >= 0 ? freeList.push(it) : orderList.push(it));
			if (sortingType == 'descending') {
				list = orderList.sort((a, b) => a[fieldName] - b[fieldName]);
				freeList.push.apply(freeList, orderList);
				this.list = freeList;
			} else if (sortingType == 'ascending') {
				orderList = orderList.sort((a, b) => b[fieldName] - a[fieldName]);
				freeList.push.apply(freeList, orderList);
				this.list = freeList;
			} else {
				orderList = orderList.sort((a, b) => a.nameCode > b.nameCode ? 1 : -1);
				freeList.push.apply(freeList, orderList);
				this.list = freeList;
			}
			this.$emit('sortList', this.list);
			this.$emit('sort-list', this.list);
		},
		setColumnWidth(text) {
			if (this.tablecolumn.length <= 3) return null;
			if (!text) {
				return 96;
			}
			return 96;
		},
		getPaddingRight(scope, item) {
			if (item.paddingRight) {
				if (item.paddingRight > 0) {
					return item.paddingRight + 'px';
				}
			}
			if (item.paddingRight < 0 || (!item.width && item.align == 'right')) {
				let width = (scope.column.realWidth - scope.column.label.length * 12) / 2;
				if (item.sortable) {
					width += 12;
				}
				if (width > 0) {
					return width + 'px';
				}
			}
			if (item.sortable && item.align == 'right') {
				return '24px';
			}
			return '0px';
		},
		// 表头换行
		renderHeader(h, {
			column,
			$index
		}) {
			var lab = column.label;
			if (lab.indexOf("|") < 0) {
				return h('span', {}, lab)
			} else {
				var arr = lab.split('|')
				const list = [];
				arr.forEach(item => {
					list.push(h('span', {}, item));
					list.push(h('br'));
				})
				list.pop()
				return h('span', {}, list)
			}
		},
		// 特殊名字过滤
		filterDrillDown(row, item) {
			if (this.specialName.indexOf(row.name) >= 0) {
				return false;
			}
			return true;
		},
		switchColumn() {
			this.$emit('switchcolumn', {});
		},
		filterColumn(c) {
			return c.filter(function(item) {
				return item.chose == undefined || item.chose;
			});
		},
		columnSetConfirm() {
			Emp.execute("saveColumnSetKnow()");
		},
		getSortIcon(index) {
			if (index == 1) {
				return '../../image/icon_sort_1.png';
			} else if (index == 2) {
				return '../../image/icon_sort_2.png';
			} else {
				return '../../image/icon_sort_3.png';
			}
		},
		// 排序图标
		iconSrc1(order) {
			if (order === 0) return '../../image/px.png'
			if (order === 1) return '../../image/up1.png'
			if (order === 2) return '../../image/down1.png'
		},
		toggleToast(row, item) {
			let views = this.$refs.toast;
			let pop;
			if (views) {
				if (views.length > 1) {
					pop = views[1];
				} else if (views.length > 0) {
					pop = views[0];
				}
			}
			if (!pop) return;
			//某个单元格需要点击吐丝提示增加的代码
			if (this.toastId) {
				clearTimeout(this.toastId);
			}
			if (pop.value) {
				pop.value = false;
			} else {
				pop.value = true;
				this.toastId = setTimeout(() => {
					pop.value = false;
					this.toastId = null;
				}, 3100);
			}
		},
		changeCellStyle({
			row,
			column,
			rowIndex,
			columnIndex
		}) {
			if (this.redBy) {
				// if(column.property == '140300'){
				// 	console.log(row[column.property])
				// }
				//红图模式
				if (columnIndex === 0) {
					return 'background:#0197FF;color:#fff;text-align:center;';
				} else if (this.redBy.max) {
					if (row[column.property] > this.redBy.max) {
						return 'text-align:right;padding-right:14px;background: #58DEB6;';
					} else if (row[column.property] < this.redBy.min) {
						return 'text-align:right;padding-right:14px;background: #FF6666;';
					} else {
						return 'text-align:right;padding-right:14px;background: #FFF;';
					}
				} else if (row[column.property] && row[column.property].color) {
					return 'text-align:right;padding-right:14px;background: ' + row[column.property].color + ';';
				}
			}
			return null;
		},
		registerLoadMoreListener() {
			const selectWrap = document.querySelector('.el-table__body-wrapper');
			selectWrap.addEventListener('scroll', () => {
				const scrollDistance = selectWrap.scrollHeight - selectWrap.scrollTop - selectWrap.clientHeight;
				// console.log(scrollDistance);
				// 同时满足以下情况，加载下一页
				// 1.页面滑动到底部，即scrollDistance = 0
				// 2.页面有滑动的情况，即selectWrap.scrollHeight > selectWrap.clientHeight
				if (scrollDistance <= 2 && selectWrap.scrollHeight > selectWrap.clientHeight) {
					// 加载更多
					this.$emit('load-more');
				}
			})
		},
		closeDrawer() {
			this.drawer = false;
		},
		format(percentage) {
			return percentage === 100 ? '满' : `${percentage}%`;
		},
		sortListFun() {
			this.sortList1.forEach(i => {
				i.up = false;
				i.down = false;
				i.order = 0;
			})
		},
		sortItem1(item, i, index) {
			this.clickCount = i;
			this.index = index;
			if (item.up) {
				this.sortDown(i, index)
				return
			}
			if (item.down) {
				this.sortUp(i, index)
				return
			} 
			if (!item.up && !item.down) {
				this.sortDown(i, index)
				return
			}
		},
		sortDefault(i, index) {
			this.accordionList[i - 1].table = [...this.accordionList[i - 1].table_copy]
		},
		sortDown(i, index) {
			let name = ['rate'];
			this.sortListFun()
			this.sortList1[index].down = true;
			this.sortList1[index].order = 2;
			this.accordionList[i - 1].table.sort((a, b) => {
				return parseFloat(a[name[index]]) - parseFloat(b[name[index]])
			})
			this.accordionList[i - 1].table.reverse();
		},
		sortUp(i, index) {
			let name = ['rate'];
			this.sortListFun();
			this.sortList1[index].up = true;
			this.sortList1[index].order = 1;
			this.accordionList[i - 1].table.sort((a, b) => {
				return parseFloat(b[name[index]]) - parseFloat(a[name[index]])
			})
			this.accordionList[i - 1].table.reverse();
		},
		// 是否禁用下钻
		isDisabled(arr) {
			if(arr.length === 0) return true;
			else return false;
		}
	},
	mounted() {
		if (this.isLoadMore) {
			this.registerLoadMoreListener();
		}
	},
	template: `<div>
					<el-drawer
						title="山西-河北"
						:visible.sync="drawer"
						:direction="direction"
						size="390px"
						:with-header="false"
					>
						<div style="display:flex;padding:15px 0px 15px 0px;justify-content:center;position:relative;border-bottom:1px solid #ece9ec">
								<span style="font-size:18px">{{sendName}}-{{recvProvName}}</span>
								<span style="font-size:18px;margin-left:10px;color:#409eff">{{ wholeRate }}</span>
								<div
									@click="closeDrawer"
									style="
										width:15px;
										height:5px;
										position: absolute;
										padding:8px;
										background: no-repeat url(../../image/closeRed.png) center / 15px;
										right:14px;
										top:50%;
										transform: translate(0, -50%);
									"
								></div>
						</div>  
						<div style="overflow:auto;height: 330px;">
							<el-collapse v-model="activeNames" v-for="its in accordionList" style="position:relative;" accordion>
								<el-collapse-item
									:name="its.index"
									:disabled="isDisabled(its.worseList)"
									style="border-top:0px"
									:class="{
										'no-arrow': !its.table || its.table.length < 1
									}"
								>
									<template slot="title">
										<div style="display:flex; justify-content:between; align-items:center;">
											<div :style="{backgroundImage: 'url(' + its.img + ')'}" style="background-repeat: no-repeat;
												 background-size: 100% 100%;width:30px;height:30px;margin-right:20px">
											</div>
											<div style="width:270px; display:flex;justify-content:center;flex-direction:column">
												<div>{{ its.title }}</div>
												<div style="display: flex; color: #fa2426;">
													<div v-show="its.worseList.length !== 0"  style="white-space:nowrap;">最差：</div>
													<div style="display: flex;flex-wrap: wrap;">
														<div style="display: flex; font-size: 12px;" v-for="i in its.worseList" >
															{{ i.sendCityName }} 
															{{ i.rate + '%' }}
															<div style="width: 8px;"></div>
														</div>
													</div>
												</div>
												<div style="display: flex; align-items: center;">
													<el-progress id="redPro" :percentage="its.progress" style="width: 250px;"></el-progress> 
													<div style="color: #409eff;font-size: 14px; width: 45px;margin-right: -15px;">
														{{ (its.progress == undefined || its.progress * 1 < 0) ? ' - ' : parseFloat(its.progress).toFixed(2) }}%
													</div>
												</div>
											</div>
										</div>
									</template>

									<div 
										 style=" padding:10px 20px 10px 20px;border-bottom:1px solid #ece9ec;" >
										<div class="header" style="background-color: #0199FF; color: white;height: 40px;" 
											 v-for="(item, index) in sortList1"
											 v-show="its.worseList.length !== 0"
											 :key="index">
											<div class="item" style="width: 30%;"> 序号 </div>
											<div class="item" style="width: 40%;"> {{ its.name }} </div> 
											<div class="item" style="width: 30%;"
												 @click="sortItem1(item, its.index * 1, index)"
											>
												{{ item.name }}
												<img :src="iconSrc1(item.order)" alt="" style="height: 18px; margin-left: 5px">
											</div>
										</div>
										<div style="" >
											<div v-for="(i, index) in its.table"
												 :key="index"
												 class="header"
												 :style="{'background-color': index % 2 === 0 ? '#ece9ec' : ''}"
											>
												<div class="item" style="width: 30%;" >{{ index + 1 }}</div>	
												<div class="item" style="width: 40%;" >{{ i.sendCityName }}</div>	
												<div class="item" style="width: 30%;" >{{ i.rate }}</div>	
											</div>
										</div>
									</div>
								</el-collapse-item>
							</el-collapse>
						</div>
					</el-drawer>

                <div style="box-sizing: border-box">
                    <div style="padding: 0 2px">
                        <el-table
                                ref="tableActive"
                                :data="list"
                                stripe
                                :border="isBorder"
                                header-cell-class-name="blue-table-header"
                                row-class-name="blue-table-row"
                                :header-cell-style="{background:defaultColor ? defaultColor : '#0199FF',color:'#FFF', height: '30px', 'text-align': 'center', fontSize: '12px', fontWeight: 'normal'}"
                                :row-style="{height:'30px',fontSize: '12px'}"
                                :cell-style="changeCellStyle"
                                :style="[!isLoadMore ? {width: '100%'} : {width: '100%',overflow: 'auto',height: '100vh'}]"
                                :height="tableHeight"
                                @sort-change="changeTableSort"
                                >
                            <el-table-column
                                    v-if="isNo"
                                    type="index"
                                    label="序号"
                                    align="center"
                                    fixed
                                    width="50"
                                    >
                            </el-table-column>
                            <el-table-column
                                    v-for="item in filterColumn(tablecolumn)"
                                    :key="item.key"
                                    :prop="item.key"
                                    :fixed="item.fixed ? true : false"
                                    :label="item.label"
                                    label-class-name="headerClass"
                                    :render-header="renderHeader"
                                    :sortable="item.sortable"
                                    :sort-method="(a,b) => sortMethod(a,b,item.key,item.compareYestKey)"	
                                    :width="item.width ? item.width : setColumnWidth(item.label)"
                                    :align="!item.align ? 'center' : item.align">
                                <template slot-scope="scope">
                                	<div v-if="scope.row.toast && item.toast" >
		                                <el-popover ref="toast" :content="scope.row.toast" placement="bottom-start" trigger="manual">
				                        	<span slot="reference" @click="toggleToast(scope.row,item)" :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
				                            	{{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand)}}
				                            </span>
			                            </el-popover>
                                	</div>
		                            <div v-else-if="item.isProgress" :class="scope.row[item.key] > 0 ? 'progressBox positive' : 'progressBox negative'">
			                            <el-progress
			                                :percentage="scope.row[item.key + 'Progress']"
			                                :color="scope.row[item.key] > 0 ? '#00C482' : '#F74627'"
			                                :stroke-width="21"
			                                :show-text="false"
			                            ></el-progress>
			                            <p :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
			                                {{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand)}}
			                            </p>
			                        </div>
                                	<div v-else>
	                        			<img v-if="item.rank && scope.row[item.key] <= 3" style="width:0.16rem; height:0.16rem;" :src="getSortIcon(scope.row[item.key])" >    
		                                <span v-else @click="xiazuan(scope.row, item,scope.$index)" :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
		                                    {{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand)}}
		                                </span>
                                	</div>
                                </template>
                            </el-table-column>
                        </el-table>
                    </div>
                </div>
</div>`
});
