Vue.component('drillDownBox', {
    data() {
        return {
            style1: {
                color: '#3377FF'
            },
            style2: {
                color: '#333333'
            },
            upColor: '#FA2525', // 上升颜色
            downColor: '#009900' // 下降颜色
        }
    },
    props: {
        tablecolumn: {
            Array,
            default: () => {
                return [{
                    label: '封发量',
                    key: 'value',
                    sortable: true,
                    isDrillDown: true,
                    width: 90,
                }]
            }
        },
        title: {
            String,
            default: '省份'
        },
        tableHeight: {
        	Number,
        	default: null
        },
        list: {
            Array,
            default: () => {
                return [{
                    name: '北京市',
                    value: '36',
                    zrtb: 0
                }]
            }
        },
        isDrillDown: {
            Boolean,
            default: true
        },
        isNo: {
            Boolean,
            default: true
        },
        ifSetting: {
        	Boolean,
        	default: false
        },
        ifSettingKnown: {
        	String,
        	default: ''
        },
        notReverse: {
            Boolean,
            default: true
        },
        defaultSort: {
            Object,
            default: () => {
                return {
                    prop: 'areaCode',
                    order: 'ascending'
                }
            }
        },
        echartName: {
            String,
            default: ''
        },
        valueName: {
        	String,
        	default: ''
        },
        isShowLine: {
            Boolean,
            default: false
        },
        valueMax: {
            String,
            default: null
        },
        specialName: {
            Array,
            default: () => {
                return ['总计','其他']
            }
        },
        divideCode: {
            String,
            default: null
        }
    },
    computed: {
        x_data() {
            const newList = this.list.sort((i, n) => {
                return Number(i.nameCode) - Number(n.nameCode)
            });
            const arr = this.list.filter(e => e.name !== '总计')
            return arr.map(i => i.name);
        },
        value_data() {
            const newList = this.list.sort((i, n) => {
                return Number(i.nameCode) - Number(n.nameCode)
            });
            const arr = this.list.filter(e => e.name !== '总计')
            return arr.map(i => i.value);
        }
    },
    methods: {
        getColor(val) {
            if (val === '-' || parseFloat(val) == 0) return '';
            if (this.notReverse) {
                if (parseFloat(val) < 0) return this.downColor;
                if (parseFloat(val) > 0) return this.upColor;
            } else {
                if (parseFloat(val) < 0) return this.upColor;
                if (parseFloat(val) > 0) return this.downColor;
            }
        },
        getValue(val,compareKey,isRate) {
        	let res;
            if (val === undefined || val === '' || val == null) {
            	res = '-'
            }else if(compareKey && compareKey < 0){
            	res = "-" + val;
            }else{
            	res = val;
            }
            
            if(isRate && res != '-'){
            	res = res + "%";
            }
            return res;
        },
        xiazuan(item, key) {
            if (key === 'name') {
                if (!this.isDrillDown || !this.filterDrillDown(item.areaCode, item.areaLevel)) return;
                this.$emit('drilldown', {
                    item: item,
                    key: key
                })
            } else {
                if (key.isDrillDown && item[key.key] != 0) {
                    this.$emit('drilldown', {
                        item: item,
                        key: key.key
                    })
                }
            }
        },
        sortMethod(a,b,key,compareKey){
        	let l = a[key];
        	let r = b[key];
        	if(l == undefined || l == null || l == ''){
        		l = -100000000;
        	}else{
            	if(a[compareKey] < 0){
            		l *= -1;
            	}
        	}
        	if(r == undefined || r == null || r == ''){
        		r = -100000000;
        	}else{
            	if(b[compareKey] < 0){
            		r *= -1;
            	}
        	}
        	return r - l;
        },
        setWidth() {
            const width = this.title.length > 2 ? 120 : 80;
            if (this.tablecolumn.length === 1) return null;
            else return width
        },
        setColumnWidth(text){
            if (this.tablecolumn.length < 3) return null;
    		if(!text){
    			return 106;
    		}
    		return 106;
//    		const len = text.length;
//    		if(len <= 2){
//    			return 80;
//    		}else{
//    			return 80 + 12 * (len - 2);
//    		}
        },
        // 对比昨天，获取颜色
        getColorByCompareYest(row, item) {
            // top5的数据显示红色
            if(row[item.key + 'IsTop5']) {
                return this.upColor;
            }
            // 检验昨日值字段
            if (!item.compareYestKey) {
            	return ''
            }
            if(row[item.compareYestKey] == 0){
            	return ''
            }
            if(this.notReverse){
            	return row[item.compareYestKey] > 0 ? this.upColor : this.downColor
            }else{
            	return row[item.compareYestKey] < 0 ? this.upColor : this.downColor
            }
        },
        getPaddingRight(scope, item) {
        	if(!item.width && item.align == 'right') {
        		let width = (scope.column.realWidth - scope.column.label.length * 12) / 2;
        		if(item.sortable){
        			width += 12;
        		}
            	return width + 'px';
        	} else {
        		if(item.sortable && item.align == 'right') {
        			return '24px';
        		}
        		return '0px';
        	}
        },
        // 表头换行
        renderHeader(h, { column, $index }) {
        	var lab = column.label;
        	if(lab.indexOf("|") < 0){
        		return h('span',{},lab)
        	}else{
        		var arr = lab.split('|')
        		const list = [];
        		arr.forEach(item => {
        			list.push(h('span', {}, item));
                    list.push(h('br'));
        		})
        		list.pop()
        		return h('span', {}, list)
        	}
        },
        //特殊名字过滤
        filterDrillDown(areaCode, areaLevel){
            if (areaCode !== this.divideCode && areaLevel < 4) return true;
            else return false
        },
        switchColumn(){
        	this.$emit('switchcolumn', {});
        },
        filterColumn(c){
        	return c.filter(function(item){
        		return item.chose == undefined || item.chose;
        	});
        },
        columnSetConfirm(){
        	Emp.execute("saveColumnSetKnow()");
        },
        // 改变表格排序
        changeTableSort({ column, prop, order }) {
            let orderGroup = [];
            const fieldName = prop;
            const sortingType = order;
            this.list.map(item => {
                orderGroup.push(item)
            })
            // 先进行地区排序
            if(this.defaultSort.prop == 'areaCode') {
                orderGroup = orderGroup.sort((a, b) => {
                    return a['areaCode'] - b['areaCode'];
                })
                this.$emit('sortList', orderGroup);
            } else {
            	this.list = orderGroup.sort((a, b) => {
            		let aVal = a[this.defaultSort.prop];
            		let bVal = b[this.defaultSort.prop];
            		if (this.defaultSort.order == 'descending') {
            			return aVal - bVal;
            		} else {
            			return bVal - aVal;
            		}
                })
            }
            if (sortingType == 'descending') {
                // 从大到小排序
                this.list = orderGroup.sort((a, b) => {
                    let aVal = a[fieldName]
                    let bVal = b[fieldName]
                    // 让不参与排序的所在行值最大
                    if (a.areaCode == this.divideCode) {
                        aVal = -2;
                    }
                    if (b.areaCode == this.divideCode) {
                        bVal = -2;
                    }
                    return aVal - bVal
                })
                this.$emit('sortList', this.list);
            } else if (sortingType == 'ascending') {
                // 从小到大排序
                this.list = orderGroup.sort((a, b) => {
                    let aVal = a[fieldName]
                    let bVal = b[fieldName]

                    // 让不参与排序的所在行值最小
                    if (a.areaCode == this.divideCode) {
                        aVal = 99999999;
                    }
                    if (b.areaCode == this.divideCode) {
                        bVal = 99999999;
                    }
                    return bVal - aVal;
                })
                this.$emit('sortList', this.list);
            } else {
            	this.$refs.tableOwe.clearSort();
            }
        },
    },
    mounted() {

    },
    template: `<div>
                <div style="box-sizing: border-box">
                    <div style="padding: 0 2px">
                        <el-table
                                ref="tableOwe"
                                :data="list"
                                stripe
                                :header-cell-style="{background:'#0199FF',color:'#FFF', height: '30px', 'text-align': 'center', fontSize: '12px', fontWeight: 'normal'}"
                                :row-style="{height:'30px',fontSize: '12px'}"
                                @sort-change="changeTableSort"
                                style="width: 100%"
                                :height="tableHeight"
                        >
                            <el-table-column
                                    v-if="isNo"
                                    type="index"
                                    label="序号"
                                    align="center"
                                    fixed
                                    width="50"
                            >
                            </el-table-column>
                            <el-table-column
                            		v-if="title"
                                    prop="areaCode"
                                    :label="title"
                                    :width="setWidth()"
                                    align="center">
                                <template slot-scope="scope">
                                    <span :style="[isDrillDown && filterDrillDown(scope.row.areaCode, scope.row.areaLevel) ? style1 : style2 ]"
                                          @click="xiazuan(scope.row, 'name')">{{scope.row.name}}</span>
                                </template>
                            </el-table-column>
                            <el-table-column
                                    v-for="item in filterColumn(tablecolumn)"
                                    :key="item.key"
                                    :prop="item.key"
                                    :label="item.label"
                                    label-class-name="headerClass"
                                    :render-header="renderHeader"
                                    :sortable="item.sortable"
                                    :sort-method="(a,b) => sortMethod(a,b,item.key,item.compareYestKey)"	
                                    :width="item.width ? item.width : setColumnWidth(item.label)"
                                    :align="!item.align ? 'center' : item.align">
                                <template slot-scope="scope">
	                                	<!--如果是率-->
	                                    <span v-if="!item.isDrillDown" :style="{color: getColorByCompareYest(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
	                                        {{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate)}}
	                                    </span>
	                                    <!--其他-->
	                                    <span v-else @click="xiazuan(scope.row, item)" :style="[item.isDrillDown && scope.row[item.key] != 0 ? style1 : style2 ]">
	                                        {{getValue(scope.row[item.key],scope.row[item.compareYestKey])}}
	                                    </span>
                                </template>
                            </el-table-column>
                            <el-table-column
                            	v-if="ifSetting"
	                            align="center"
	                            >
	                            <template slot="header" slot-scope="scope">
		                            <div v-if="ifSettingKnown" slot="reference" style="display: flex; justify-content: center;" @click="switchColumn(scope.$index, scope.row)">
		                            	<img src="../../image/icon_column_setting.png" alt="" style="width:10px; height:10px; margin-right:3px;">
		                            	<span>列表设置</span>
		                            </div>
	                            	<el-popconfirm v-else ref="explain" cancel-button-text="" confirm-button-text='知道了' hide-icon=true title="此处可对指标进行排序" @onConfirm="columnSetConfirm">
			                            <div slot="reference" style="display: flex; justify-content: center;" @click="switchColumn(scope.$index, scope.row)">
			                            	<img src="../../image/icon_column_setting.png" alt="" style="width:10px; height:10px; margin-right:3px;">
			                            	<span>列表设置</span>
			                            </div>
			                        </el-popconfirm>
	                            </template>
		                    </el-table-column>
                        </el-table>
                    </div>
                </div>
</div>`
});