// 欠费余额tab
var oweTheBalance = {
    props: ['isShow', 'type', 'month'],
    data() {
        return {
			// 当前页面地区
            areaCode: '',
            // 上一级页面地区
            beforeAreaCode: '',
            // 页面层级 1-全国 2-省 3-地市 4-区县
            level: 1,
            maxLevel: 3,
            // 无数据
            noData:false,
            // -------表格相关
            tableHeight: null,
            // 第一列名称
            title: '省份',
            // 表头
            tableColumn: [
                {
                    label: '欠费余额(万元)',
                    key: 'arrearsBalance',
                    sortable: 'custom',
                    isDrillDown: false,
                    isNumber: true,
                    align: 'right'
                }
            ],
            // 表格数据
            tableData: [],
            // 缓存数据
            cacheData: {}
        }
    },
    template: `
    <div>
        <div v-if="!noData">
            <div class="chart marginTop8" ref="bar"></div>
            <drill-down-box 
                id="oweTable0"
                ref="echarts"
                :tableHeight="tableHeight"
                :is-no="false"
                :list="tableData"
                :title="title" 
                :is-drill-down="isDrillDown" 
                :tablecolumn="tableColumn"
                :divideCode="areaCode"
                @sortList="sortTableData"
                @drilldown="drillDown" />
        </div>

        <div class="noData" v-if="noData">
            <img src="../../image/nodata.png" alt="暂无数据" />
            <h3>暂无数据</h3>
        </div>
    </div>
    `,
    watch: {
        // 监控是否显示
        isShow: function (val, oldVal) {
            if (val && this.month && this.tableData.length == 0) {
                this.title = getNameFromPermission(this.level, false);
                this.getData();
                this.handleScroll();
            }
        },
        month: function(val, oldVal) {
        	if (val && this.isShow) {
                this.getData();
                this.handleScroll();
            }
        },
        level: function(val) {
            this.title = getNameFromPermission(val, false);
        }
    },
    computed: {
        isDrillDown: function(){
            return Number(this.level) < Number(this.maxLevel);
        }
    },
    methods: {
        handleScroll() {
            let dom = document.getElementsByClassName('tabContent')[0];
            let tabsHeight = document.getElementsByClassName('tabs')[0].clientHeight;
            let topHeight = document.getElementById('oweTable0').getBoundingClientRect().top - tabsHeight;
            let windowHeight = (document.documentElement.clientHeight || document.body.clientHeight) - tabsHeight;
            // 滚动监控
            dom.addEventListener('scroll', () => {
                let scrollTop = dom.scrollTop;
                if (Math.floor(scrollTop) >= Math.floor(topHeight)) {
                    dom.scrollTop = topHeight;
                    this.tableHeight = windowHeight;
                } else if (Math.floor(scrollTop) < Math.floor(topHeight)) {
                    this.tableHeight = null;
                }
            })
        },
        // 获取数据
    	getData: function() {
            let params = {
                statMonth: this.month,
                productType: this.type,
                areaLevel: String(this.level),
                areaCode: this.areaCode
            };
            queryArrearsBalance(params).then(({data}) => {
                if(!data || data == '[]' ) {
                    this.noData = true;
                    return;
                }
                this.noData = false;
                
                data = JSON.parse(data);
                // 数据排序
                data = data.sort((a, b) => {
                    return a['areaCode'] - b['areaCode'];
                })
                let sortData = [];
                data.forEach((item, index) => {
                    item.arrearsBalance = item.arrearsBalance === null ? '' : Math.round(item.arrearsBalance / 10000);
                    
                    if (index > 0 && item.arrearsBalance !== '') {
                        sortData.push(item.arrearsBalance);
                    }
                })
                sortData = sortData.length > 5 ? sortData.sort((a,b) => b-a).slice(0,5) : sortData;

                // 整理数据
                let tableData = [];
                data.forEach((item,index) => {
                    item.areaName = item.areaSname ? item.areaSname : (item.areaName ? item.areaName : '其他');
                    item.name = item.areaName;
                    item.value = item.areaName;

                    if(index > 0) {
                        let isTop5  = sortData.indexOf(item.arrearsBalance);
                        if (isTop5 > -1) {
                            item.arrearsBalanceIsTop5 = true;
                            sortData.splice(isTop5, 1);
                        } else {
                            item.arrearsBalanceIsTop5 = false;
                        }
                    }
                    
                    if(index == 0) {
                        this.areaCode = this.areaCode ? this.areaCode : item.areaCode;
                        this.beforeAreaCode = item.pAreaCode ? item.pAreaCode : '100000';
                    }
                    tableData.push(item);
                });

                // 柱状图排序
                let xValue = [];
                let yValue = [];
                let filterData = data.filter(item => {
                    if(item.areaCode != this.areaCode || data.length == 1) {
                        return item;
                    }
                });
                filterData = filterData.sort((a, b) => {
                    let aVal = a['arrearsBalance'];
                    let bVal = b['arrearsBalance'];
                    return bVal - aVal;
                })
                xValue = this.getMappingValueArrayOfKey(filterData, 'areaName');
                yValue = this.getMappingValueArrayOfKey(filterData, 'arrearsBalance');

                this.renderPage(tableData, xValue, yValue);
                // 存储数据
                if(Object.keys(this.cacheData).length > 10) {
                    this.cacheData.shift();
                }
                this.cacheData[this.areaCode] = {
                    "beforeAreaCode": this.beforeAreaCode,
                    "tableData": tableData,
                    "xValue": xValue,
                    "yValue": yValue
                }
            }).catch(err => {
                this.noData = true;
            })
        },
        // 渲染页面
        renderPage(tableData, xValue, yValue) {
            // 表格
            this.tableData = tableData;
            this.$refs.echarts.$refs.tableOwe.clearSort();

            // 柱状图
            let json = {
                name: "欠费余额",
                yName: "金额(万元）",
                xValue: xValue,
                yValue: yValue
            }
            
            this.$nextTick(() => {this.getBarChart('bar', json)});
        },
        // 下钻接口
        drillDown: function (data){
            const item = data.item;
            this.areaCode = item.areaCode;
            this.level = this.level + 1;
            const cacheData = this.cacheData[item.areaCode];
            // 获取数据，重新渲染页面
            if(cacheData) {
                this.beforeAreaCode = cacheData.beforeAreaCode;
                this.renderPage(cacheData.tableData, cacheData.xValue, cacheData.yValue);
            } else {
                this.getData();
            }
        },
        // 返回上一级
        upLevel() {
            if (this.level == 1) {
                Emp.execute("goBack()");
            } else {
                this.level = this.level - 1;
                this.areaCode = this.beforeAreaCode;
                const cacheData = this.cacheData[this.areaCode];
                // 获取数据，重新渲染页面
                if(cacheData) {
                    this.beforeAreaCode = cacheData.beforeAreaCode;
                    this.renderPage(cacheData.tableData, cacheData.xValue, cacheData.yValue);
                } else {
                    this.getData();
                }
            }
        },
        // 柱状图
        getBarChart: function (refs, json) {
            let myChart = echarts.init(this.$refs[refs]);
            let option = barOption(['#0197FF'], json);
            myChart.setOption(option, true);
            myChart.on('legendselectchanged', function (params) {
                let option = this.getOption();
                if (!params.selected[params.name]) {
                    // false 的时候
                    let isTure = [];
                    for(var item in params.selected){
                        if (params.selected[item]) {
                            isTure.push(item)
                        };
                    }
                    if (isTure.length > 0) {
                        option.legend[0].selected[params.name] = false;
                    } else {
                        option.legend[0].selected[params.name] = true;
                    }
                } else {
                    // true 的时候
                    option.legend[0].selected[params.name] = true;
                }
                this.setOption(option)
            });
        },
        // 表格数据排序
        sortTableData(data) {
            this.tableData = data;
        },
        getMappingValueArrayOfKey(array,keyName) {
            if(Object.prototype.toString.call(array)=='[object Array]'){
                return array.map(item => {
                    return item[keyName]
                })
            }
            return '';
        }
    }
};