/**
 * yy
 * color: 柱子颜色渐变数组，当前支持2个颜色渐变
 * radius: 柱子末端是否圆角
 */
var horizontalBar = {
    data() {
        return {
        }
    },
    props: {
        specialName: {
            Array,
            default: () => {
                return []
            }
        },
        echartName: '',
        valueName:{
	        Array,
	        default: () => {
	            return ['','']
	        }
	    },
    	boxHeight: {
            String,
            default: '200px',
        },
        color: {
        	Array,
        	default: ['#0199FF','#0199FF'],
        },
        radius: {
	        Boolean,
	        default: () => {
	            return false;
	        }
	    },
        tooltip: {
	        Boolean,
	        default: () => {
	            return true;
	        }
	    },
    },
    computed: {
    },
    methods: {
    	initEcharts(list) {
            document.documentElement.scrollIntoView();
            const arr = list.filter(e => this.specialName.indexOf(e.name) < 0)
            const xData = arr.map(i => i.name);
            const yData = arr.map(i => i.value);
            this.initBar(xData, yData);
        },
        initBar(xData, yData) {
            const _this = this
            let myChart = echarts.init(this.$refs.chart);
            let option = {
                color: ['#0199FF'],
                tooltip: {
                	show: _this.tooltip,
                	trigger: 'axis',
                    axisPointer: { // 坐标轴指示器，坐标轴触发有效
                        type: 'line' // 默认为直线，可选为：'line' | 'shadow'
                    },
                    textStyle: {
                    	fontSize: 13,
                    },
                    formatter:function(param){
                    	let arr = param.filter(e => e.value || e.value == 0);
                    	if(!arr || arr.length <= 0){
                    		 return '';
                    	}
                    	let col = 'linear-gradient(90deg, '+_this.color[0]+' 0%, '+_this.color[1]+' 100%)';
                    	let dotHtml = '<span style="display:inline-block;margin-right:5px;border-radius:10px;width:10px;height:10px;background:'+col+'"></span>';
                    	let x = _this.echartName;
                    	arr.forEach((e,i) => {
                    		x += '<br/>' + dotHtml + e.name + ' : ' + e.value;
                    	});
                    	return x;
                    },
                },
                grid: {
                    top: '1%',
                    left: '1%',
                    right: '8%',
                    bottom: '1%',
                    containLabel: true
                },
                yAxis: [{
                    type: 'category',
                    data: xData,
                    axisLine: {
                        lineStyle: {
                            color: '#E4E4E4'
                        }
                    },
                    splitLine: {
                        show: false
                    },
                    axisTick: {
                        show: false
                    },
                    splitArea: {
                        show: false
                    },
                    axisLabel: {
                        interval: 0,
                        fontSize: 10,
                        color: '#666666',
                        formatter: (val) => {
                            if (val.length > 8) return val.substring(0, 8) + '...'
                            else return val
                        }
                    }
                }],
                xAxis: [{
                    type: 'value',
                    name: _this.valueName[0],
                    nameLocation: 'start',
                    nameTextStyle: {
                    	color: '#666666',
                    	fontSize: 10,
                    	padding: [25, 0, 0, 0],
                    },
                    axisLine: {
                        show: false
                    },
                    axisTick: {
                        show: false
                    },
                    axisLabel: {
                        formatter: (val) => {
                            if (Number(val) >= 10000) return (Number(val) / 10000).toFixed(1) + '万'
                            else return val
                        }

                    }
                }],
                series: [{
                    type: 'bar',
                    barWidth: 12,
                    barGap: 24,
                    color: {
                        type: 'linear', // 线性渐变
                        x: 0,
                        y: 0,
                        x2: 1,
                        y2: 0,
                        colorStops: [{
                            offset: 0,
                            color: _this.color[0],
                        }, {
                            offset: 1,
                            color: _this.color[1],
                        }]
                    },
                    itemStyle: {
                        barBorderRadius: _this.radius ? [0,5,5,0] : [0,0,0,0],
                    },
                    data: yData,
                    label: {
                        normal: {
                            show: true,
                            position: 'right',
                            fontSize: 10,
                            color: '#999999',
                        }
                    },
                }],
            }
            myChart.setOption(option, true);
        },
    },
    mounted() {
    },
    template: `<div style="padding: 10px 5px; position: relative">
					<div ref="chart" :style="{'width': '100%', 'height': boxHeight}"></div>
	           </div>`
};