var scat = {
	props: ['show','month','monthType','productType','productName','areaCode','areaName'],
	components: {
	},
	data(){
		return {
		   	noData:false,
		   	list: [],
		   	data: {},
		   	minX: 0,
		   	maxX: 0,
		   	minY: 0,
		   	maxY: 0,
		};
	},
    computed: {
    	boxHeight: function(){
			let w = document.documentElement.clientWidth || document.body.clientWidth;
			let h = document.documentElement.clientHeight || document.body.clientHeight;
			h -= (w*100) / 375 * 0.85;
			return h + 'px';
//			return w + 'px';
    	},
    },
	watch: {
		show: function(val){
			if(this.show && this.month && (this.noData || this.list.length == 0)){
				this.initData();
			}
		},
		month: function(val,oldVal){
			if(!this.show){
				this.list = [];
				this.noData = true;
				return;
			}
			this.initData();
		},
		areaCode: function(val,oldVal){
			if(!this.show){
				this.list = [];
				this.noData = true;
				return;
			}
			this.initData();
		},
	},
	methods: {
        echartClick: function(arg){
        	if(!this.data[arg] || !this.data[arg].num){
        		return;
        	}
        	let url = '/fiveSystemKanban/technologyPower/scatter/scatterDetail.html';
			let p = {
				month: this.month,
				monthType: this.monthType,
				lineName: this.data[arg].name,
				lineCode: this.data[arg].code,
				productType: this.productType,
				productName: this.productName,
				areaCode: this.areaCode,
				areaName: this.areaName,
			};
         	Emp.execute("$M.page.goTo('"+url+"','"+JSON.stringify(p)+"', false)");
		},
    	initData: function(){
			let lv = getLevelFromPermission(1);
			let co = getAccountCode();
			if(lv > 2){
				this.noData = true;
				return;
			}
			
			if(!this.areaCode){
				return;
			}
    		
    		let params = {
    			dataDate: this.month.replace('-',''),
    			dateType: this.getMT(),
    			businessType: this.productType,
    			distCode: this.areaCode == '100000' ? '' : this.areaCode,
    		};
    		requestScatterData(params).then(({data}) => {
    			if(!data){
    				this.noData = true;
    				return;
    			}
    			let isNoData = true;
    			data = JSON.parse(data);
    			let json = {};
    			let list = [];
				let minX = -0.1;
				let maxX = 0.1;
				let minY = 0;
				let maxY = 0;
    			data.forEach(e => {
    				if(e.num && isNoData){
    					isNoData = false;
    				}
    				json[e.lineTypeCode] = {
    					code: e.lineTypeCode,
    					name: this.convertToName(e.lineTypeName),
    					num: this.convertToSafe(e.num),
    					rate: this.convertToRate(e.rate),
    				};
    				if(e.data){
    					e.data.forEach(it => {
//    						if(it[0] == 0 && it[1] == 0){
//    							alert(JSON.stringify(e))
//    						}
//    						minX = minX < it[0] ? minX : it[0];
//    						maxX = maxX > it[0] ? maxX : it[0];
    						it[0] = it[0] > maxX ? maxX : it[0];
    						it[0] = it[0] < minX ? minX : it[0];
    						minY = minY < it[1] ? minY : it[1];
    						maxY = maxY > it[1] ? maxY : it[1];
    						list.push(it);
    					});
    				}
    			});
    			
				if((minX + maxX) > 0){
					minX = maxX * -1;
				}else{
					maxX = minX * -1;
				}
				if((minY + maxY) > 0){
					minY = maxY * -1;
				}else{
					maxY = minY * -1;
				}
				
				this.minX = minX;
				this.maxX = maxX;
				this.minY = minY;
				this.maxY = maxY;
				
    			this.data = json;
    			this.list = list;
    			this.$nextTick(() => {
    				this.$refs.refScatter.init(list);
	            });
    			
    			this.noData = isNoData;
            }).catch(err => {
            	this.noData = true;
				console.log(err);
            });
    	},
    	getMT(){
    		if(this.monthType === 'day') return 'D';
    		if(this.monthType === 'month') return 'M';
    		if(this.monthType === 'week') return 'W';
    		if(this.monthType === 'sevenDay') return 'W';
    		return this.monthType;
	    },
	    isCen(areaCode){
        	let code = areaCode.slice(0,2);
        	return code == '11' || code == '12' || code == '31' || code == '50';
        },
	    notEmpty(arg){
        	if(arg === undefined || arg === '' || arg == null){
        		return false;
        	}else{
        		return true;
        	}
        },
        convertToName(arg){
        	return this.notEmpty(arg) ? arg : '其他';
        },
        convertToSafe(arg){
        	return this.notEmpty(arg) ? arg : '-';
        },
        convertToRate(arg){
        	return this.notEmpty(arg) ? (arg).toFixed(1) : '-';
        },
        convertToW(arg){
        	return this.notEmpty(arg) ? Math.round(arg / 10000) : '-';
        },
	},
	created() {
	},
	mounted() {
		if(this.show && this.month){
			this.initData();
		}
	},
    template: `
    	<div>
			<div v-show="!noData" style="background:#FFF;">
				<div style="position: relative;">
					<scatter-box
						ref="refScatter"
						:box-height="boxHeight"
						:minx="minX"
						:maxx="maxX"
						:miny="minY"
						:maxy="maxY"
						:reversey="productType == 'K'"
						>
					</scatter-box>	
					<div v-if="data['2']" class="lineType leftTop" @click="echartClick('2')">
						<p class="name">{{data['2'].name}}</p>
						<p class="value">{{data['2'].num}}条 {{data['2'].rate}}%</p>
					</div>
					<div v-if="data['1']" class="lineType rightTop" @click="echartClick('1')">
						<p class="name">{{data['1'].name}}</p>
						<p class="value">{{data['1'].num}}条 {{data['1'].rate}}%</p>
					</div>
					<div v-if="data['3']" class="lineType leftBottom" @click="echartClick('3')">
						<p class="name">{{data['3'].name}}</p>
						<p class="value">{{data['3'].num}}条 {{data['3'].rate}}%</p>
					</div>
					<div v-if="data['4']" class="lineType rightBottom" @click="echartClick('4')">
						<p class="name">{{data['4'].name}}</p>
						<p class="value">{{data['4'].num}}条 {{data['4'].rate}}%</p>
					</div>
					
					<div class="lineName lineTopName">
						<span class="lineNameNormal">线路平均时限<span>
						<span class="lineNameGreen">快于<span>
						<span class="lineNameNormal">竞品(天)<span>
					</div>
					<div class="lineName lineBottomName">
						<span class="lineNameNormal">线路平均时限<span>
						<span class="lineNameRed">慢于<span>
						<span class="lineNameNormal">竞品(天)<span>
					</div>
					<div class="lineName lineLeftName">
						<span class="lineNameNormal">线 \n 路 \n 业 \n 务 \n 量 \n 占 \n 比 \n <span>
						<span class="lineNameRed">低 \n 于 \n <span>
						<span class="lineNameNormal">竞 \n 品 \n (%)<span>
					</div>
					<div class="lineName lineRightName">
						<span class="lineNameNormal">线 \n 路 \n 业 \n 务 \n 量 \n 占 \n 比 \n <span>
						<span class="lineNameGreen">高 \n 于 \n <span>
						<span class="lineNameNormal">竞 \n 品 \n (%)<span>
					</div>
				</div>
			</div>
			<div v-if="noData" class="noData" v-if="noData">
				<img src="../../image/nodata.png" alt="暂无数据"/>
				<h3>暂无数据</h3>
			</div>
    	</div>
    `,
};