// 单柱状图
// color = ['#0197FF'],
// json = {
//  name: "直接访问",
//  yName: "金额(万元）",
//  isDataZoom: true,
//  xValue: ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun'],
//  yValue: [10, 52, 200, 334, 390, 330, 220]
// }
function barOption(color, json){
    json['legend'] = [json.name];
    json['series'] = [
        {
            name: json.name,
            type: 'bar',
            barWidth: 30,
            barCategoryGap: 8,
            label: {
                show: true,
                position: 'insideTop',
                fontSize: 10
            },
            data: json.yValue
        }
    ];
    return getBarOption(color, json);
}

// 堆叠柱状图
// let json = {
//     name: "期外费用",
//     xValue: ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun'],
//     yName: "占比(%）",
//     stack: "占比",
//     isDataZoom: false,
//     yValue: [
//         {
//             name: "账期外占比",
//             value: [10, 52, 200, 334, 390, 330, 220]
//         },
//         {
//             name: "账期内占比",
//             value: [10, 52, 200, 334, 390, 330, 220]
//         }
//     ]
// }

function stackBarOption(color, json) {
    let stackBarLegend = [];
    let stackBarSeries = [];
    json['yValue'].forEach(function(item, i) {
        stackBarLegend.push(item.name);
        stackBarSeries.push({
            name: item.name,
            type: 'bar',
            stack: json.stack,
            barWidth: 30,
            barCategoryGap: 8,
            label: {
                show: true,
                position: 'insideTop',
                fontSize: 10
            },
            data: item.value
        });
    })
    json['legend'] = stackBarLegend;
    json['series'] = stackBarSeries;
    return getBarOption(color, json);
}

// 公共barOption
// color = ['#0197FF'],
// json = {
//  name: "直接访问",
//  yName: "金额(万元）",
//  isDataZoom: true,
//  xValue: ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun'],
//  yValue: [10, 52, 200, 334, 390, 330, 220],
//  legend: ['直接访问'],
//  series: {
//         name: json.name,
//         type: 'bar',
//         barWidth: 40,
//         label: {
//             show: true,
//             position: 'inside',
//             fontSize: 10
//         },
//         data: json.yValue
//     }
// }
function getBarOption(color, json) {
    return {
        color: color,
        tooltip: {
        	confine:true,
            trigger: 'axis',
            axisPointer: {            // 坐标轴指示器，坐标轴触发有效
                type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
            }
        },
        legend: {
            top: 10,
            right: 5,
            data: json.legend
        },
        grid: {
            top: 45,
            left: 16,
            right: 16,
            containLabel: true
        },
        xAxis: {
            type: 'category',
            axisLabel: {
                color: '#666666',
                interval: 0,
                rotate: 45,
                formatter: function (value, index) {
                    return value.length > 4 ? value.substring(0, 3) + '...' : value;
                }
            },
            axisLine: {
                lineStyle: {color: "#979797"}
            },
            axisTick: {
                show: false
            },
            data: json.xValue
        },
        yAxis: {
            type: 'value',
            name: json.yName,
            nameTextStyle: {
                color: "#666666",
                fontSize: 12
            },
            axisLine: {
                show: false
            },
            axisTick: {
                show: false
            },
            axisLabel: {
                color: '#333333'
            },
        },
        dataZoom: [{
            show: true,
            xAxisIndex: [0],
            height: 30,
            bottom: 10,
            startValue: 0,
            endValue: json.xValue.length > 6 ? 6 : json.xValue.length - 1,
            maxValueSpan: 6,
            mixValueSpan: 6,
            handleIcon: 'path://M306.1,413c0,2.2-1.8,4-4,4h-59.8c-2.2,0-4-1.8-4-4V200.8c0-2.2,1.8-4,4-4h59.8c2.2,0,4,1.8,4,4V413z',
            handleSize: '110%',
            handleStyle: {color: "#d3dee5"},
            textStyle: {color: "#0199FF"},
            borderColor: "#90979c"
        }, {
            "type": "inside"
        }],
        series: json.series
    }
}
// 平均值柱状图
// let json = {
//     title: '全国',
//     legendData: [
//     {
//         name: '平均值'
//     }, {
//         name: '实际值',
//         icon: 'image://data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAFAAAAAoAQMAAABTru9CAAAABlBMVEUAxIL3RidNALHZAAAAE0lEQVQY02NgAIH/IMAwyhw6TABNs8c5rOzZTgAAAABJRU5ErkJggg=='
//     }],
//     yName: '及时率(%)',
//     average: 50,
//     xValue: ['北京', '天津', '河北', '河南', '黑龙江', '辽宁'],
//     barName: '实际值',
//     barValue: [20, 30, 50, 60, 80, 70],
//     lineName: '平均值',
//     lineValue: [50, 50, 50, 50, 50, 50]

// };
function averageBarOption(json) {
    return {
        tooltip: {
        	confine:true,
            trigger: 'axis',
            axisPointer: {            // 坐标轴指示器，坐标轴触发有效
                type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
            }
        },
        title:{
            text: json.title,
            padding: [15, 0, 0, 10],
            textStyle: {
                color: '#333333',
                fontSize: json.titleTextSize,
                fontWeight: 'bold'
            }
        },
        legend: {
            top: 10,
            right: 5,
            data: json.legendData
        },
        grid: {
            top: json.title ? 65 : 45,
            left: 16,
            right: 16,
            containLabel: true
        },
        xAxis: {
            type: 'category',
            axisLabel: {
                color: '#666666',
                interval: 0,
                rotate: 45,
                formatter: function (value, index) {
                    return value.length > 4 ? value.substring(0, 3) + '...' : value;
                }
            },
            axisLine: {
                lineStyle: {color: "#979797"}
            },
            axisTick: {
                show: false
            },
            data: json.xValue
        },
        yAxis: {
            type: 'value',
            name: json.yName,
           
            nameTextStyle: {
                color: "#666666",
                fontSize: 12,
                padding:json.barValue.length == 0 ? [0,0,0,85] : [0,0,0,25],
            },
            axisLine: {
                show: false
            },
            axisTick: {
                show: false
            },
            axisLabel: {
                color: '#333333'
            },
        },
        dataZoom: [{
            show: true,
            xAxisIndex: [0],
            height: 30,
            bottom: 10,
            startValue: 0,
            endValue: json.xValue.length > 6 ? 6 : json.xValue.length - 1,
            maxValueSpan: 6,
            mixValueSpan: 6,
            handleIcon: 'path://M306.1,413c0,2.2-1.8,4-4,4h-59.8c-2.2,0-4-1.8-4-4V200.8c0-2.2,1.8-4,4-4h59.8c2.2,0,4,1.8,4,4V413z',
            handleSize: '110%',
            handleStyle: {color: "#d3dee5"},
            textStyle: {color: "#0199FF"},
            borderColor: "#90979c",
            filterMode: json.filterMode ? json.filterMode : 'filter'
        }, {
            "type": "inside",
            filterMode: json.filterMode ? json.filterMode : 'filter'
        }],
        series: [
            {
                name: json.barName,
                type: 'bar',
                barWidth: 30,
                barCategoryGap: 8,
                label: {
                    show: true,
                    position: 'inside',
                    fontSize: 10
                },
                itemStyle: {
                    normal:{
                        color: function(params){
                            return Number(params.value) >= Number(json.average) ? '#00C482' : '#F74627';
                        }
                    }
                },
                data: json.barValue
            },
            {
                name: json.lineName,
                type: 'line',
                color: '#FA2525',
                data: json.lineValue
            }
        ]
    }
}
