/**
 * 市场体系-营销结果分析表格组件
 * @author baixueru
 * @desc 非本人不允许修改及复制
 * @time  2020-12-25
 */

// 全局注册表格组件
/**
 * isSettingKnown 是否显示提示弹窗
 * 表格列
 * tableColumnList: [
        {
            label: '日期',
            prop: 'date',
            fixed: true,
            align: 'left',
            sortable: true,
            isDrillDown: true
        },
        {
            label: '配送信息',
            children: [
                {
                    label: '姓名',
                    prop: 'name',
                    align: 'left'
                },
                {
                    label: '地址',
                    prop: 'address',
                    fixed: false,
                    align: 'left'
                },
            ]
        }
    ]
 * 表格数据 tableData
 * 是否显示列表排序 isSetting true false
 * 不可下钻行
 */

Vue.component('tableBox', {
    data() {
        return {
            isShow: true,
            isSettingKnown: false,
            callback: "switchColumnCallback" +  Math.round(Math.random() * 1000000)
        }
    },
    props: ['tableHeight', 'tableColumnList', 'tableData', 'isSetting', 'isSettingKey', 'divideCode', 'divideCodeLevel', 'isMaxLevel', 'providedDrillDown', 'mergeSpan'],
    template: `
    <div ref="tableBox" class="tableBox">
        <el-table
            v-if="isShow"
            stripe
            header-cell-class-name="blue-table-header"
            row-class-name="blue-table-row"
            ref="table"
            :height="tableHeight"
            :data="tableData"
            @sort-change="changeTableSort"
            :span-method="mergeSpanMethod"
        >
            <!-- 表格数据内容 -->
            <table-column 
                v-for="(item, index) in filterColumn(tableColumnList)"
                :key="item.id"
                :table-column-list="item"
                :divide-code="divideCode"
                :divide-code-level="divideCodeLevel"
                :is-max-level="isMaxLevel"
                :provided-drill-down="providedDrillDown"
            >
            </table-column>
            <!-- 表格列表设置 -->
            <el-table-column
                v-if="isSetting"
                align="center"
                :width="100"
                class-name="isSetting"
                :key="isSetting"
            >
                <template slot="header" slot-scope="scope">
                    <div 
                        v-if="isSettingKnown"
                        class="isSettingBox"
                        @click="switchColumn(scope.$index, scope.row)"
                    >
                        <img src="../../image/icon_column_setting.png" alt="" />
                        <span>列表设置</span>
                    </div>
                    <el-popconfirm 
                        v-else 
                        ref="explain" 
                        hide-icon=true
                        popper-class="tableExplain"
                        cancel-button-text="" 
                        title="此处可对指标进行排序"
                        confirm-button-text="知道了"
                        @onConfirm="setIsSettingKnown"
                    >
                        <div 
                            class="isSettingBox"
                            slot="reference"
                            @click="switchColumn(scope.$index, scope.row)"
                        >
                            <img src="../../image/icon_column_setting.png" alt=""  />
                            <span>列表设置</span>
                        </div>
                    </el-popconfirm>
                </template>
            </el-table-column>
        </el-table>
    </div>
    `,
    watch: {
        // 监控是否显示列表设置
    	isSetting: function (val) {
            if (val) {
                this.setField(this.tableColumnList);
                this.$emit('change-table-column', this.tableColumnList);
                // 获取本机缓存中 列表设置是否知道
                let key = this.isSettingKey ? this.isSettingKey : 'isSettingKnown';
                // 测试代码
                //localStorage.removeItem(key);
                this.isSettingKnown = localStorage.getItem(key);
                // 监听表格滑动，显示列表设置提示
                if(!this.isSettingKnown){
                    this.$nextTick(() => {
                        let dom = this.$refs.tableBox.getElementsByClassName("el-table__body-wrapper")[0];
                        dom.addEventListener('scroll', () => {
                            this.listenScroll(dom);
                        });
                    });
                }
            }
        },
        isShow: function (val) {
            if (val && this.isSetting) {
                if(this.tableColumnList[0].chose == undefined) {
                    this.setField(this.tableColumnList);
                    this.$emit('change-table-column', this.tableColumnList);
                }
                
                // 获取本机缓存中 列表设置是否知道
                let key = this.isSettingKey ? this.isSettingKey : 'isSettingKnown';
                // 测试代码
                //localStorage.removeItem(key);

                this.isSettingKnown = localStorage.getItem(key);
                // 监听表格滑动，显示列表设置提示
                if(!this.isSettingKnown){
                    this.$nextTick(() => {
                        let dom = this.$refs.tableBox.getElementsByClassName("el-table__body-wrapper")[0];
                        dom.addEventListener('scroll', () => {
                            this.listenScroll(dom);
                        });
                    });
                }
            }
        }
    },
    created(){
        window[this.callback] = (param) => {
            this.isShow = false;
            // 按地区排序
            if(this.divideCode) {
                let orderGroup = JSON.parse(JSON.stringify(this.tableData));
                // 参与排序的元素
                let divideGroup = orderGroup.filter(item => {
                    return (item.orgCode != this.divideCode || (item.orgCode == this.divideCode && this.divideCodeLevel && item.areaLevel !== this.divideCodeLevel))
                })


                // 不参与排序的元素
                let divideItem = orderGroup[0]
                orderGroup = divideGroup.sort((a, b) => {
                    return a['orgCode'] > b['orgCode'] ? 1 : -1;
                })
                orderGroup.unshift(divideItem)

                this.tableData = orderGroup;
                // 父级保存数据
                this.$emit('sort-list', orderGroup);
             }
            this.$nextTick(() => {
                let newList = JSON.parse(param);
                this.tableColumnList = newList;
                this.$emit('change-table-column', newList);
                this.isShow = true;
            });
        }
    },
    mounted() {
        // 设置表格列
        if(this.isSetting) {
            this.setField(this.tableColumnList);
            this.$emit('change-table-column', this.tableColumnList);
            // 获取本机缓存中 列表设置是否知道
            let key = this.isSettingKey ? this.isSettingKey : 'isSettingKnown';
            // 测试代码
            //localStorage.removeItem(key);
            this.isSettingKnown = localStorage.getItem(key);
            // 监听表格滑动，显示列表设置提示
            if(!this.isSettingKnown){
                this.$nextTick(() => {
                    let dom = this.$refs.tableBox.getElementsByClassName("el-table__body-wrapper")[0];
                    dom.addEventListener('scroll', () => {
                        this.listenScroll(dom);
                    });
                });
            }
        }
    },
    methods: {
        // 过滤表格列，表格列显隐
        filterColumn(c){
            if (!c) return;
        	let list = c.filter(function(item){
        		return item.chose == undefined || item.chose;
            });
            return list;
        },
        // 监听表格左右滑动，控制列表设置弹出框显隐
        listenScroll(dom) {
            if(dom.scrollWidth - dom.scrollLeft - dom.clientWidth <= 5){
                this.$refs.explain.visible = true;
            }else{
                this.$refs.explain.visible = false;
            }
        },
        // 表格列数据添加id和chose
    	setField(list, id, parentId){
    		let index = id ? id : 0;
    		list.forEach(e => {
                e.id = index;
                e.chose = true;
                if(parentId != null && parentId != undefined){
                    e.parentId = parentId;
                }
                if(e.children){
                    index = this.setField(e.children,index + 1,index);
                } else {
                    index++;
                }
    		});
    		return index;
    	},
        // 列表设置点击事件 跳转到列表设置页
        switchColumn() {
        	let arg = {
            	data : this.tableColumnList,
            	method : this.callback,
            };
        	
            Emp.execute("toSwitchColumn('" + JSON.stringify(arg) + "')");
        },
        // 设置本机缓存中 列表设置是否知道为true
        setIsSettingKnown() {
            this.isSettingKnown = true;
            let key = this.isSettingKey ? this.isSettingKey : 'isSettingKnown';
            localStorage.setItem(key, true);
            let dom = this.$refs.tableBox.getElementsByClassName("el-table__body-wrapper")[0];
            dom.removeEventListener('scroll', () => { this.listenScroll(dom);} );
        },
        // 改变表格排序
        changeTableSort({ column,  prop, order}) {
            if(column.sortable !== 'custom') {
                return;
            }
            let orderGroup = [];
            const fieldName = prop;
            const sortingType = order;
            orderGroup = JSON.parse(JSON.stringify(this.tableData));
            // 先进行地区排序
            if(this.divideCode) {
                // 参与排序的元素
                let divideGroup = orderGroup.filter(item => {
                    return (item.orgCode != this.divideCode || (item.orgCode == this.divideCode && this.divideCodeLevel && item.areaLevel !== this.divideCodeLevel))
                })
                // 不参与排序的元素
                let divideItem = orderGroup[0]
                orderGroup = divideGroup.sort((a, b) => {
                	let ran1=Number(a['ranking']);
                	let ran2=Number(b['ranking']);
                    return ran1 > ran2 ? 1 : -1;
                })
                orderGroup.unshift(divideItem)
                // 父级保存数据
                this.$emit('sort-list', orderGroup);
            }
            // 排序
            if (sortingType == 'descending') {
                // 从小到大排序
                this.tableData = orderGroup.sort((a, b) => {
                    let aVal = a[fieldName];
                    let bVal = b[fieldName];
                    // 让不参与排序的所在行值最小
                    if (a.orgCode == this.divideCode && !(this.divideCodeLevel && a.areaLevel !== this.divideCodeLevel)) {
                        aVal = -99999999;
                    }
                    if (b.orgCode == this.divideCode && !(this.divideCodeLevel && b.areaLevel !== this.divideCodeLevel)) {
                        bVal = -99999999;
                    }
                    if(aVal === undefined || aVal === null || aVal === ''){
                        aVal = -99999998.9;
                    }
                    if(bVal === undefined || bVal === null || bVal === ''){
                        bVal = -99999998.9;
                    }
              
                    return aVal - bVal;
                })
                // 父级保存数据
                this.$emit('sort-list', this.tableData);
            }  else if (sortingType == 'ascending') {
                // 从大到小排序
                this.tableData = orderGroup.sort((a, b) => {
                    let aVal = a[fieldName]
                    let bVal = b[fieldName]

                    // 让不参与排序的所在行值最大
                    if (a.orgCode == this.divideCode && !(this.divideCodeLevel && a.areaLevel !== this.divideCodeLevel)) {
                        aVal = 99999999;
                    }
                    if (b.orgCode == this.divideCode && !(this.divideCodeLevel && b.areaLevel !== this.divideCodeLevel)) {
                        bVal = 99999999;
                    }
                    if(aVal === undefined || aVal === null || aVal === ''){
                        aVal = -99999998.9;
                    }
                    if(bVal === undefined || bVal === null || bVal === ''){
                        bVal = -99999998.9;
                    }
                    return bVal - aVal;
                })
                // 父级保存数据
                this.$emit('sort-list', this.tableData);
            } else {
                this.tableData = orderGroup;
                this.$refs.table.clearSort();
            }
        },
        mergeSpanMethod({ row, column, rowIndex, columnIndex}) {
        	if(!this.mergeSpan){
        		return;
        	}
            if (rowIndex === 0) {
            	let index = 0;
            	let mergeKey;
            	this.tableColumnList.forEach((e,i) => {
            		if(e.mergeKey){
            			index = i;
            			mergeKey = e.mergeKey;
            		}
            	});
            	let left = index != 0 && this.tableColumnList[index - 1].prop === mergeKey;
            	if(!this.tableColumnList[index].chose || !this.tableColumnList[left ? index - 1 : index + 1].chose){
            		return;
            	}
                if (columnIndex === 0) {
                	return left ? [0, 0] : [1, 2];
                } else if (columnIndex === 1) {
                	return left ? [1, 2] : [0, 0];
                }
            }
        },
    }
});

// 全局注册表格列组件
/**
 * 递归表格列组件，实现多级表头展示
 * tableColumnList: [
        {
            label: '日期',
            prop: 'date',
            fixed: true,
            align: 'left',
            sortable: true,
            isDrillDown: true
        },
        {
            label: '配送信息',
            children: [
                {
                    label: '姓名',
                    prop: 'name',
                    align: 'left'
                },
                {
                    label: '地址',
                    prop: 'address',
                    fixed: false,
                    align: 'left'
                },
            ]
        }
    ]
 * 
 */
Vue.component('tableColumn', {
    data() {
        return {
			isDrillColor: '#3377FF',
            isNoDrillColor: '#333333',
        }
    },
    props: ['tableColumnList', 'divideCode', 'divideCodeLevel', 'isMaxLevel', 'providedDrillDown'],
    template: `
    <el-table-column
        :label="tableColumnList.label" 
        :prop="tableColumnList.prop ? tableColumnList.prop : null"
        :fixed="tableColumnList.fixed"
        :align="tableColumnList.align ? tableColumnList.align : 'center'"
        :sortable="tableColumnList.sortable"
        :sort-method="(a,b) => sortMethod(a,b,tableColumnList)"
        :render-header="renderHeader"
        label-class-name="headerClass"
        :width="tableColumnList.width ? tableColumnList.width : null"
    >
        <!-- 多级表头 -->
		<template v-if="tableColumnList.children">
            <table-column
                v-for="(item, index) in filterColumn(tableColumnList.children)"
			    :key="item.id"
                :table-column-list="item"
                :divide-code="divideCode"
                :divide-code-level="divideCodeLevel"
                :is-max-level="isMaxLevel"
                :provided-drill-down="providedDrillDown"
            >
            </table-column>
        </template>
        <!-- 行内显示内容 -->
        <template v-if="!tableColumnList.children" slot-scope="scope">
            <!-- 排行列 -->
            <span v-if="tableColumnList.isRanking">
                <img 
                    v-if="scope.row[tableColumnList.prop]&&scope.row[tableColumnList.prop] < 4" 
                    style="width:0.16rem; height:0.16rem;" 
                    :src="getSortIcon(scope.row[tableColumnList.prop])" 
                />
                <span v-else>{{scope.row[tableColumnList.prop]}}</span>
            </span>
            <!-- 下钻列 -->
            <span v-if="tableColumnList.isDrillDown" 
                :style="{
                    color: filterDrillDown(scope.row, tableColumnList) ? isDrillColor : isNoDrillColor,
                    paddingRight: getPaddingRight(scope.column, tableColumnList)
                }"
                :class="tableColumnList.isNumber ? 'tableBold' : '' "
                @click="drillDown(scope.row, tableColumnList)"
            >
                {{formatValue(scope.row[tableColumnList.prop])}}
            </span>
            <!-- 带有进度条列 -->
            <div 
                v-if="tableColumnList.isProgress" 
                :class="scope.row[tableColumnList.prop] > 0 ? 'progressBox positive' : 'progressBox negative'"
            >
                <el-progress 
                    :percentage="scope.row[tableColumnList.prop + 'Progress']"
                    :color="scope.row[tableColumnList.prop] > 0 ? '#00C482' : '#F74627'"
                    :stroke-width="23" 
                    :show-text="false"
                ></el-progress>

                <p :class="tableColumnList.isNumber ? 'tableBold' : '' ">
                    {{formatValue(scope.row[tableColumnList.prop])}}
                </p>
            </div>
            <!-- 带有颜色标识列 -->
            <span  v-if="!tableColumnList.isRanking && !tableColumnList.isDrillDown && !tableColumnList.isProgress" 
                :style="{
                    color: getValueColor(scope.row, tableColumnList),
                    paddingRight: getPaddingRight(scope.column, tableColumnList)
                }"
                :class="tableColumnList.isNumber ? 'tableBold' : '' "
            >
                {{formatValue(scope.row[tableColumnList.prop])}}
            </span>
        </template>
    </el-table-column>`,
    mounted() {
    },
    methods: {
        // 过滤表格列，表格列显隐
        filterColumn(c){
            if (!c) return;
        	let list = c.filter(function(item){
        		return item.chose == undefined || item.chose;
            });
            return list;
        },
        // 表头换行
        renderHeader(h, { column }) {
        	var lab = column.label;
        	if(lab.indexOf("|") < 0){
        		return h('span', {}, lab)
        	}else{
        		var arr = lab.split('|')
        		const list = [];
        		arr.forEach(item => {
        			list.push(h('span', {}, item));
                    list.push(h('br'));
        		})
        		list.pop()
        		return h('span', {}, list)
        	}
        },
        // 排行榜 前三图片
        getSortIcon(index,ii) {
            if(index == 1){
        		return '../../image/icon_sort_1.png';
        	}else if(index == 2){
        		return '../../image/icon_sort_2.png';
        	}else {
        		return '../../image/icon_sort_3.png';
        	}
        },
        // 数据右边padding
        getPaddingRight(column, item) {
            if(!item.width && item.align == 'right') {
        		let width = (column.realWidth - column.label.length * 12) / 2;
        		if(item.sortable){
        			width += 12;
        		}
            	return width + 'px';
        	} else {
        		if(item.sortable && item.align == 'right') {
        			return '24px';
        		}
        		return '0px';
        	}
        },
        // 格式数据
        formatValue(val) {
            if (val === undefined || val === '' || val == null) {
            	return '-';
            } else {
            	return val;
            }
        },
     // 数据颜色
        getValueColor(row, item) {
        	 if(item.subByTarget){
                 if(row[item.subByTarget] >= 0){
             		return item.textColorPerversion ? '#FA2525' : '#009900';
             	}else if(row[item.subByTarget] < 0){
             		return  item.textColorPerversion ? '#009900' : '#FA2525';
             	}
             }

            if (item.textColor) {
                if (!!isNaN(row[item.prop]) || row[item.prop] === '' || row[item.prop] === null) {
                    return '#333333';
                }
            	if(row[item.prop] >= 0){
            		return item.textColorPerversion ? '#FA2525' : '#009900';
            	}else if(row[item.prop] < 0){
            		return  item.textColorPerversion ? '#009900' : '#FA2525';
            	}
            }
            if(item.textColorDown && row[item.prop] < 0) {
                return  '#FA2525';
            }
            return '#333333';
        },
        
        //特殊名字过滤
        filterDrillDown(row, tableColumnList){
            let propArr = ['orgName', 'areaSname'];
            let nationalCodeArr = ['100000', '999999'];
            let prop = tableColumnList.prop;
            let isNumber = tableColumnList.isNumber;
            if(propArr.indexOf(prop) == -1) {
                if (row[prop] && row[prop] != '-' && (isNumber && row[prop] > 0) && (tableColumnList.isNationalNoDrillDown && nationalCodeArr.indexOf(row.orgCode) == -1)) {
                    return true;
                } else {
                    return false;
                }
            }
            if (propArr.indexOf(prop) > -1 && this.divideCode) {
                if (row.orgCode !== this.divideCode && !this.isMaxLevel && row.regionalLevel != '9') {
                    return true;
                } else if(row.orgCode == this.divideCode && this.divideCodeLevel && row.areaLevel !== this.divideCodeLevel) {
                    return true;
                } else {
                    return false;
                }
            }
        },
        // 下钻
        drillDown(row, tableColumnList) {
            if (!this.filterDrillDown(row, tableColumnList)) return;
            // 调用下钻方法
            this.providedDrillDown(row, tableColumnList.prop);
        },
        // 数据排序
        sortMethod(a, b, tableColumnList) {
            let l = a[tableColumnList.prop];
            let r = b[tableColumnList.prop];
        	if(l === undefined || l === null || l === ''){
        		l = -100000000;
        	}
        	if(r === undefined || r === null || r === ''){
        		r = -100000000;
            }
        	return r - l;
        }
    },
});