var secondaryPageTab = {
	props: ['isShow', 'id', 'pageTitle', 'dateType', 'countDate', 'businessTypes', 'importRcportType', 'areaCode', 'level'],
	data() {
		return {
			// echart相关
			yName: '准点率(%)',
			noData: false,
			// 下钻层级控制
			maxLevel: 3,
			isMaxLevel: false,
			// 表格相关
			tableHeight: null,
			// 数据
			isGetData: true,
			dataList: ''
		}
	},
	computed: {
		// 表格相关
		tableColumnList: function () {
			let tableColumnList = [];
			let pageTitle = this.pageTitle;
			switch(pageTitle) {
				case '邮车运行准点率':
					tableColumnList = [
						{
							label: '省份',
							prop: 'areaName',
							isDrillDown: true,
							width: 70
						},
						{
							label: '实际值|(%)',
							prop: 'timeLimit',
							sortable: 'custom',
							isNumber: true,
							align: 'right',
							width: 85
						},
						{
							label: '与目标值|差距(%)',
							prop: 'disTargetRate',
							sortable: 'custom',
							isProgress: true,
							isNumber: true,
							align: 'right'
						},
						{
							label: '与平均值|差距(%)',
							prop: 'disAverRate',
							sortable: 'custom',
							isProgress: true,
							isNumber: true,
							align: 'right'
						}
					];
					break;
				case '分拣准确率':
					tableColumnList = [
						{
							label: '省份',
							prop: 'areaName',
							isDrillDown: true,
							width: 70
						},
						{
							label: '实际值(%)',
							prop: 'timeLimit',
							sortable: 'custom',
							isNumber: true,
							align: 'right'
						},
						{
							label: '与平均值差距(%)',
							prop: 'disAverRate',
							sortable: 'custom',
							isProgress: true,
							isNumber: true,
							align: 'right'
						}
					];
					break;
				default:
					break;
			}
			return tableColumnList;
		}
	},
	template: `
		<secondary-page
			ref="page"
			:no-data="noData"
			:area-code="areaCode"
			:count-date="countDate"
			:is-max-level="isMaxLevel"
			:table-column-list="tableColumnList"
			:table-height="tableHeight"
			:y-name="yName"
			:data-list="dataList"
			@change-level="changeLevel"
			@change-area-code="changeAreaCode"
		>
		</secondary-page>
	`,
	watch: {
		// 监控是否显示
        isShow: function (val) {
			// 时间或地区更改
			if(val) {
				let areaLevel = getLevelFromPermission(this.level);
				let cacheData = this.$refs.page.cacheData[this.areaCode + this.countDate + areaLevel];
				if(cacheData) {
					this.dataList = cacheData.dataList;
					this.noData = false;
				} else {
					this.getData();
				}
			}
        },
		// 监控当时间变化时, 重新请求
		countDate: function(val) {
			if (val && this.isShow) {
				if(this.level == 1) {
					let userLevel = getAccountLevel();
					let userCode = getAccountCode();
					switch (userLevel) {
						case '01':
						case '02':
							this.maxLevel = 4;
							break;
						case '03':
							this.maxLevel = this.isCen(userCode) ? 2 : 3;
							break;
						case '04':
							this.maxLevel = this.isCen(userCode) ? 1 : 2;
							break;
						default:
							this.maxLevel = 1;
							break;
					}
					this.isMaxLevel = this.level == this.maxLevel ? true : false;
					this.tableColumnList[0].label = this.isMaxLevel ? '机构' : getNameFromPermission(this.level, false);
					this.$refs.page.$refs.tableBox.isShow = false;
					this.$nextTick(() => {
						this.$refs.page.$refs.tableBox.isShow = true;
					});
				}
				this.getData();
			}
		},
		level: function(val) {
			this.tableColumnList[0].label = this.isMaxLevel ? '机构' : getNameFromPermission(val, false);
			this.$refs.page.$refs.tableBox.isShow = false;
			this.$nextTick(() => {
				this.$refs.page.$refs.tableBox.isShow = true;
			});
		},
		areaCode: function(val) {
			let areaLevel = getLevelFromPermission(this.level);
			let cacheData = this.$refs.page.cacheData[this.areaCode + this.countDate + areaLevel];
			if (val && this.isShow) {
				if (cacheData) {
					this.noData = false;
					this.dataList = cacheData.dataList;
				} else {
					this.getData();
				}
			}
		}
	},
	mounted() {
		this.handleScroll();
		if(this.countDate && this.isShow) {
			let userLevel = getAccountLevel();
			let userCode = getAccountCode();
			switch (userLevel) {
				case '01':
				case '02':
					this.maxLevel = 4;
					break;
				case '03':
					this.maxLevel = this.isCen(userCode) ? 2 : 3;
					break;
				case '04':
					this.maxLevel = this.isCen(userCode) ? 1 : 2;
					break;
				default:
					this.maxLevel = 1;
					break;
			}
			this.isMaxLevel = this.level == this.maxLevel ? true : false;
			this.tableColumnList[0].label = this.isMaxLevel ? '机构' : getNameFromPermission(this.level, false);
			this.getData();
		}
	},
	methods: {
		// 监控页面滚动体
		handleScroll() {
			let dom = this.$parent.$refs.tabContent[this.id -1];
			let topHeight = document.getElementsByClassName('echart')[0].clientHeight;
			dom.addEventListener('scroll', () => {
				let scrollTop = dom.scrollTop;
				if (Math.floor(scrollTop) >= (Math.floor(topHeight) - 1)) {
                    dom.scrollTop = topHeight;
                    this.tableHeight = dom.clientHeight;
                } else if (Math.floor(scrollTop) < (Math.floor(topHeight)- 1)) {
                    this.tableHeight = null;
                }
			})
		},
		// 获取数据
		getData() {
			let countDate = this.dateType == 'W' ? this.countDate.split('-')[0] + this.countDate.split(' ')[1] : this.countDate;
			let params = {
				dateType: this.dateType,
				countDate: countDate,
				businessTypes: this.businessTypes,
				areaCode: this.areaCode,
				areaLevel: this.level
			}
			switch(this.pageTitle) {
				case '邮车运行准点率':
					punctualityDetail(params).then(({data}) => {
						this.setData(data);
					}).catch(err => {
						this.noData = true;
					})
					break;
				case '分拣准确率':
					params.importRcportType = this.importRcportType;
					selectDisplayBoardSortingAccuracyDetailByCode(params).then(({data}) => {
						this.setData(data);
					}).catch(err => {
						this.noData = true;
					})
					break;
				default:
					break;
			}
			
		},
		setData(data) {
			if(!data || data == '[]' ) {
				this.noData = true;
				this.dataList = '';
				return;
			}
			this.noData = false;
			this.dataList = data;
			this.areaCode = this.areaCode ? this.areaCode : JSON.parse(data)[0].areaCode;
			this.$emit("change-area", this.areaCode, this.level);
		},
		// 表格下钻
		changeLevel(row, isGetData) {
			this.areaCode = row.areaCode;
			this.level = this.level + 1;
			this.isGetData = isGetData;
			this.noData = isGetData == false ? false : this.noData;
			this.$emit("change-area", this.areaCode, this.level);
			if (this.isCen(row.areaCode) && getAccountLevel() < 3) {
				this.isMaxLevel = this.level == this.maxLevel - 1 ? true : false;
			} else {
				this.isMaxLevel = this.level == this.maxLevel ? true : false;
			}
		},
		// 页面返回上一层
		upLevel() {
			this.level = this.level - 1;
			this.isMaxLevel = false;
			this.$refs.page.upLevel();
		},
		// 返回上一层时更改areaCode
		changeAreaCode(areaCode, isGetData) {
			this.areaCode = areaCode;
			this.isGetData = isGetData;
			this.noData = isGetData == false ? false : this.noData;
			this.$emit("change-area", this.areaCode, this.level);
		},
		// 是否为直辖市
		isCen(areaCode){
			let code = areaCode.slice(0,2);
			return code == '11' || code == '12' || code == '31' || code == '50';
		}
	}

};