const ContainsBox = {
    props: {
        title: {
            type: String,
            default: '标题'
        },
        expendTitle: Object
    },
    computed: {
        flag(){
            return !this.expendTitle
        }
    },
    template: `<div class="contain_box">
                    <div style="border-radius: .8rem; overflow: hidden">
                        <div class="contain_title">
                            {{title}}
                        </div>
                        <div v-if="!flag" class="contain_expend">
                            <p>{{expendTitle.text}}：{{expendTitle.value}}</p>
                        </div>
                        <slot></slot>
                    </div>
                </div>`
};

const LineBox = {
    props: {
        type: {
            type: Number,
            default: 1
        }
    },
    methods: {
        initData(){
            switch (this.type) {
                case 1:
                    this.initEcharts(...arguments);
                    break;
                case 2:
                    this.initEcharts2(...arguments);
                    break;
                case 3:
                    this.initEcharts3(...arguments);
                    break;
            }
        },
        initEcharts(xData, data) {
            let mychart2 = echarts.init(this.$refs.chart1);
            if (!xData || xData.length === 0){
                mychart2.dispose();
                return;
            }
            let option2 = {
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    },
                    formatter: function(params) {//提示框自定义
                        return params[0].axisValueLabel + '<br>' + params[0].seriesName + ':  ' + params[0].value + '件' + '<br>' +
                            params[1].seriesName + ':  ' + params[1].value + '%'
                    }
                },
                legend: {
                    data: ['出库及时数', '出库及时率'],
                    bottom: 40,
                    itemGap: 10
                },
                grid: {
                    top: '13%',
                    left: '3%',
                    right: '4%',
                    bottom: '25%',
                    containLabel: true
                },
                xAxis: [
                    {
                        type: 'category',
                        data: xData,
                        'axisLine': {
                            lineStyle: {
                                color: '#90979c'
                            }
                        },
                        'splitLine': {
                            'show': false
                        },
                        'axisTick': {
                            'show': true
                        },
                        'splitArea': {
                            'show': false
                        },
                        'axisLabel': {
                            'interval': 0
                        }
                    }
                ],
                yAxis: [
                    {
                        type: 'value',
                        name: '及时数',
                        axisLine: { show: false },
                        'axisTick': {
                            'show': false
                        },

                        axisLabel: {
                            margin: 2,
                            formatter: function(value, index) {
                                if (value >= 10000 && value < 10000000) {
                                    value = value / 10000 + '万'
                                } else if (value >= 10000000) {
                                    value = value / 10000000 + '千万'
                                }
                                return value
                            }
                        }
                    },
                    {
                        type: 'value',
                        name: '及时率',
                        axisLine: { show: false },
                        'axisTick': {
                            'show': false
                        },
                        'splitLine': {
                            'show': false
                        },
                        min: 0,
                        max: 100,
                        axisLabel: {
                            margin: 2,
                            formatter: function(value, index) {
                                if (value >= 10000 && value < 10000000) {
                                    value = value / 10000 + '万'
                                } else if (value >= 10000000) {
                                    value = value / 10000000 + '千万'
                                }
                                return value + '%'
                            }
                        }
                    }
                ],
                'dataZoom': [{
                    'show': true,
                    'height': 20,
                    bottom: 10,
                    // "start": 0,
                    // "end": (7/this.ckjslX.length).toFixed(0) >= 1 ? 100 : 50,
                    startValue: 0,
                    endValue: 6,
                    maxValueSpan: 6,
                    mixValueSpan: 6,
                    handleStyle: {   //滚动条样式
                        color: '#d3dee5'
                    },
                    textStyle: {   //文本提示样式
                        color: '#1D95F4'
                    },
                    borderColor: '#90979c'
                }],
                series: [
                    {
                        name: '出库及时数',
                        type: 'line',
                        data: data[0],
                        symbolSize: 10,
                        symbol: 'circle',
                        'itemStyle': {
                            'normal': {
                                'color': '#1D95F4',
                                'barBorderRadius': 1,
                                borderColor: '#fff',
                                borderWidth: 2
                            }
                        },
                        lineStyle: {  //线条样式
                            normal: {
                                color: '#1D95F4',
                                width: 2
                            }
                        },
                        smooth: true
                    },
                    {
                        name: '出库及时率',
                        type: 'line',
                        data: data[1],
                        symbolSize: 10,
                        symbol: 'circle',
                        'itemStyle': {
                            'normal': {
                                'color': '#FF0050',
                                'barBorderRadius': 1,
                                borderColor: '#fff',
                                borderWidth: 2
                            }
                        },
                        yAxisIndex: 1,
                        lineStyle: {  //线条样式
                            normal: {
                                color: '#FF0050',
                                width: 2
                            }
                        },
                        smooth: true
                    }
                ]
            }
            mychart2.setOption(option2)
        },
        initEcharts2(data, name, xData, yName) {
            let mychart2 = echarts.init(this.$refs.chart1);
            if (!data || data.length === 0){
                mychart2.dispose();
                return;
            }
            let option2 = {
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    }
                },
                legend: {
                    data: [name],
                    bottom: 40,
                    itemGap: 10
                },
                grid: {
                    top: yName === '' ? '7%' : '13%',
                    left: '3%',
                    right: '4%',
                    bottom: '25%',
                    containLabel: true
                },
                xAxis: [
                    {
                        type: 'category',
                        data: xData,
                        'axisLine': {
                            lineStyle: {
                                color: '#90979c'
                            }
                        },
                        'splitLine': {
                            'show': false
                        },
                        'axisTick': {
                            'show': true
                        },
                        'splitArea': {
                            'show': false
                        },
                        'axisLabel': {
                            'interval': 0
                        }
                    }
                ],
                yAxis: [
                    {
                        type: 'value',
                        name: yName,
                        axisLine: { show: false },
                        'axisTick': {
                            'show': false
                        },
                        axisLabel: {
                            margin: 2,
                            formatter: function(value, index) {
                                if (value >= 10000 && value < 10000000) {
                                    value = value / 10000 + '万'
                                } else if (value >= 10000000) {
                                    value = value / 10000000 + '千万'
                                }
                                return value
                            }
                        }
                    }
                ],
                'dataZoom': [{
                    'show': true,
                    'height': 20,
                    bottom: 10,
                    startValue: 0,
                    endValue: 6,
                    maxValueSpan: 6,
                    mixValueSpan: 6,
                    handleStyle: {   //滚动条样式
                        color: '#d3dee5'
                    },
                    textStyle: {   //文本提示样式
                        color: '#1D95F4'
                    },
                    borderColor: '#90979c'
                }],
                series: [
                    {
                        name: name,
                        type: 'line',
                        data: data,
                        symbolSize: 10,
                        symbol: 'circle',
                        'itemStyle': {
                            'normal': {
                                'color': '#1D95F4',
                                'barBorderRadius': 1,
                                borderColor: '#fff',
                                borderWidth: 2
                            }
                        },
                        lineStyle: {  //线条样式
                            normal: {
                                color: '#1D95F4',
                                width: 2
                            }
                        },
                        smooth: true
                    }
                ]
            };
            mychart2.setOption(option2)
        },
        initEcharts3(xData, sr, cb, lr) {
            let mychart2 = echarts.init(this.$refs.chart1);
            if (!xData || xData.length === 0){
                mychart2.dispose();
                return;
            }
            let option2 = {
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    }
                },
                legend: {
                    data: ['收入', '成本', '利润'],
                    bottom: 40,
                    itemGap: 10
                },
                grid: {
                    top: '7%',
                    left: '3%',
                    right: '4%',
                    bottom: '25%',
                    containLabel: true
                },
                xAxis: [
                    {
                        type: 'category',
                        data: xData,
                        'axisLine': {
                            lineStyle: {
                                color: '#90979c'
                            }
                        },
                        'splitLine': {
                            'show': false
                        },
                        'axisTick': {
                            'show': true
                        },
                        'splitArea': {
                            'show': false
                        },
                        'axisLabel': {
                            'interval': 0,
                            rotate:40
                        }
                    }
                ],
                yAxis: [
                    {
                        type: 'value',
                        //name: '及时数',
                        axisLine: { show: false },
                        'axisTick': {
                            'show': false
                        },

                        axisLabel: {
                            margin: 2,
                            formatter: function(value, index) {
                                if (value >= 10000 && value < 10000000) {
                                    value = value / 10000 + '万'
                                } else if (value >= 10000000) {
                                    value = value / 10000000 + '千万'
                                }
                                return value
                            }
                        }
                    }
                ],
                'dataZoom': [{
                    'show': true,
                    'height': 20,
                    bottom: 10,
                    startValue: 0,
                    endValue: 6,
                    maxValueSpan: 6,
                    mixValueSpan: 6,
                    handleStyle: {   //滚动条样式
                        color: '#d3dee5'
                    },
                    textStyle: {   //文本提示样式
                        color: '#1D95F4'
                    },
                    borderColor: '#90979c'
                }],
                series: [
                    {
                        name: '收入',
                        type: 'line',
                        data: sr, //[22, 26, 121, 134, 165, 112, 132],
                        symbolSize: 10,
                        symbol: 'circle',
                        'itemStyle': {
                            'normal': {
                                'color': '#1D95F4',
                                'barBorderRadius': 1,
                                borderColor: '#fff',
                                borderWidth: 2
                            }
                        },
                        lineStyle: {  //线条样式
                            normal: {
                                color: '#1D95F4',
                                width: 2
                            }
                        },
                        smooth: true
                    },
                    {
                        name: '成本',
                        type: 'line',
                        data: cb, //[12, 21, 21, 21, 34, 65, 12, 32],
                        symbolSize: 10,
                        symbol: 'circle',
                        'itemStyle': {
                            'normal': {
                                'color': '#FF0050',
                                'barBorderRadius': 1,
                                borderColor: '#fff',
                                borderWidth: 2
                            }
                        },
                        lineStyle: {  //线条样式
                            normal: {
                                color: '#FF0050',
                                width: 2
                            }
                        },
                        smooth: true
                    },

                    {
                        name: '利润',
                        type: 'line',
                        data: lr, //[-34, -65, -12, -32, -34, -65, 12, 32],
                        symbolSize: 10,
                        symbol: 'circle',
                        'itemStyle': {
                            'normal': {
                                'color': '#1BF78D',
                                'barBorderRadius': 1,
                                borderColor: '#fff',
                                borderWidth: 2
                            }
                        },
                        areaStyle: {
                            color: '#D5F5E6'
                        },
                        lineStyle: {  //线条样式
                            normal: {
                                color: '#1BF78D',
                                width: 2
                            }
                        },
                        smooth: true
                    }
                ]
            }

            mychart2.setOption(option2)
        },
    },
    template: `<div ref="chart1" class="contain_line"></div>`
};



