const vm = new Vue({
    el: '#app',
    data() {
        return {
            defaultDate: [
                dayjs().subtract(7, 'day').$d,
                new Date()
            ],
            minDate: new Date(2010, 0, 0),
            maxDate: new Date(),
            showDate: false,
            startTime: dayjs().subtract(7, 'day').format('YYYY-MM-DD'),
            endTime: dayjs().format('YYYY-MM-DD'),

            isExends: false,
            storageName: '请选择',

            projectNo: '',
            warehouseNo: '',
            projectList: [],

            lineList: [
                {title: '出库及时率', expendTitle: {text: '接入订单量', value: 0}, type: 1},
                {title: '坪效', type: 2},
                {title: '人效', type: 2},
                {title: '盈亏平衡点', type: 3},
                {title: '平均出库时间', type: 2},
                {title: '揽收进展', type: 2}
            ]
        }
    },
    components: {
        'contains-box': ContainsBox,
        'line-box': LineBox
    },
    filters: {
        limitLen(val) {
            if (val.length > 8) return val.substr(0, 8) + '...';
            else return val
        }
    },
    methods: {
        onConfirmDate: function (date) {
            const [start, end] = date;
            const dayNum = dayjs(end).subtract(30, 'day').valueOf();
            if (new Date(start).valueOf() < dayNum) {
                Emp.execute(`showMsg('日期查询区间不能大于30天')`);
                return
            }
            this.showDate = false;
            this.startTime = dayjs(start).format('YYYY-MM-DD');
            this.endTime = dayjs(end).format('YYYY-MM-DD');
        },
        openFilter() {
            this.isExends = !this.isExends
        },
        reSet() {
            this.startTime = dayjs().subtract(6, 'day').format('YYYY-MM-DD');
            this.endTime = dayjs().format('YYYY-MM-DD');
            this.isExends = false
        },
        //出库及时率
        queryTimelyRate() {
            const params = {
                warehouseNo: this.warehouseNo,
                projectNo: this.projectNo,
                /*warehouseNo: '00000100',
                projectNo: '',*/
                startTime: this.startTime + ' 00:00:00',
                endTime: this.endTime + ' 23:59:59'
            };
            weekTimelyRate(params).then(resp => {
                const data = [];
                const data2 = [];
                const xData = [];
                let num = 0;
                const lineData = resp[0].cwmProjectEveryDayInfo.sort((a,b) => {
                    return dayjs(a.queryTime).valueOf() - dayjs(b.queryTime).valueOf()
                });
                lineData.forEach(item => {
                    num += parseInt(item.accessOrders);
                    data.push(item.deliveryTime);
                    data2.push(item.deliveryTimeRate.split('%')[0]);

                    if (item.queryTime.includes('-')) {
                        const x = item.queryTime.split('-');
                        xData.push(x[1] + '-' + x[2])
                    } else {
                        xData.push(item.queryTime)
                    }
                });
                this.lineList[0].expendTitle.value = num;
                this.$refs.lineBox[0].initData(xData, [data, data2])
            }).catch(err => {
                this.$refs.lineBox[0].initData()
            })
        },
        //坪效
        queryLevelEffect() {
            const params = {
                warehouseNo: this.warehouseNo,
                projectNo: this.projectNo,
                startTime: this.startTime + ' 00:00:00',
                endTime: this.endTime + ' 23:59:59'
            };
            findLevelEffect(params).then(resp => {
                let xData = [];
                let yData = [];
                const lineData = resp[0].fenwineProjectEverydayDate.sort((a,b) => {
                    return dayjs(a.queryTime).valueOf() - dayjs(b.queryTime).valueOf()
                });
                lineData.forEach(e => {
                    if (e.queryTime.includes('-')) {
                        let x = e.queryTime.split('-');
                        xData.push(x[1] + '-' + x[2])
                    } else {
                        xData.push(e.queryTime)
                    }
                    yData.push(e.projectSize * 100)
                });
                this.$refs.lineBox[1].initData(yData, '坪效', xData, '')
            }).catch(err => {
                this.$refs.lineBox[1].initData()
            })
        },
        //人效
        queryHumanEffect() {
            const params = {
                warehouseNo: this.warehouseNo,
                projectNo: this.projectNo,
                startTime: this.startTime + ' 00:00:00',
                endTime: this.endTime + ' 23:59:59'
            };
            findHumanEffect(params).then(resp => {
                let xData = [];
                let yData = [];
                const lineData = resp[0].projectList.sort((a,b) => {
                    return dayjs(a.queryTime).valueOf() - dayjs(b.queryTime).valueOf()
                });
                lineData.forEach(e => {
                    if (e.queryTime.includes('-')) {
                        let x = e.queryTime.split('-');
                        xData.push(x[1] + '-' + x[2])
                    } else {
                        xData.push(e.queryTime)
                    }
                    yData.push(e.peopleEffect * 100)
                });
                this.$refs.lineBox[2].initData(yData, '人效', xData, '')
            }).catch(err => {
                this.$refs.lineBox[2].initData()
            })

        },
        //盈亏平衡点
        queryIncomeCostMargin() {
            const params = {
                warehouseNo: this.warehouseNo,
                projectNo: this.projectNo,
                /*warehouseNo: '00000100',
                projectNo: '',*/
                startTime: dayjs(this.endTime).subtract(6, 'month').format('YYYY-MM'),
                endTime: dayjs(this.endTime).format('YYYY-MM'),
            };
            findIncomeCostMargin(params).then(resp => {
                const sr = [];
                const cb = [];
                const lr = [];
                const xData = [];

                if (resp.resCode === 'W0002' || resp.list.length === 0) throw new Error('出错了');
                for (let i=0; i<resp.list.length; i++){
                    try{
                        const e = resp.list[i];
                        let lrz = parseFloat(e.warehouseShouRuCount) - parseFloat(e.warehouseChengBenCount);
                        sr.push(e.warehouseShouRuCount);
                        cb.push((e.warehouseChengBenCount * 1).toFixed(2));
                        lr.push(lrz.toFixed(2));
                        xData.push(e.date)
                    }catch (e) {
                        continue;
                    }
                }
                this.$refs.lineBox[3].initData(xData, sr, cb, lr)
            }).catch(err => {
                console.log(err);
                this.$refs.lineBox[3].initData()
            })
        },
        //平均出库时间
        queryOutMeanTimeLimit() {
            const params = {
                warehouseNo: this.warehouseNo,
                projectNo: this.projectNo,
                /*warehouseNo: '00000100',
                projectNo: '',*/
                startTime: this.startTime + ' 00:00:00',
                endTime: this.endTime + ' 23:59:59'
            };
            findOutMeanTimeLimit(params).then(resp => {
                if (resp.resCode === 'W0002') throw new Error('出错了');
                let xData = [];
                let yData = [];
                const lineData = resp.data[0].projectDomianList.sort((a,b) => {
                    return dayjs(a.createTime).valueOf() - dayjs(b.createTime).valueOf()
                });
                lineData.forEach(e => {
                    if (e.createTime.includes('-')) {
                        let x = e.createTime.split('-');
                        xData.push(x[1] + '-' + x[2])
                    } else {
                        xData.push(e.createTime)
                    }
                    yData.push(e.timeCount)
                });
                this.$refs.lineBox[4].initData(yData, '出库时间', xData, '分钟')
            }).catch(err => {
                console.log(err);
                this.$refs.lineBox[4].initData()
            })
        },
        //揽收进展
        queryCollectProgress() {
            const params = {
                warehouseNo: this.warehouseNo,
                projectNo: this.projectNo,
                startTime: this.startTime + ' 00:00:00',
                endTime: this.endTime + ' 23:59:59'
            };

            findCollectProgress(params).then(resp => {
                let xData = [];
                let yData = [];
                const lineData = resp[0].projectList.sort((a,b) => {
                    return dayjs(a.queryTime).valueOf() - dayjs(b.queryTime).valueOf()
                });
                lineData.forEach(e => {
                    if (e.queryTime.includes('-')) {
                        let x = e.queryTime.split('-');
                        xData.push(x[1] + '-' + x[2])
                    } else {
                        xData.push(e.queryTime)
                    }
                    yData.push(e.completionRate * 100)
                });
                this.$refs.lineBox[5].initData(yData, '揽收进展', xData, '完成率(%)')
            }).catch(err => {
                this.$refs.lineBox[5].initData()
            })
        },
        getData() {
            this.queryTimelyRate();
            this.queryLevelEffect();
            this.queryHumanEffect();
            this.queryIncomeCostMargin();
            this.queryOutMeanTimeLimit();
            this.queryCollectProgress();
            this.$refs.contains_box.scrollTop = 0
        },
        selectState(key) {
            this.projectList.forEach(e => {
                e.state = 1
            });
            this.projectList[key].state = 0;
            this.projectNo = this.projectList[key].value;
            this.storageName = this.projectList[key].text
        },
        queryProduct(){
            findProjectInfo({
                warehouseNo: this.warehouseNo
            }).then(resp => {
                this.projectList = resp.data[0].projectList.map((item, idx) => {
                    return {
                        text: item.projectName,
                        value: item.projectNo,
                        state: idx === 0 ? 0 : 1
                    }
                });
                console.log(this.filterss);
                this.projectNo = this.projectList[0].value;
                this.storageName = this.projectList[0].text;
                this.getData()
            })
        }
    },
    created() {
        window['getInfo'] = (key, items) => {
            key = key || '41200060';
            this.warehouseNo = key;
            this.queryProduct()
        }
    }
});
