/*
* 时间选择组件
* prop
*   date: Object/Date | 时间
*
* */
Vue.component('time-select', {
    props: {
        curdate: {
            Object,
            default: () => {
                return dayjs()
            }
        }
    },
    data() {
        return {
            list: []
        }
    },
    model: {
        prop: 'curdate',
        event: 'change'
    },
    methods: {
        getRequireList() {
            const today = ['周日', '周一', '周二', '周三', '周四', '周五', '周六'];
            let list = [this.curdate];
            for (let i = 1; i < 4; i++) {
                list.push(this.curdate.subtract(i, 'day'));
                list.push(this.curdate.add(i, 'day'))
            }
            list.sort((a, b) => a.valueOf() - b.valueOf());
            this.list = list.map((item, index) => {
                return {
                    state: index === 3 ? 1 : 0,
                    text: today[item.get('day')],
                    date: item,
                    dateFormat: item.format('MM/DD')
                }
            });

            this.$nextTick(() => {
                /*this.$refs.selectRef[1].scrollIntoView({
                    inline: 'start'
                })*/
                const index = this.list.findIndex(item => item.state);
                const div = this.$refs.selectRef[index];
                const contain = document.getElementsByClassName('time-select')[0];
                const width = document.body.clientWidth;
                if (div.offsetLeft + width / 2 + div.offsetWidth / 2 <= contain.scrollWidth){
                    //满足在最中间
                    console.log('最中间显示');
                    contain.scrollLeft = div.offsetLeft - width / 2 + div.offsetWidth / 2
                }else {
                    contain.scrollLeft = 0
                }

               /* console.log(width);   //屏幕宽度
                console.log(contain.scrollWidth);  //容器可滚动的宽度
                console.log(div.offsetLeft);  //距离左边的宽度
                console.log(div.offsetWidth);   //容器宽度(padding + margin + width)*/
            })
        },
        selectDate(item, index) {
            this.list.forEach(item => item.state = 0);
            item.state = 1;
            this.$emit('change', item.date)
        }
    },
    mounted() {
        this.getRequireList()
    },
    watch: {},
    template: `
        <div class="time-select" style="padding: 8px 5px">
            <div v-for="(item, index) in list" :key="item.text" style="padding: 0 5px"  ref="selectRef" @click="selectDate(item, index)">
                <div class="item">
                    <div style="border-bottom: 1px solid #e6e6e6" :class="{'time-select-active': item.state, 'time-select-active-text': item.state}">{{item.text}}</div>
                    <div :class="{'time-select-active': item.state, 'time-select-active-date': item.state}">{{item.dateFormat}}</div>
                </div>
            </div>
        </div>
    `
});

/*
* 头部导航
* */
Vue.component('header-content', {
    props: {
        title: {
            String,
            default: '标题'
        },
        showLeft: {
            Boolean,
            default: true
        },
        headSty: {
            Object,
            default: () => {
                return {}
            }
        }
    },
    methods: {
        goBack() {
            this.$emit('go-back')
        }
    },
    template: `
        <div class="header-content" :style="headSty">
            <van-icon name="arrow-left" :color="headSty.color ? headSty.color : '#FFF'" v-if="showLeft" size="20" @click="goBack"/>
            <span class="title">{{title}}</span>
            <slot></slot>
        </div>
    `
});

/*
* 航班列表
* props
*   list: Array | 列表集合
*
* */
Vue.component('flight-list', {
    props: {
        list: {
            Array,
            default: () => {
                return [{},{},{}]
            }
        },
        containHeight: {
            String,
            default: () => {
                const h = document.documentElement.clientHeight || document.body.clientHeight;
                return h - 100 + 'px'
            }
        },
        bodySty: {
            Object,
            default: () => {
                return {

                }
            }
        },
        isNoData: {
            Boolean,
            default: false
        }
    },
    methods: {
        handleFlight(item){
            this.$emit('handle-flight', item)
        }
    },
    template: `
        <div :style="{height: containHeight}" style="-webkit-overflow-scrolling: touch;
overflow-scrolling: touch;
overflow-y: scroll;" class="list-content">
            <div v-for="item in list" class="item" @click="handleFlight(item)">
                <div class="header">
                    <span style="color: #1E97F2">{{item.headLeft}}</span>
                    <span>{{item.headRight}}</span>
                </div>
                <div class="body" :style="">
                    <div :style="bodySty">
                        <div>{{item.bodyNameLeft}}</div>
                        <div style="font-size: 20px; font-weight: bold">{{item.bodyValueLeft}}</div>
                    </div>
                    <div style="text-align: right" :style="bodySty">
                        <div>{{item.bodyNameRight}}</div>
                        <div style="font-size: 20px; font-weight: bold">{{item.bodyValueRight}}</div>
                    </div>
            
                    <slot :data="item" name="bodyExpend"></slot>
                </div>
                <div class="expend" v-if="item.bodyExpend1 && item.bodyExpend2" :style="{'border-bottom': item.bottom ? '1px solid #e6e6e6' : ''}">
                    <div v-html="item.bodyExpend1"></div>
                    <div v-html="item.bodyExpend2"></div>
                </div>
                <div class="bottom" v-if="item.bottom">
                    <span v-for="txt in item.bottom" :key="txt" v-html="txt" style="flex: 1; line-height: 20px;"></span>
                </div>
            </div>
            <div v-show="isNoData" style="position: absolute; left: 50%; top: 50%; transform: translate(-50%, -50%)">
                <img src="../img/nodata.png" alt="">   
                <div style="width: 100%; text-align: center">暂无数据</div>    
            </div>
        </div>
    `
});

