//swiper容器
Vue.component('swiper-contain', {
    // margin-top:改为0
    template: `<div class="swiper-container" style="margin-top: 0">
                    <div class="swiper-wrapper">
                        <div class="swiper-slide">
                            <slot name="first"></slot>
                        </div>
                        <div class="swiper-slide">
                            <slot name="second"></slot>
                        </div>
                    </div>
                </div>`
});

//顶部图标
Vue.component('top-icon', {
    methods: {
        handleLine(){
            this.$emit('handleline')
        },
        handleTable(){
            this.$emit('handletable')
        }
    },
    props: {
        showIcon: {
            type: Boolean,
            default: true
        }
    },
    //修改新图标 老图标为line/right
    template: `<div class="top-contain">
                    <img src="./img/line-new.png" alt="" style="width: 20px; height: 20px" @click="handleLine">
                    <img src="./img/right-new.png" alt="" style="width: 20px; height: 20px" @click="handleTable" v-show="showIcon">
                </div>`
});

//第一页底部
Vue.component('bottom-one', {
    data(){

    },
    props: {
        valuesObj: {
            Object,
            default: () => {
                return {
                    zrz: 0,
                    rhb: 0,
                    rtb: 0
                }
            }
        }
    },
    methods: {
        openDialog(flag){
            const msg = flag ? '日环比 = (今日整点量 - 昨日整点量) / 昨日整点量' : '日同比 = (今日整点量 - 上周同期量) / 上周同期量';
            vant.Dialog.alert({
                message: msg,
            }).then(() => {
                // on close
            });
        }
    },
    filters: {
        filterRate(val){
            const rate = val.split('%')[0];
            if (Number(rate) == Infinity || Number(rate) == NaN){
                return '--'
            }else return val
        }
    },
    template: `<div class="bottom-one">
                    <div class="bottom-one-item">
                        <span>昨日</span>
                        <span style="font-weight: bold">{{valuesObj.zrz}}</span>
                    </div>
                    <div class="bottom-one-item">
                        <span @click="openDialog(1)" style="color: #3a8ee6">日环比</span>
                        <span style="font-weight: bold">{{valuesObj.rhb | filterRate}}</span>
                    </div>
                    <div class="bottom-one-item" style="border-right: none">
                        <span @click="openDialog(0)" style="color: #3a8ee6">日同比</span>
                        <span style="font-weight: bold">{{valuesObj.rtb | filterRate}}</span>
                    </div>
                </div>`
});

//饼图显示内容
Vue.component('swiper-body', {
    props: {
        valuesObj: {
            Object,
            default: () => {
                return {
                    name: '标题',
                    value: 0,
                    refName: 'orderRef'
                }
            }
        }
    },
    //['#06BDB2','#1ED3C8','#14A496','#08F6E7']
    methods: {
        initEcharts(data = {
            val: [
                {value: 0, name: '国内特快'},
                {value: 0, name: '国内快包'},
                {value: 0, name: '国际邮件'},
                {value: 0, name: '其他'}
            ],
            begin: ['#79DD8E','#F99D8C','#FBD078','#67BAF1'],
            end: ['#8EFFB0','#FEB3A3','#FEEF95','#74D5FF']
        }){
            const total = data.val.reduce((a,b) => {
                return a + Number(b.value)
            }, 0);
            let mychart = echarts.init(this.$refs[this.valuesObj.refName]);
            let option = {
                tooltip: {
                	confine: true,
                    trigger: 'item',
                    show: true,
                    formatter: (params) => {
                        const v = (Number(params.data.value) / total * 100).toFixed(1);
                        const rale = v == '0.0' ? '0%' : v + '%';
                        return `${params.data.name}: ${params.data.value}(${total == 0 ? '0%' : rale})`
                    },
                },
                series: [
                    {
                        name: '访问来源',
                        type: 'pie',
                        data: data.val,
                        radius: '50%',
                        center: ['50%', '50%'],
                        label: {
                            color: '#ffffff',
                            formatter: (params) => {
                                const v = (Number(params.data.value) / total * 100).toFixed(1);
                                const rale = v == '0.0' ? '0%' : v + '%';
                                return `${params.data.name}\n ${total == 0 ? '0%' : rale}`
                            },
                            fontSize: 10
                        },
                        labelLine: {
                            normal: {
                                length: 10,
                                length2: 2,
                            }
                        },
                        itemStyle: {normal: {
                                color: function(params) {
                                    const colorList = data.begin;
                                    const colorList2 = data.end;
                                    return new echarts.graphic.LinearGradient(1, 0, 0, 0, [{
                                        offset: 0,
                                        color: colorList[params.dataIndex]
                                    }, {
                                        offset: 1,
                                        color: colorList2[params.dataIndex]
                                    }], false)
                                }
                            }
                        }}
                ]
            };
            mychart.setOption(option)
        }
    },
    template: `<div style="display: flex">
                        <div class="swiper-title">
                            <span style="font-size: 1rem">{{valuesObj.name}}</span> <br>
                            <span style="font-size:.8rem">{{valuesObj.value}}</span>
                        </div>
                        <div :ref="valuesObj.refName" class="echarts-box"></div>
                    </div>`
});

Vue.component('swiper-two-item',{
    props: {
        list: {
            Array,
            default: () => {
                return [
                    {name: '昨日总量', val: 0},
                    {name: '上周同期', val: 0},
                    {name: '今日总量', val: 0}
                ]
            }
        },
        bodyContent: {
            Boolean,
            default: false
        }
    },
    filters: {
        filterRate(val){
            if (!val) return '--'
            else return val
        }
    },
    template: `<div class="bottom-one" style="flex-wrap: wrap; justify-content: space-between; align-content: space-between" :class="{'swiper-body-two': bodyContent}">
                    <div class="bottom-one-item swiper-two" :class="{'hold-font': bodyContent}" v-for="item in list">
                        <span>{{item.name}}</span>
                        <span>{{item.val | filterRate}}</span>
                    </div>
                </div>`
});



Vue.component('home-board', {
    props: {
        valuesObj: {
            Object,
            default: () => {
                return {}
            }
        },
        pagekey: {
            String,
            default: ''
        },
        refName: {
            String,
            default: ''
        },
        showIcon: {
            type: Boolean,
            default: true
        }
    },
    methods: {
        handleLine(){
            console.log('点击了');
            this.$emit('handleline', this.pagekey)
        },
        handleTable(){
            console.log('点击了');
            this.$emit('handletable', this.pagekey)
        },
        initEcharts(data) {
            this.$refs[this.refName].initEcharts(data)
        }
    },
    template: `<swiper-contain>
                    <div slot="first" style="position: relative; height: 100%">
                        <top-icon @handleline="handleLine" @handletable="handleTable" :showIcon="showIcon"></top-icon>
                        <bottom-one :values-obj="valuesObj.values"></bottom-one>
                        <img src="./img/hand.png" alt="" class="handtouch"/>
                        <swiper-body style="position: absolute" :ref="refName" :values-obj="valuesObj.body"></swiper-body>
                    </div>
                    <div slot="second" style="position: relative; height: 100%">
                        <top-icon @handleline="handleLine" @handletable="handleTable" :showIcon="showIcon"></top-icon>
                        <swiper-two-item :body-content="true" :list="valuesObj.bodyList"></swiper-two-item>
                        <swiper-two-item :list="valuesObj.bottomList"></swiper-two-item>
                    </div>
                </swiper-contain>`
});
//新饼图-卡片部分1
Vue.component('card-body-one', {
    props: {
        valuesObj: {
            Object,
            default: () => {
                return {
                    name: '标题',
                    value: 0,
                    refName: 'orderRef',
                    zrz:0,
                    rhb:0,
                    rtb:0
                }
            }
        },
        pagekey: {
            String,
            default: ''
        },
        refName: {
            String,
            default: ''
        },
        showIcon: {
            type: Boolean,
            default: true
        }
    },
    filters: {
        filterRate(val){
            // console.log('ssssssssssssssssssssssssssssssss',val)
            if(val == undefined) return
            const rate = val.split('%')[0];
            if (Number(rate) == Infinity || Number(rate) == NaN || rate=='-Infinity' || rate=='NaN'){
                return '--'
            }else return val
        }
    },
    computed: {
        valUnit() {
            const val =this.valuesObj.value;
            const unit ='件'
            if (val > 100000000) return  '亿' + unit;
            else if (val > 10000) return '万' + unit;
            else return  unit
        },
        yesValUnit() {
            const val =this.valuesObj.zrz;
            const unit ='件'
            if (val > 100000000) return  '亿' + unit;
            else if (val > 10000) return '万' + unit;
            else return  unit
        },
        filterVal() {
            const total =this.valuesObj.value;
            if (total > 100000000) return (total / 100000000).toFixed(1) ;
            else if (total > 10000) return (total / 10000).toFixed(1) ;
            else return total 
        },
        filteryYsVal() {
            const total =this.valuesObj.zrz;
            if (total > 100000000) return (total / 100000000).toFixed(1) ;
            else if (total > 10000) return (total / 10000).toFixed(1) ;
            else return total 
        },
    },
    //['#06BDB2','#1ED3C8','14A496','#08F6E7']
    methods: {
        initEcharts(data = {
            val: [
                {value: 0, name: '国内特快'},
                {value: 0, name: '国内快包'},
                {value: 0, name: '国际邮件'},
                {value: 0, name: '其他'}
            ],
            begin:['#06BDB2','#1ED3C8','#14A496','#08F6E7'],
            end:['#06BDB2','#1ED3C8','#14A496','#08F6E7']
        }){
            // console.log('ssssssssssssssss',data)
            const total = data.val.reduce((a,b) => {
                return a + Number(b.value)
            }, 0);
            let mychart = echarts.init(this.$refs[this.valuesObj.refName]);
            let option = {
                tooltip: {
                	confine: true,
                    trigger: 'item',
                    show: true,
                    formatter: (params) => {
                        const v = (Number(params.data.value) / total * 100).toFixed(1);
                        const rale = v == '0.0' ? '0%' : v + '%';
                        return `${params.data.name}: ${params.data.value}(${total == 0 ? '0%' : rale})`
                    },
                },
                series: [
                    {
                        name: '访问来源',
                        type: 'pie',
                        data: data.val,
                        radius: '50%',
                        center: ['50%', '50%'],
                        label: {
                            color: '#000000',
                            position: 'outside',
                            formatter: (params) => {
                                const v = (Number(params.data.value) / total * 100).toFixed(1);
                                const rale = v == '0.0' ? '0%' : v + '%';
                                return `${params.data.name}\n ${total == 0 ? '0%' : rale}`
                            },
                            fontSize: 10
                        },
                        labelLine: {
                            normal: {
                                length: 10,
                                length2: 2,
                            }
                        },
                        itemStyle: {normal: {
                                color: function(params) {
                                    const colorList = data.begin;
                                    const colorList2 = data.end;
                                    return new echarts.graphic.LinearGradient(1, 0, 0, 0, [{
                                        offset: 0,
                                        color: colorList[params.dataIndex]
                                    }, {
                                        offset: 1,
                                        color: colorList2[params.dataIndex]
                                    }], false)
                                }
                            }
                        }}
                ]
            };
            mychart.setOption(option)
        },
      
    },
    template: `<div>
                    
                    <div style="display: flex; padding:10px; padding-top:25px">
                        <div style="min-width:85px">
                            <div class="swiper-content">
                                <span style="font-size: .8rem">{{valuesObj.name}}</span>
                            </div>
                            <div  style="font-size: .65rem">
                                <div class="swiper-content">
                                    <span style="color: #14A496 ; font-weight:bold;font-size: 1.1rem">{{filterVal}}</span>
                                    <span>{{valUnit}} </span>
                                </div>
                                <div style="" class="swiper-content">
                                    <span>昨日总量:</span>
                                    <span style="color: #2DC3BC ;">{{filteryYsVal}}</span>
                                    <span>{{yesValUnit}} </span>
                                </div> 
                                <div style="" class="swiper-content">
                                    <span>日环比:</span>
                                    <span style="color: #14A496 ; font-weight:bold;"> {{valuesObj.rhb | filterRate}}</span>
                                </div>
                                <div style="" class="swiper-content">
                                    <span>日同比:</span>
                                    <span style="color: #14A496 ; font-weight:bold;"> {{valuesObj.rtb | filterRate}}</span>
                                </div>
                            </div>
                        </div>
                        <div :ref="valuesObj.refName" class="echarts-box-new"></div>
                    </div>
                </div>
                `
});
//卡片部分2
Vue.component('card-body-two',{
    data(){
       
    },
    props: {
        list: {
            Array,
            default: () => {
                return [
                    {name: '昨日总量', val: 0},
                    {name: '上周同期', val: 0},
                    {name: '今日总量', val: 0}
                ]
            }
        },
        
    },
    filters: {
        filterRate(val){
            // const total =this.valuesObj.value;
            if (!val) return '0'
            else if (val > 100000000) return (val / 100000000).toFixed(1) ;
            else if (val > 10000) return (val / 10000).toFixed(1) ;
            else return val 
            

        },
        filterUnit(val) {
            // const val =this.valuesObj.value;
            const unit ='件'
            if (val > 100000000) return  '亿' + unit;
            else if (val > 10000) return '万' + unit;
            else return  unit
        },
    },
    template: `<div class="bottom-one-new" style="flex-wrap: wrap; justify-content: space-between; align-content: space-between" >
                    <div class="bottom-one-item-new swiper-two-new"  v-for="item in list">
                        <span>{{item.name}}：</span>
                        <span style="color:#14A496">{{item.val | filterRate}} </span>
                        <span>{{item.val | filterUnit}}</span>
                    </div>
                </div>`
});
//新大屏指标卡片
Vue.component('board-card', {
    props: {
        valuesObj: {
            Object,
            default: () => {
                return {}
            }
        },
        pagekey: {
            String,
            default: ''
        },
        refName: {
            String,
            default: ''
        },
        showIcon: {
            type: Boolean,
            default: true
        }
    },
    methods: {
        handleLine(){
            console.log('点击了',this.pagekey);
            this.$emit('handleline', this.pagekey)
        },
        handleTable(){
            console.log('点击了',this.pagekey);
            this.$emit('handletable', this.pagekey)
        },
        initEcharts(data) {
            console.log('initEcharts',data)
            this.$refs[this.refName].initEcharts(data)
        }
    },
    template: `<swiper-contain>
                    <div slot="first" style="position: relative; height: 100%">
                        <top-icon @handleline="handleLine" @handletable="handleTable" :showIcon="showIcon"></top-icon>
                        <img src="./img/hand-new.png" alt="" class="handtouch-new"/>
                        <card-body-one :ref="refName" :values-obj="valuesObj.body"></card-body-one>
                    </div>
                    <div slot="second" style="position: relative; height: 100%">
                        <top-icon @handleline="handleLine" @handletable="handleTable" :showIcon="showIcon"></top-icon>
                        
                        <card-body-two :list="valuesObj.bodyList"></card-body-two>
                    </div>
                </swiper-contain>`
});
//新饼图-卡片部分1
Vue.component('new-card-body-one', {
    props: {
        valuesObj: {
            Object,
            default: () => {
                return {
                    name: '标题',
                    value: 0,
                    refName: 'orderRef',
                    zrz:0,
                    rhb:0,
                    rtb:0
                }
            }
        },
        pagekey: {
            String,
            default: ''
        },
        refName: {
            String,
            default: ''
        },
        showIcon: {
            type: Boolean,
            default: true
        }
    },
    filters: {
        filterRate(val){
            // console.log('ssssssssssssssssssssssssssssssss',val)
            if(val == undefined) return
            const rate = val.split('%')[0];
            if (Number(rate) == Infinity || Number(rate) == NaN || rate=='-Infinity' || rate=='NaN'){
                return '--'
            }else return val
        }
    },
    computed: {
        valUnit() {
            const val =this.valuesObj.value;
            const unit ='元'
            if (val > 100000000) return  '亿' + unit;
            else if (val > 10000) return '万' + unit;
            else return  unit
        },
        yesValUnit() {
            const val =this.valuesObj.zrz;
            const unit ='元'
            if (val > 100000000) return  '亿' + unit;
            else if (val > 10000) return '万' + unit;
            else return  unit
        },
        filterVal() {
            const total =this.valuesObj.value;
            if (total > 100000000) return (total / 100000000).toFixed(1) ;
            else if (total > 10000) return (total / 10000).toFixed(1) ;
            else return total 
        },
        filteryYsVal() {
            const total =this.valuesObj.zrz;
            if (total > 100000000) return (total / 100000000).toFixed(1) ;
            else if (total > 10000) return (total / 10000).toFixed(1) ;
            else return total 
        },
    },
    //['#06BDB2','#1ED3C8','14A496','#08F6E7']
    methods: {
        initEcharts(data = {
            val: [
                {value: 0, name: '国内特快'},
                {value: 0, name: '国内快包'},
                {value: 0, name: '国际邮件'},
                {value: 0, name: '其他'}
            ],
            begin:['#06BDB2','#1ED3C8','#14A496','#08F6E7'],
            end:['#06BDB2','#1ED3C8','#14A496','#08F6E7']
        }){
            // console.log('ssssssssssssssss',data)
            const total = data.val.reduce((a,b) => {
                return a + Number(b.value)
            }, 0);
            let mychart = echarts.init(this.$refs[this.valuesObj.refName]);
            let option = {
                tooltip: {
                	confine: true,
                    trigger: 'item',
                    show: true,
                    formatter: (params) => {
                        const v = (Number(params.data.value) / total * 100).toFixed(1);
                        const rale = v == '0.0' ? '0%' : v + '%';
                        return `${params.data.name}: ${params.data.value}(${total == 0 ? '0%' : rale})`
                    },
                },
                series: [
                    {
                        name: '访问来源',
                        type: 'pie',
                        data: data.val,
                        radius: '50%',
                        center: ['50%', '50%'],
                        label: {
                            color: '#000000',
                            position: 'outside',
                            formatter: (params) => {
                                const v = (Number(params.data.value) / total * 100).toFixed(1);
                                const rale = v == '0.0' ? '0%' : v + '%';
                                return `${params.data.name}\n ${total == 0 ? '0%' : rale}`
                            },
                            fontSize: 10
                        },
                        labelLine: {
                            normal: {
                                length: 10,
                                length2: 2,
                            }
                        },
                        itemStyle: {normal: {
                                color: function(params) {
                                    const colorList = data.begin;
                                    const colorList2 = data.end;
                                    return new echarts.graphic.LinearGradient(1, 0, 0, 0, [{
                                        offset: 0,
                                        color: colorList[params.dataIndex]
                                    }, {
                                        offset: 1,
                                        color: colorList2[params.dataIndex]
                                    }], false)
                                }
                            }
                        }}
                ]
            };
            mychart.setOption(option)
        },
      
    },
    template: `<div>
                    <div style="display: flex; padding:10px; padding-top:25px">
                        <div style="min-width:85px">
                            <div class="swiper-content">
                                <span style="font-size: .8rem">{{valuesObj.name}}</span>
                            </div>
                            <div  style="font-size: .65rem">
                                <div class="swiper-content">
                                    <span style="color: #14A496 ; font-weight:bold;font-size: 1.1rem">{{filterVal}}</span>
                                    <span>{{valUnit}} </span>
                                </div>
                                <div style="" class="swiper-content">
                                    <span>昨日总量:</span>
                                    <span style="color: #2DC3BC ;">{{filteryYsVal}}</span>
                                    <span>{{yesValUnit}} </span>
                                </div> 
                                <div style="" class="swiper-content">
                                    <span>日环比:</span>
                                    <span style="color: #14A496 ; font-weight:bold;"> {{valuesObj.rhb | filterRate}}</span>
                                </div>
                                <div style="" class="swiper-content">
                                    <span>日同比:</span>
                                    <span style="color: #14A496 ; font-weight:bold;"> {{valuesObj.rtb | filterRate}}</span>
                                </div>
                            </div>
                        </div>
                        <div :ref="valuesObj.refName" class="echarts-box-new"></div>
                    </div>
                </div>
                `
});
//卡片部分2
Vue.component('new-card-body-two',{
    data(){
       
    },
    props: {
        list: {
            Array,
            default: () => {
                return [
                    {name: '昨日总量', val: 0},
                    {name: '上周同期', val: 0},
                    {name: '今日总量', val: 0}
                ]
            }
        },
        
    },
    filters: {
        filterRate(val){
            // const total =this.valuesObj.value;
            if (!val) return '0'
            else if (val > 100000000) return (val / 100000000).toFixed(1) ;
            else if (val > 10000) return (val / 10000).toFixed(1) ;
            else return val 
            

        },
        filterUnit(val) {
            // const val =this.valuesObj.value;
            const unit ='元'
            if (val > 100000000) return  '亿' + unit;
            else if (val > 10000) return '万' + unit;
            else return  unit
        },
    },
    template: `<div class="bottom-one-new" style="flex-wrap: wrap; justify-content: space-between; align-content: space-between" >
                    <div class="bottom-one-item-new swiper-two-new"  v-for="item in list">
                        <span>{{item.name}}：</span>
                        <span style="color:#14A496">{{item.val | filterRate}} </span>
                        <span>{{item.val | filterUnit}}</span>
                    </div>
                </div>`
});
Vue.component('new-board-card', {
    props: {
        valuesObj: {
            Object,
            default: () => {
                return {}
            }
        },
        pagekey: {
            String,
            default: ''
        },
        refName: {
            String,
            default: ''
        },
        showIcon: {
            type: Boolean,
            default: true
        }
    },
    methods: {
        handleLine(){
            console.log('点击了',this.pagekey);
            this.$emit('handleline', this.pagekey)
        },
        handleTable(){
            console.log('点击了',this.pagekey);
            this.$emit('handletable', this.pagekey)
        },
        initEcharts(data) {
            console.log('initEcharts',data)
            this.$refs[this.refName].initEcharts(data)
        }
    },
    template: `<swiper-contain>
                    <div slot="first" style="position: relative; height: 100%">
                        <top-icon @handleline="handleLine" @handletable="handleTable" :showIcon="showIcon"></top-icon>
                        <img src="./img/hand-new.png" alt="" class="handtouch-new"/>
                        <new-card-body-one :ref="refName" :values-obj="valuesObj.body"></new-card-body-one>
                    </div>
                    <div slot="second" style="position: relative; height: 100%">
                        <top-icon @handleline="handleLine" @handletable="handleTable" :showIcon="showIcon"></top-icon>
                        
                        <new-card-body-two :list="valuesObj.bodyList"></new-card-body-two>
                    </div>
                </swiper-contain>`
});
//精选指标-卡片部分
Vue.component('card-jx-one',{
    data(){
       
    },
    props: {
        objList: {
            Object,
            default: () => {
                return {
                    title:'总体',
                    list:[
                        {name: '日业务量', val: 15456811},
                        {name: '日业务收入', val: 55565,count:true},
                        {name: '月业务量增幅', val: -5,isRate:true},
                        {name: '月收入增幅', val: 11.5,isRate:true}     
                    ]
                }
            }
        },
        
    },
    filters: {
        filterRate(val){
            if(val.isRate){
                if (!val.val) return '--'
                else if(val.val>0) return  '+'+val.val +'%'
                else return  val.val +'%'
            }else{
                if (!val.val) return '--'
                else if (val.val > 100000000) return (val.val / 100000000).toFixed(1);
                else if (val.val > 10000) return (val.val / 10000).toFixed(1);
                else if (val.val < 10000 && !NaN) {
                	if (val.count) return Number(val.val).toFixed(1);
                	else  return Number(val.val);
                }
                else if (val.val < 10000 && val.count) return Number(val.val).toFixed(1);
                else return '--';
            }
            // const total =this.valuesObj.value;
        },
        filterUnit(val) {
            // const val =this.valuesObj.value;
            // console.log(val)
            let unit
            if (val.count){
                unit='元'
            }  else{
                unit ='件'
            }
              
            if (val.val > 100000000) return  '亿' + unit;
            else if (val.val > 10000) return '万' + unit;
            else return  unit
        },
        filterName(val){
            switch(val){
                case "cntFee":
                    return '日业务收入'
                case "cntMail":
                    return '日业务量'
                case "mrateM":
                    return '月业务量增幅'
                case "frateM":
                    return '月收入增幅'
            }
        }
    },
    template: `<div class="card-jx">
                    <div class="card-jx-title">
                        {{objList.title}}量收
                        <span>({{objList.date_code}})</span>
                    </div>
                    <div style="display:flex; flex-wrap:wrap;place-content:space-between; width:100%">
                        <div class="card-jx-content" v-for="item in objList.list">
                            <div style="padding:5px 0">
                                {{item.name | filterName}}:
                            </div>
                            <div>
                               <span style="font-weight:bold"  :style="{'color':isNaN(item.val) ? '#505050' : (item.val>0 ? '#14A496' :  '#F13535') }">{{item | filterRate}}</span> 
                               <span  v-show="!item.isRate">{{item | filterUnit}}</span> 
                            </div>
                        </div>
                    </div>
                    
                </div>`
});
//精选指标-卡片部分2
Vue.component('card-jx-two',{
    data(){
       
    },
    props: {
        objList: {
            Object,
            default: () => {
                return {
                    title:'省内互寄时限达成率',
                    rate:95,
                    rhb:94,
                    card:2,
                    zengfu:2.34,
                    soccer:87
                }
            }
        },
        
    },
    filters: {
        filterRate(val){
            if (!val) return '--'
            else if(val>0) return  '+'+val +'%'
            else return  val +'%'
        },
        filterSoccer(val){
            if (!val) return '--'
            else return val
        },
        filterrhb(val){
            if (!val) return '--'
            else return  val +'%'
        },
    },
    template: `<div class="card-jx">
                    <div class="card-jx-title">
                        {{objList.title}}</br>
                        <span>({{objList.countDate}})</span>
                    </div>
                    <div style="color:#505050">
                        <div class="card-jx-content" :style="{'justify-content':objList.card == 2 ? 'space-around' :'left' }" style="display:flex; width:100%; padding:5px 0">
                            <div v-show="objList.card == 2 ? true : false" style="font-size:1rem;font-weight:bold" :style="{'color':isNaN(objList.rate)?'#505050':'#14A496' }">
                                {{objList.rate | filterrhb}}
                            </div>
                            <div style="line-height:20px" v-show="objList.card == 2 ? true : false">
                               <span >日环比:</span> 
                               <span style="font-weight:bold"  :style="{'color':isNaN(objList.rhb) ? '#505050' : (objList.rhb>0 ? '#14A496' :  '#F13535')}">{{objList.rhb | filterrhb}}</span> 
                                
                            </div>
                            <div v-show="objList.card == 3 ? true : false">
                               <span >得分:</span> 
                               <span  style="font-weight:bold" :style="{'color':isNaN(objList.soccer)?'#505050':'#14A496' }">{{objList.soccer | filterSoccer}}</span> 
                               分
                            </div>
                        </div>
                    </div>
                    <div style="font-size:0.7rem;color:#505050" v-show="objList.card == 2 ? true : false">
                        <span>较上周同期增幅：</span>
                        <span style="font-weight:bold"  :style="{'color':isNaN(objList.zengfu) ? '#505050' : (objList.zengfu>0 ? '#14A496' :  '#F13535')}">{{objList.zengfu | filterRate}}</span>
                    </div>
                    <div  style="font-size:0.8rem;color:#505050" v-show="objList.card == 3 ? true : false">
                        <span>日环比</span>
                        <span style="font-weight:bold"  :style="{'color':isNaN(objList.rhb) ? '#505050' : (objList.rhb>0 ? '#14A496' :  '#F13535')}">{{objList.rhb | filterrhb}}</span>
                    </div>
                </div>`
});
//精选指标-卡片部分3
Vue.component('card-jx-three',{
    data(){
       
    },
    created() {
    	console.log('子组件---------', this.objList)
    },
    methods: {
    	myToFixed(num) {

    	},
    },
    props: {
        objList: {
            Object,
            default: () => {
                return {
                    title:'客户投诉率',
                    targetValue:95,
                    link:94,
                    curMonthTarget:87,
                }
            }
        },
        
    },
    filters: {
        filterRate(val){
            if (!val) return '--'
            if(val == 'NaN'||val == NaN || val == '--') return '--'
            else return  Number(val).toFixed(1) +'%'
        },
        filterrhb(val){
            if (!val) return '--'
            if(val == 'NaN'||val == NaN || val == '--') return '--'
            else {
        		let numAbs = Math.abs(Number(val))
        		if (Number(val) >= 0) {
        			return (Math.round(numAbs * 10) / 10) +'‱'
        		} else {
        			return -(Math.round(numAbs * 10) / 10) +'‱'
        		}
            }
        },
    },
    template: `<div class="card-jx">
                    <div class="card-jx-title">
                        {{objList.pageTitle}}
                        <span>({{objList.count_date}})</span>
                    </div>
                    <div style="display:flex; flex-wrap:wrap;place-content:space-between; width:100%">
	                    <div class="card-jx-content">
		                    <div style="line-height:20px">
		                        <span>当日实际值:</span> <br>
		                        <span style="font-weight:bold" :style="{'color':isNaN(objList.targetValue) ? '#505050' : (objList.targetValueDiff<0 ? '#14A496' :  '#F13535')}">{{objList.targetValue | filterrhb}}</span> 
		                     </div>    
	                    </div>
	                    <div class="card-jx-content">
		                    <div style="line-height:20px">
		                       <span>环比:</span>  <br>
		                       <span style="font-weight:bold"  :style="{'color':isNaN(objList.dayLink) ? '#505050' : (objList.dayLink>0 ? '#F13535' :  '#14A496')}">{{objList.dayLink | filterrhb}}</span> 
		                    </div>
	                    </div>
	                </div>
	                <div style="display:flex; flex-wrap:wrap;place-content:space-between; width:100%">
	                    <div class="card-jx-content">
		                    <div style="line-height:20px">
		                    	<span>月累计:</span> <br>
		                    	<span style="font-weight:bold" :style="{'color':isNaN(objList.curMonthTarget)?'#505050' : (objList.curMonthTargetDiff<0 ? '#14A496' :  '#F13535')}">{{objList.curMonthTarget | filterrhb}}</span> 
	                        </div> 
	                    </div>
	                </div>
                </div>`
});
Vue.component('banner', {
    template: `<van-swipe :autoplay="3000" indicator-color="#FFF">
                    <van-swipe-item v-for="(image, index) in pics" :key="index">
                        <div style="position: relative" @click="toNews(image)">
                            <img width="100%" height="150" :src="image.picture" />
                            <p style="position: absolute; top: 100px; color: #ffffff; margin: 0 10px; font-size: 14px " v-html="image.desc_"></p>
                        </div>
                    </van-swipe-item>
                </van-swipe>`,
    data(){
        return {
            pics: [],
            url: board_url + 'bsv/upload/down?downFile=',

        }
    },
    methods: {
        getData() {
            getBanner({id: 'ALL'}).then(resp => {
                /*let real = resp.data.list;
                let pics = real.filter(e => e.status === '1' && e.is_banner === '1');*/
                //console.log(pics)
                this.pics = resp.data.list;
                this.pics.forEach(e => {

                    if (e.desc_.length > 30) e.desc_ = e.desc_.slice(0, 40) + '...'
					if (e.picture.indexOf('https://') == -1 && e.picture.indexOf('http://') == -1) {
						e.picture = this.url + e.picture
					}

                })
            })
        },
        toNews(item) {
            console.log(item);
            try {
                Emp.execute(`toNews('${item.id}')`)
            } catch (e) {
            }
        },

    },
    mounted(){
        this.getData()
    }

});


