const vm = new Vue({
    el: '#app',
    data() {
        return {
            defaultDate: new Date(),
            minDate: new Date(new Date().getFullYear(), 0, 1),
            maxDate: new Date(),
            selectDate: new Date(),
            showDate: false,
            startTime: dayjs().format('YYYY-MM-DD'),

            isExends: false,
            storageName: '请选择角色',

            projectNo: '',
            projectList: [],

            tableConfig: {
                moduleList: []
            },
            tip: '数据加载中...',
            pageNo: 0,
            totalSum: null
        }
    },
    filters: {
        limitLen(val) {
            if (val.length > 8) return val.substr(0, 8) + '...';
            else return val
        }
    },
    methods: {
        openDate() {
            this.showDate = true;
            this.isExends = false;
            this.defaultDate = this.selectDate;
            this.$refs.calendar.reset()
        },
        tableHeight() {
            const h = document.documentElement.clientHeight || document.body.clientHeight;
            return h - 60;
        },
        onConfirmDate: function (date) {
            this.selectDate = date;
            this.showDate = false;
            this.startTime = dayjs(date).format('YYYY-MM-DD');
            this.getData(true);
        },
        openFilter() {
            this.isExends = !this.isExends
        },
        moreData() {
            console.log('加载更多数据');
            if (this.totalSum === this.tableConfig.moduleList.length) {
                this.tip = '全部数据加载完毕';
                return
            }
            this.getData(false);
        },
        getData(flag) {
            if (flag) {
                this.pageNo = 0;
                this.tableConfig.moduleList = []
            }
            this.tip = '数据加载中...';
            const params = {
                beginDate: this.startTime + ' 00:00:00',
                endDate: this.startTime + ' 23:59:59',
                role: this.projectNo,
                pageNo: ++this.pageNo,
                pageSize: 20
            };
            console.log(params);
            queryRoleLogin(params).then(resp => {
                console.log(resp);
                const names = {'西藏自治区': '西藏', '内蒙古自治区': '内蒙古', '广西壮族自治区': '广西', '宁夏回族自治区': '宁夏', '新疆维吾尔自治区': '新疆'};

                if (resp.data.length < 20) {
                    this.tip = '全部数据加载完毕';
                }
                this.totalSum = resp.sum;
                const list = resp.data.map(item => {
                    const phone = item.phone.replace(/(.{3}).*(.{4})/, '$1****$2');
                    const keys = Object.keys(names);
                    return {
                        name: item.person_name,
                        phone: phone,
                        count: item.sum * 1,
                        provence: keys.includes(item.province_name) ? names[item.province_name] : item.province_name
                    }
                });
                this.tableConfig.moduleList.push(...list);
            }).catch(err => {
                this.tip = '数据加载出错';
            }).finally(() => {
                this.isExends = false;
            })
        },
        selectState(key) {
            this.projectList.forEach(e => {
                e.state = 1
            });
            this.projectList[key].state = 0;
            this.projectNo = this.projectList[key].value;
            this.storageName = this.projectList[key].text
        },
        queryProduct() {
            queryRole({}).then(resp => {
                const data = resp.data;
                const list = [];
                for (let key in data) {
                    list.push({
                        text: data[key],
                        value: key,
                        state: 1
                    })
                }
                list[0].state = 0;
                this.projectList = list;
                this.projectNo = this.projectList[0].value;
                this.storageName = this.projectList[0].text;
                this.getData(true);
            })
        }
    },
    created() {
        window['getInfo'] = () => {
            this.queryProduct()
        };
        window['refresh'] = () => {
            this.getData(true)
        }
    }
});
