
/**
 * 日期转字符串
 * @author lin
 * @time 2020.11.06
 * @params object Date
 * @return 格式如下
 * 日-D：2020.11.06
 * 月-M：2020.11
 * 周-W：2020.44
 */
const dateFormat = {
    'D': (val) => {
        return dayjs(val).format('YYYY.MM.DD');
    },
    'M': (val) => {
        return dayjs(val).format('YYYY.MM')
    },
    'W': (val) => {
        //console.log(dayjs(val).format('YYYYMMDD'));
        //const day = [0, 6, 5, 4, 3, 2, 1]; //周日到周五计算方式
        const day = [1,0,6,5,4,3,2]; //周一到周六计算方式
        let beginDate = new Date(val.getFullYear(), 0, 1);
        //判断是否小于等于周四
        const isThursday = [1, 4, 2, 3].includes(beginDate.getDay());
        let week = Math.ceil((parseInt((val - beginDate) / (24 * 60 * 60 * 1000)) + 1 - day[beginDate.getDay()]) / 7);
        if (isThursday) return `${val.getFullYear()}.${(Number(week) + 1).toString().padStart(2, '0')}`;
        else return `${val.getFullYear()}.${(Number(week)).toString().padStart(2, '0')}`;
    }
};

/**
 * 符串转日期
 * @author lin
 * @time 2020.11.06
 * @params 格式如下
 * 日-D：2020.11.06
 * 月-M：2020.11
 * 周-W：2020.44
 * @return object Date
 */
const dateValue = {
    'D': (val) => {
        const date = val.split('.');
        return new Date(Number(date[0]), Number(date[1]) - 1, Number(date[2]));
    },
    'M': (val) => {
        const date = val.split('.');
        return new Date(Number(date[0]), Number(date[1]) - 1)
    },
    'W': (val) => {
        //const day = [0, 1, 2, 3, 4, 5, 6]; //周日到周六
        const day = [6, 0, 1, 2, 3, 4, 5];
        const week = Number(val.split('.')[1]);
        const year = Number(val.split('.')[0]);
        const beginDate = new Date(year, 0, 1);
        const isThursday = [1, 4, 2, 3].includes(new Date(year, 0,1).getDay());
        let d = '';
        if (isThursday) d = week == 1 ? 1 : ((week - 1) * 7) + 1 - day[beginDate.getDay()];
        else d = week == 1 ? 1 : ((week) * 7) + 1 - day[beginDate.getDay()];
        //console.log(dayjs(new Date(new Date().getFullYear(), 0, d)).format('YYYYMMDD'));;
        return new Date(year, 0, d);
    }
};


/**2020/11/6
 * 作者: LWJ
 * 功能: 过滤每月周一
 * 参数说明:
 *  date: Date
 *  list: 每月日期的集合
 */
const filterMonday = (date, list = ["01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30"]) => {
    //const substrat = [0, 6, 5, 4, 3, 2, 1]; //周日到周六
    const substrat = [1,0,6,5,4,3,2];

    //计算每月1号周几
    const day = new Date(date.getFullYear(), date.getMonth()).getDay();

    const newList = list.splice(substrat[day]);
    const mapList = newList.map((item,index) => {
        if (index % 7 == 0) return item
    }).filter(i => i);

    if (date.getMonth() === 0) {
        const isThursday = [1, 4, 2, 3].includes(new Date(date.getFullYear(), 0,1).getDay());
        if (isThursday) mapList.unshift('01');
    }
    return mapList
    //return newList.filter((item,index) => index % 7 == 0)
};


const formtWeek = (date, val) => {
    const newDate = new Date(date.getFullYear(), date.getMonth(), Number(val));
    const addDay = dayjs(newDate).add(6, 'day').format('DD');

    let week = dateFormat.W(newDate).split('.')[1];
    let day = `(${val}-${addDay}日)`;

    if (date.getMonth() === 0) {
        const firstDay = new Date(date.getFullYear(), 0,1);
        const today = firstDay.getDay();
        const isThursday = [1, 4, 2, 3].includes(today);
        if (isThursday){
            if (val === '01') {
                const subtract = [null,0,1,2,3];
                week = val;
                const begin = dayjs(firstDay).subtract(subtract[today], 'day').format('DD');
                const end = dayjs(firstDay).add(6-subtract[today], 'day').format('DD');
                day = `(${begin}-${end}日)`
            }
        }
    }
    return `${week}周${day}`

};

const getFirstWeek = (week = '2020.36') => {
    const currTime = dateValue.W(week);
    const dayCount = dayjs(currTime).daysInMonth();
    let list = [];
    for (let i = 1; i <= dayCount; i++){
        if (i >= 10) list.push(i.toString());
        else list.push('0' + i)
    }
    const newList = filterMonday(currTime, list);
    const newDate = new Date(currTime.getFullYear(), currTime.getMonth(), Number(newList[0]));
    return currTime.getFullYear() + formtWeek(newDate, newList[0]).split('周')[0];
};


