/**
 * 表
 * isNo: 是否显示序号列
 * redBy: 是否红图模式[min,max]
 * notReverse: 红绿色显示逻辑是否反转 
 * specialName: 不参与排序的特殊行
 * 列
 * subByZero: true数字显示红绿色根据0分割为2段 绿-红
 * subByTarget: key数字显示红绿色根据字段分割为2段 绿-红
 * subByKey: 数字显示红绿色根据0和字段分割为3段 绿-黑-红
 * subDown: 比给定值小的显示红色
 * subUp: 比给定值大的显示绿色
 * reverse: 单列的颜色设置是否反转，支持subByZero、subByTarget
 * isRate: 一般在表头显示%，isRate时单元格显示%
 * isNumber: 表示这一列是数字，需要粗体显示
 * align: 值靠左靠右
 * paddingRight: 值右边距，和align=right组合使用
 */

Vue.component('drillDownBox', {
    data() {
        return {
        	normalColor: '#333333',
            drillColor: '#3377FF',
            upColor: '#009900',
            downColor: '#FA2525',
            toastId: null,
			drawer: false,
			direction: 'btt',

			sendCode: '',
			recvProvCode: '',
			sendName: '',
			recvProvName: '',
			wholeRate: '',
			activeNames: [],
			accordionList: [
				{
					img: 'image/out.png',
					title: '省际出口段达成率',
					index: '1',
					progress: '0',
					table: [],
					worseList: []
				}, {
					img: 'image/in.png',
					title: '省际进口段达成率',
					index: '2',
					progress: '0',
					table: [],
					worseList: []
				}, {
					img: 'image/transport.png',
					title: '省际运输段达成率',
					index: '3',
					progress: '0',
					table: [],
					worseList: []
				}, {
					img: 'image/transfer.png',
					title: '省际经转段达成率',
					index: '4',
					progress: '0',
					table: [],
					worseList: []
				}
			],
        }
    },
    props: {
		initSendCode: {
			String,
			default: '-1'
		},
		businessType: {
			String,
			default: () => {
				return '';
			}
		},
		dateType: {
			String,
			default: () => {
				return '';
			}
		},
		dataDate: {
			String,
			default: () => {
				return '';
			}
		},
		sumLevel: {
			String,
			default: () => {
				return '';
			}
		},
    	defaultColor: {
    		String,
    		default: ()=>{
    			return '';
    		}
    	},
        tablecolumn: {
            Array,
            default: () => {
                return [{
                    label: '封发量',
                    key: 'value',
                }]
            }
        },
        tableHeight: {
        	Number,
        	default: null
        },
        list: {
            Array,
            default: () => {}
        },
        isNo: {
            Boolean,
            default: false
        },
        isLoadMore: {
        	Boolean,
        	default: false
        },
        isBorder: {
        	Boolean,
        	default: false
        },
        notReverse: {
            Boolean,
            default: true
        },
        subByZero: {
            Boolean,
        	default: false
        },
        specialName: {
            Array,
            default: () => {
                return []
            }
        },
        redBy: {
            Object,
        	default: null
        },
    },
    computed: {
    	rowLen: function(){
    		return this.list ? this.list.length : 0;
    	},
    	colLen: function(){
    		return this.tablecolumn ? this.tablecolumn.length : 0;
    	},
    },
	created() {
	},
    methods: {
        getColor(row, item) {
        	if(this.redBy){
        		//红图模式，样式自定
        		return;
        	}
        	if(item.isDrillDown && this.filterDrillDown(row, item)){
        		if(!row.notDrill && row[item.key] != 0){
        			if(this.defaultColor){
        				//如果设置有主色调颜色，下钻单元格问题颜色用主色调,否则用默认
        				return this.defaultColor;
        			}
        			return this.drillColor;
        		}
        	}

        	if(item.compareKey){
                if(row[item.compareKey] != 0){
                	if(this.notReverse){
                		if (row[item.compareKey] > 0) return this.upColor;
                		if (row[item.compareKey] < 0) return this.downColor;
                    }else{
                		if (row[item.compareKey] < 0) return this.upColor;
                		if (row[item.compareKey] > 0) return this.downColor;
                    }
                }
        	}

        	if(item.subByZero){
        		//以0分为2段
        		let val = row[item.key];
                if (val != '-' && parseFloat(val) != 0) {
                    if (this.notReverse && !item.reverse) {
                        if (parseFloat(val) < 0) return this.downColor;
                        if (parseFloat(val) > 0) return this.upColor;
                    } else {
                        if (parseFloat(val) < 0) return this.upColor;
                        if (parseFloat(val) > 0) return this.downColor;
                    }
                }
        	}

        	if(item.subByTarget){
        		//以key分为2段
        		let val = row[item.key];
        		let sub = row[item.subByTarget];
                if (val != '-' && parseFloat(val) != 0) {
                    if (this.notReverse && !item.reverse) {
                        if (parseFloat(val) < sub) return this.downColor;
                        if (parseFloat(val) > sub) return this.upColor;
                    } else {
                        if (parseFloat(val) < sub) return this.upColor;
                        if (parseFloat(val) > sub) return this.downColor;
                    }
                }
        	}

        	if(item.subByKey){
        		//以0和key分为3段
        		let sub = row[item.subByKey];
        		let val = row[item.key];
        		if (val != '-' && parseFloat(val) != 0) {
                    if(val <= 0){
                    	return this.downColor;
                    }else if(val > sub){
                    	return this.upColor;
                    }else{
                    	return this.normalColor;
                    }
        		}
        	}

        	if(item.subDown || parseFloat(item.subDown) === 0){
        		let val = row[item.key];
        		let sub = item.subDown;
                if (val != '-' && parseFloat(val) != 0) {
                    if (this.notReverse) {
                        if (parseFloat(val) < sub) return this.downColor;
                    } else {
                        if (parseFloat(val) < sub) return this.upColor;
                    }
                }
        	}
        	if(item.subUp || parseFloat(item.subUp) === 0){
        		let val = row[item.key];
        		let sub = item.subUp;
                if (val != '-' && parseFloat(val) != 0) {
                    if (this.notReverse) {
                        if (parseFloat(val) > sub) return this.upColor;
                    } else {
                        if (parseFloat(val) > sub) return this.downColor;
                    }
                }
        	}
        	return this.normalColor;
        },
        getValue(val,compareKey,isRate,is10Thousand) {
        	if(val && val.color){
        		//重点区域提速-红图使用
        		val = val.value;
        	}
        	let res;
            if (val === undefined || val === '' || val == null) {
            	res = '-'
            }else if(compareKey && compareKey < 0){
            	res = "-" + val;
            }else{
            	res = val;
            }
            if(isRate && res != '-'){
            	res = res + "%";
            } else if (is10Thousand && res != '-') {
                res = (res / 10000).toFixed(2);
            }
            return res;
        },
        xiazuan(row, item, index) {
			// 原寄地市名称
			
			this.sendName = row.name;
			this.sendCode = row.code;
			this.recvProvCode = item.key;
			this.recvProvName = item.label;

			
			// 当点击的是进口汇总或者出口汇总时，不弹出弹层
			if(this.sendCode == '100000' || this.recvProvCode == '100000') return

			// 出口城市和进口城市一样时，不弹出下钻弹层
			if(this.sendCode == this.recvProvCode) return;
			
			
			//整体达成率
			this.wholeRate = row[item.key].value + '%'
			// console.log(this.recvProvCode, this.sendCode, 'klklkl');
			// 红图弹窗接口
			// row[item.key].value ? (this.drawer = true) : (  );
			
			this.redWindow()

			this.$emit('drilldown', {
				row: row,
				item: item
			});
        },
		redWindow() {
			this.accordionList.forEach(its => {
				its.title = '';
				its.progress = 0;
			})
			vant.Toast.loading({
				message: '加载中...',
				forbidClick: true,
				duration: 10000
			})	
			var timestamp = dayjs().format('YYYY-MM-DD HH:mm:ss');
			const path = '/dpkServer/getRedFigureInfoDetail';
			let params = {
				sendProvCode: this.sendCode,
				recvProvCode: this.recvProvCode,
				sumLevel: '3',
				dataDate: this.dataDate.split('.').join(''),
				dateType: this.dateType,
				businessType: this.businessType,
			};
			const msgbody1 = JSON.stringify(params);
			var interface = axios.create({
				'Access-Control-Allow-Origin': '*',
				baseURL: board_url,
				timeout: 10000,
			})
			
			interface.get(path, {
				params: {
					'sendID': '00000001',
					'timestamp': timestamp,
					'msgBody': msgbody1,
					'dataDigest': base64.encode(hex_md5(msgbody1 + data_key + timestamp))
				}
			}).then(({ data }) => {
				// alert( JSON.stringify(params) )
				if (data.data.length === 0) {
					// this.$message.error('没有查询到符合条件的数据！');
					this.drawer = false;
					return 
				} else {
					this.drawer = true
					// console.log(data.data,'红图弹窗数据');
					data.data.forEach(i => {
						if (i.partType == 1) {
							this.accordionList[0].title = i.partName
							this.accordionList[0].progress = i.rate;
						} else if (i.partType == 2) {
							this.accordionList[1].title = i.partName
							this.accordionList[1].progress = i.rate;
						} else if (i.partType == 3) {
							this.accordionList[2].title = i.partName
							this.accordionList[2].progress = i.rate;
						} else {
							this.accordionList[3].title = i.partName
							this.accordionList[3].progress = i.rate;
						}
					})
				}
			}).catch(err => {
				this.accordionList.forEach(its => {
					its.title = '';
					its.progress = 0;
				})
				console.log(err);
			}).finally(() => {
				this.$nextTick(() => {
					vant.Toast.clear();
					console.log()
					// this.$refs.echarts.initDefault();
				})
			});
		},
        sortMethod(a,b, key,compareKey){
        	let l = a[key];
        	let r = b[key];
			// console.log(a[key])
			// console.log(b[key])
        	if(l == undefined || l == null || l == '') {
				l = -100000000;
        	} else {
            	if(a[compareKey] < 0) {
            		l *= -1;
					console.log(a[compareKey])
            	}
        	}
        	if(r == undefined || r == null || r == '' ) {
        		r = -100000000;
        	} else {
            	if(a[compareKey] < 0) {
            		r *= -1;
					console.log(a[compareKey])
            	}
        	}
        	return r - l;
        },
        changeTableSort({column, prop, order}) {
			// console.log(this.list)
			// console.log(this.specialName)
			if (column.sortable !== 'custom') {
				return;
			}
			let fieldName = prop;
			let sortingType = order;
			console.log(order)
			let list = []			
			list =JSON.parse(JSON.stringify(this.list)) ;
			let orderList = [];
			let freeList = [];
			list.map(it => this.specialName.indexOf(it.name) >= 0 ? freeList.push(it) : orderList.push(it));
			if (sortingType == 'descending') {
				orderList = orderList.sort((a, b) => a[fieldName] - b[fieldName]);
				freeList.push.apply(freeList, orderList);
				// this.list = freeList;
			} else if (sortingType == 'ascending') {
				orderList = orderList.sort((a, b) => b[fieldName] - a[fieldName]);
				freeList.push.apply(freeList, orderList);
				// this.list = freeList;
			} else {
				orderList = orderList.sort((a, b) => a.nameCode > b.nameCode ? 1 : -1);
				freeList.push.apply(freeList, orderList);
				// this.list = freeList;
			}
			this.list = freeList
			// this.$emit('sortList', this.list);
			// this.$emit('sort-list', this.list);
        },
        setColumnWidth(text){
            if (this.tablecolumn.length <= 3) return null;
    		if(!text){
    			return 96;
    		}
    		return 96;
        },
        getPaddingRight(scope, item) {
        	if(item.paddingRight){
        		if(item.paddingRight > 0){
        			return item.paddingRight + 'px';
        		}
        	}
        	if(item.paddingRight < 0 || (!item.width && item.align == 'right')) {
        		let width = (scope.column.realWidth - scope.column.label.length * 12) / 2;
        		if(item.sortable){
        			width += 12;
        		}
        		if(width > 0){
        			return width + 'px';
        		}
        	}
        	if(item.sortable && item.align == 'right') {
        		return '24px';
        	}
        	return '0px';
        },
        // 表头换行
        renderHeader(h, { column, $index }) {
        	var lab = column.label;
        	if(lab.indexOf("|") < 0){
        		return h('span',{},lab)
        	} else {
        		var arr = lab.split('|')
        		const list = [];
        		arr.forEach(item => {
        			list.push(h('span', {}, item));
                    list.push(h('br'));
        		})
        		list.pop()
        		return h('span', {}, list)
        	}
        },
        //特殊名字过滤
        filterDrillDown(row, item){
        	if(this.specialName.indexOf(row.name) >= 0){
        		return false;
        	}
        	return true;
        },
        switchColumn(){
        	this.$emit('switchcolumn', {});
        },
        filterColumn(c){
        	return c.filter(function(item){
        		return item.chose == undefined || item.chose;
        	});
        },
        columnSetConfirm(){
        	Emp.execute("saveColumnSetKnow()");
        },
        getSortIcon(index){
        	if(index == 1){
        		return '../../image/icon_sort_1.png';
        	}else if(index == 2){
        		return '../../image/icon_sort_2.png';
        	}else{
        		return '../../image/icon_sort_3.png';
        	}
        },
		closeDrawer() {
			this.drawer = false
		},
        toggleToast(row,item){
        	let views = this.$refs.toast;
        	let pop;
        	if(views){
        		if(views.length > 1){
        			pop = views[1];
        		}else if(views.length > 0){
        			pop = views[0];
        		}
        	}
        	if(!pop) return;
        	//某个单元格需要点击吐丝提示增加的代码
    		if(this.toastId){
    			clearTimeout(this.toastId);
    		}
        	if(pop.value){
        		pop.value = false;
        	}else{
        		pop.value = true;
        		this.toastId = setTimeout(()=>{
        			pop.value = false;
        			this.toastId = null;
        		},3100);
        	}
        },
        changeCellStyle({row, column, rowIndex, columnIndex}){
        	if(this.redBy){
       		// if(column.property == '140300'){
       		// 	console.log(row[column.property])
       		// }
        		//红图模式
                if(columnIndex === 0){
                    return 'background:#0197FF;color:#fff;text-align:center;';
                }else if(this.redBy.max){
                	if(row[column.property]> this.redBy.max){
                        return 'text-align:right;padding-right:14px;background: #58DEB6;';
                    } else if(row[column.property]< this.redBy.min){
                        return 'text-align:right;padding-right:14px;background: #FF6666;';
                    }else{
                    	return 'text-align:right;padding-right:14px;background: #FFF;';
                    }
                }else if(row[column.property] && row[column.property].color){
                	return 'text-align:right;padding-right:14px;background: ' + row[column.property].color + ';';
                }
        	}
        	return null;
        },
        registerLoadMoreListener(){
        	const selectWrap = document.querySelector('.el-table__body-wrapper');
            selectWrap.addEventListener('scroll', () => {
                const scrollDistance = selectWrap.scrollHeight - selectWrap.scrollTop - selectWrap.clientHeight;
//                console.log(scrollDistance);
                // 同时满足以下情况，加载下一页
                // 1.页面滑动到底部，即scrollDistance = 0
                // 2.页面有滑动的情况，即selectWrap.scrollHeight > selectWrap.clientHeight
                if (scrollDistance <= 2 && selectWrap.scrollHeight > selectWrap.clientHeight) {
                    // 加载更多
                    this.$emit('load-more');
                }
            })
        },
    },
    mounted() {
    	if(this.isLoadMore){ 
    		this.registerLoadMoreListener();
    	}
    },
    template: `<div>
				<el-drawer
					title=""
					:visible.sync="drawer"
					:direction="direction"
					size="250px"
					:with-header="false"
				>
					<div>
						<div style="display:flex;padding:15px 0px 15px 0px;justify-content:center;position:relative;border-bottom:1px solid #ece9ec">
							<span style="font-size: 18px">{{ sendName }}-{{ recvProvName }}</span>
							<span style="font-size: 18px; margin-left:10px;color:#409eff">{{ wholeRate }}</span>
							<div
								@click="closeDrawer"
								style="
									width: 15px;
									height: 5px;
									position: absolute;
									padding: 8px;
									background: no-repeat url(image/closeRed.png) center / 15px;
									right: 14px;
									top: 50%;
									transform: translate(0, -50%);">
							</div>
						</div>  
						<div style="overflow:auto;height: 230px;">
							<el-collapse v-model="activeNames" v-for="item in accordionList" style="position:relative;" accordion>
							<el-collapse-item
								:name="item.index"
								style="border-top:0px"
								:class="{ 'no-arrow': !item.table || item.table.length < 1 }">
									<template slot="title">	
										<div style="display:flex; justify-content:between; align-items:center;">
											<div :style="{backgroundImage: 'url(' + item.img + ')'}" style="background-repeat: no-repeat;
												background-size: 100% 100%;width:30px;height:30px;margin-right:20px">
											</div>
											<div style="width:270px; display:flex;justify-content:center; flex-direction:column">
												<div>{{ item.title }}</div>
												<div style="display: flex; align-items: center;">
													<el-progress id="redPro" :percentage="item.progress" style="width: 250px;"></el-progress> 
													<div style="color: #409eff;font-size: 14px; width: 45px;">
														{{ (item.progress == undefined || item.progress * 1 < 0) ? ' - ' : parseFloat(item.progress).toFixed(2) + '%' }}
													</div>
												</div>
											</div>
										</div>
									</template>
									<div v-for="i in item.table" style="display:flex;justify-content:space-between;background-color:#f0edf1;padding:10px 30px 10px 30px;border-bottom:1px solid #ece9ec;">
										<div style="width: 60px;flex: 0 0 auto;text-align: left;">{{ i.index }}</div>	
										<div>{{ i.sendCityName }}</div>	
										<div style="width: 60px;flex: 0 0 auto;text-align: right;">{{ i.rate }}</div>	
									</div>
								</el-collapse-item>
							</el-collapse>
						</div>
					</div>
					
				</el-drawer>
                <div style="box-sizing: border-box">
                    <div style="padding: 0 2px">
                        <el-table
                                ref="tableActive"
                                :data="list"
                                stripe
                                :border="isBorder"
                                header-cell-class-name="blue-table-header"
                                row-class-name="blue-table-row"
                                :header-cell-style="{background:defaultColor ? defaultColor : '#0199FF',color:'#FFF', height: '30px', 'text-align': 'center', fontSize: '12px', fontWeight: 'normal'}"
                                :row-style="{height:'30px',fontSize: '12px'}"
                                :cell-style="changeCellStyle"
                                :style="[!isLoadMore ? {width: '100%'} : {width: '100%',overflow: 'auto',height: '100vh'}]"
                                :height="tableHeight"
								@sort-change="changeTableSort"
                                >
                            <el-table-column
                                    v-if="isNo"
                                    type="index"
                                    label="序号"
                                    align="center"
                                    fixed
                                    width="50"
                                    >
                            </el-table-column>
                            <el-table-column
                                    v-for="item in filterColumn(tablecolumn)"
                                    :key="item.key"
                                    :prop="item.key"
                                    :fixed="item.fixed ? true : false"
                                    :label="item.label"
                                    label-class-name="headerClass"
                                    :render-header="renderHeader"
                                    :sortable="item.sortable"
									:sort-method="(a,b) => sortMethod(a,b,item.key,item.compareYestKey)"
                                    :width="item.width ? item.width : setColumnWidth(item.label)"
                                    :align="!item.align ? 'center' : item.align">
                                <template slot-scope="scope">
                                	<div v-if="scope.row.toast && item.toast" >
		                                <el-popover ref="toast" :content="scope.row.toast" placement="bottom-start" trigger="manual">
				                        	<span slot="reference" @click="toggleToast(scope.row,item)" :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
				                            	{{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand)}}
				                            </span>
			                            </el-popover>
                                	</div>
		                            <div v-else-if="item.isProgress" :class="scope.row[item.key] > 0 ? 'progressBox positive' : 'progressBox negative'">
			                            <el-progress
			                                :percentage="scope.row[item.key + 'Progress']"
			                                :color="scope.row[item.key] > 0 ? '#00C482' : '#F74627'"
			                                :stroke-width="21"
			                                :show-text="false"
			                            ></el-progress>
			                            <p :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
			                                {{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand)}}
			                            </p>
			                        </div>
                                	<div v-else>
	                        			<img v-if="item.rank && scope.row[item.key] <= 3" style="width:0.16rem; height:0.16rem;" :src="getSortIcon(scope.row[item.key])" >    
		                                <span v-else @click="xiazuan(scope.row, item, scope.$index)" :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
		                                    {{ getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand) }}
		                                </span>
                                	</div>
                                </template>
                            </el-table-column>
                        </el-table>
                    </div>
                </div>
</div>`
});
