/**
 * 此为公共组件
 * @author linwj
 * @desc 非本人不允许修改及复制
 * @time  2020-7-23
 */

/**
 * 自定义表头的表格
 * @author lwj
 */
Vue.component('custom-table', {
    props: {
        refName: {
            String,
            default: 'dialogTable'
        },
        orgXzqh: String,
        tableHeight: {
            String,
            default: () => {
                // 获取页面高度
                const h = document.documentElement.clientHeight || document.body.clientHeight
                // 减去上方区域
                return h-37;
            }
        },
        tableColumn: {
            Array,
            default: () => {
                return []
            }
        },
        moduleList: {
            Array,
            default: () => {
                return []
            }
        },
        showTotal: {
            Boolean,
            default: true
        },
        drillDownKeys: {
            Array,
            default: () => {
                return ['name']
            }
        },
        filterName: {
            Array,
            default: () => {
                return []
            }
        },
        defaultSort: Object,
        onlyDrillName: {
            Array,
            default: () => {
                return []
            }
        },
        rowStyle: {
            Object,
            default: () => {
                return {'font-size': '14px', 'line-height': '30px'}
            }
        },
        headStyle: {
            Object,
            default: () => {
                return {

                }
            }
        }
    },
    data(){
        return {
            dataList: [],
            sortList: [],
            fixedLeft: false
        }
    },
    computed: {
        totalValue(){
            return this.moduleList.find(i => i.nameCode==='total');
        }
    },
    watch: {
        moduleList: {
            handler(newValue, oldValue) {
                //排序图标置空
                this.sortList.forEach(item => {
                    const refs = this.$refs[item.key];
                    refs.forEach(i => {
                        i.style.color = '#666666'
                    })
                });
                if(newValue.length == 0) {
                    this.dataList = [];
                    return
                }
                const sort = this.defaultSort;
                const total = newValue.find(i => i.nameCode === 'total');
                let data = this.showTotal ? newValue.filter(i => i.nameCode !== 'total') : JSON.parse(JSON.stringify(newValue));
                if (sort){
                    //console.log('111');
                    let newdata = sort.sort === 'up' ? data.sort((a,b) => a[sort.key] - b[sort.key]) : data.sort((a,b) => b[sort.key] - a[sort.key])
                    if (this.showTotal && total) newdata.unshift(total);
                    this.dataList = newdata;
                }else{
                    if (this.showTotal && total) data.unshift(total);
                    this.dataList = data
                };
                this.$refs[this.refName].bodyWrapper.scrollTop = 0;
                this.$refs[this.refName].bodyWrapper.scrollLeft = 0;
            },
            immediate: false
        },
        tableColumn: {
            handler(newValue, oldValue) {
                //console.log('更新了');
                this.getSortList(newValue);
                this.fixedLeft = newValue.some(item => item.fixed === 'left')
            },
            immediate: true
        }
    },
    methods: {
        getSortList(newValue){
            this.sortList = newValue.filter(item => item.sort).map(item => {
                return {
                    key: item.key,
                    sort: 0
                }
            });
        },
        getNo(no){
            if (this.showTotal) return no == 0 ? '' : no;
            else return  no + 1
        },
        handleSort(row) {
            if (!row.sort) return;
            //点击列的key
            const key = row.key;
            //0默认排序  1升序 2降序
            this.sortList.forEach(item => {
                const refs = this.$refs[item.key];
                refs.forEach(i => {
                    i.style.color = '#666666';
                });
                if (item.key === key) {
                    const curkey = key === 'name' ? 'nameCode' : key;
                    item.sort++;
                    if (item.sort > 2) item.sort = 0;
                    if (item.sort === 0) {
                        this.sortFun(JSON.parse(JSON.stringify(this.moduleList)))
                    }
                    if (item.sort === 1) {
                        this.sortFun(JSON.parse(JSON.stringify(this.dataList)), {
                            key: curkey,
                            sort: 'up'
                        });
                        if (this.fixedLeft){
                            if (row.fixed == 'left'){
                                this.$refs[item.key][0].style.color = '#FFF';
                                this.$refs[item.key][1].style.color = '#666666'
                            }else{
                                //console.log('222');
                                this.$refs[item.key][2].style.color = '#FFF';
                                this.$refs[item.key][3].style.color = '#666666'
                            }
                        }else{
                            this.$refs[item.key][0].style.color = '#FFF';
                            this.$refs[item.key][1].style.color = '#666666'
                        }
                    }
                    if (item.sort === 2) {
                        this.sortFun(JSON.parse(JSON.stringify(this.dataList)), {
                            key: curkey,
                            sort: 'down'
                        });
                        if (this.fixedLeft){
                            if (row.fixed === 'left'){
                                this.$refs[item.key][0].style.color = '#666666';
                                this.$refs[item.key][1].style.color = '#FFF'
                            }else{
                                this.$refs[item.key][2].style.color = '#666666';
                                this.$refs[item.key][3].style.color = '#FFF'
                            }
                        }else{
                            this.$refs[item.key][0].style.color = '#666666';
                            this.$refs[item.key][1].style.color = '#FFF'
                        }
                    }
                    if (this.showTotal) this.dataList.unshift(this.totalValue)
                }
            });
        },
        handleClick(i, row) {
            if (this.drillDownKeys.indexOf(i.key) < 0 || this.filterName.some(i => i === row.name) || row.nameCode === 'total' || (this.onlyDrillName.length != 0 && !this.onlyDrillName.some(i => i === row.nameCode))) return;
            //console.log('下钻了',row);
            if(i.key == 'name'){
                if(this.orgXzqh && this.orgXzqh!='000000' && this.orgXzqh !='999999' ){
                    if(row.nameCode !=this.orgXzqh) return;
                }
            }
            // if(this.orgXzqh=='000000' || this.orgXzqh =='999999') return;
            this.$emit('drilldown', {
                key: i.key,
                row: row
            })
        },
        getColor(i, row) {
            if(this.orgXzqh){
                if(this.orgXzqh!='000000' && this.orgXzqh!='999999'){
                    if(i.key == 'name' || i.key == 'End10'){
                        if(row.nameCode !== this.orgXzqh) return ''
                    }
                }
            }
            if (i.key == 'name' || i.key == 'sendRate' || i.key == 'wholeRingRate' || i.key == 'rateEnd') {
                if (row.nameCode == 'total' || this.filterName.some(i => i === row.name) || (this.onlyDrillName.length != 0 && !this.onlyDrillName.some(i => i === row.nameCode))) return '';
            }
            const rateColor = i.fontColor ? i.fontColor(row) : '';
            return this.drillDownKeys.indexOf(i.key) < 0 ? rateColor : 'blue'
        },
        translateTextAlign(item) {
            const val = item.headAlign ? item.headAlign : item.align;
            const obj = {
                left: 'flex-begin',
                center: 'center',
                right: 'flex-end;'
            };
            return val ? obj[val] : 'flex-end';
        },
        sortFun(newValue, sort = this.defaultSort){
            let data = this.showTotal ? newValue.filter(i => i.nameCode !== 'total') : newValue;
            if (sort){
                let newdata = sort.sort === 'up' ? data.sort((a,b) => a[sort.key] - b[sort.key]) : data.sort((a,b) => b[sort.key] - a[sort.key])
                //newdata.unshift(total[0]);
                //Vue.set(this.dataList,newdata);
                this.dataList = newdata;
            }else{
                //Vue.set(this.dataList,data);
                this.dataList = data
            }
        }
    },
    template: `<div style="padding: 0 5px">
                    <el-table
                    :ref="refName"
                :data="dataList"
                stripe
                :header-cell-style="{background:'#0199FF',color:'#FFF', height: headStyle['line-height'] ? headStyle['line-height'] : '30px', 'text-align': 'center'}"
                :row-style="{height:'30px'}"
                :height="tableHeight"
                style="width: 100%"
        >
            <el-table-column
                    v-for="item in tableColumn"
                    :prop="item.key"
                    :align="item.align ? item.align : 'right'"
                    :min-width="item.width"
                    :fixed="item.fixed"
            >
                <template slot="header" slot-scope="scope">
                    <div class="table-sort" :style="{'justify-content': translateTextAlign(item), ...headStyle}"  @click="handleSort(item)" style="width: 100%">
                        <span v-html="item.name" style="font-size:12px;font-weight:normal;line-height:20px"  :style="item.colHeadStyle"></span>
                        <div v-if="item.sort" class="table-sort-icon">
                            <i class="el-icon-caret-top"  style="position: absolute; top: 3px;" :ref="item.key"></i>
                            <i class="el-icon-caret-bottom"  style="position: absolute; bottom: 3px" :ref="item.key"></i>
                        </div>
                    </div>
                </template>
                <template slot-scope="scope">
                    <div :style="rowStyle" @click="handleClick(item, scope.row)" v-if="item.key !== 'operate'">
                        <span v-if="item.key === 'no'">{{getNo(scope.$index)}}</span>
                        <span v-else style="display: block;" :style="{color: getColor(item, scope.row), 'margin-right': item.sort ? '10px' : '0'}">
                            {{item.filter ? item.filter(scope.row[item.key]) : scope.row[item.key]}}
                        </span>
                    </div>
                    <slot v-else :row="scope.row"></slot>
                </template>
            </el-table-column>
        </el-table>
               </div>`
});


/**
 * 下拉列表
 * @author lwj
 */
Vue.component('select-list', {
    model: {
        prop: 'msg',
        event: 'change'
    },
    props: {
        msg: String,
        dropdownlist: {
            Array,
            default: () => {
                return []
            }
        }
    },
    computed: {
        title(){
            return this.dropdownlist.find(i => i.val === this.msg).name
        }
    },
    methods: {
        handleCommand(command){
            this.$emit('change', command)
        }
    },
    template: `<div>
                    <el-dropdown trigger="click"  @command="handleCommand">
                        <span class="el-dropdown-link">
                            {{title}}<i class="el-icon-arrow-down el-icon--right"></i>
                        </span>
                        <el-dropdown-menu slot="dropdown">
                            <el-dropdown-item v-for="item in dropdownlist" :command="item.val">{{item.name}}</el-dropdown-item>
                        </el-dropdown-menu>
                    </el-dropdown>
                </div>`
});

