/**
 * 此为公共组件
 * @author linwj
 * @desc 非本人不允许修改及复制
 * @time  2020-7-23
 */

//一级标题盒子
Vue.component('mainBox', {
    data() {
        return {}
    },
    props: {
        title: String
    },
    template: `<div>
                    <div class="box-title">
                        <slot name="icon"></slot>
                        <slot name="iconImg"></slot>
                        {{title}}
                    </div>
                    <div class="base-box"><slot></slot></div>   
                </div>`
});


//二级标题盒子
Vue.component('baseBox', {
    data() {
        return {}
    },
    props: {
        isShowTitle: {
            Boolean,
            default: true
        },
        isTitle: {
            Boolean,
            default: true
        },
        title: String,
        list: {
            Array,
            default: () => {
                return []
            }
        },
        itemWidth: {
            String,
            default: ''
        },
        isShowBottom: {
            Boolean,
            default: true
        },
        backColor: {
            String,
            default: '#FFF'
        },
        itemNum: Number
    },
    filters: {
        addSpot(val) {
            if (val.toString().indexOf('.') !== -1 || val.toString().indexOf('%') !== -1 || val.toString().indexOf('-') !== -1) return val
            let source = val.toString()
            if (source.length < 4) return source;
            let arr = [...source];
            let len = arr.length / 3;
            let newArr = [];
            for (let i = 0; i < len; i++) {
                let start = arr.length - 3 * (i + 1)
                let b = []
                if (start < 0) b = arr.slice(0, arr.length % 3);
                else b = arr.slice(start, arr.length - 3 * i);
                newArr.push(b.join(''));
            }
            return newArr.reverse().join(',');
        }
    },
    methods: {
        drillDown(index, v) {
            if (v == 0) return
            this.$emit('drilldown', index)
        },
        chonseColor(rale, val) {
            if (rale !== true) return '#249BF5'
            if (val == 0) return '#249BF5'
            if (val > 0) {
                return 'red'
            } else {
                return '#4CD997'
            }


        }
    },
    template: `<div>
                    <div 
                        :class="{'base-box-title': true,'base-box-istitle': isTitle}"
                        v-if="isShowTitle" 
                        :style="{'background-color': backColor, fontSize: '16px'}">
                        <slot name="icon"></slot>
                        {{title}}
                    </div>
                   
                    <div class="base-box-list" :style="{'border-bottom': isShowBottom ? '1px solid #e6e6e6' : 'none'}">
                        <div 
                                v-for="(i,index) in list" 
                                :style="{
                                    width: itemWidth === '' ? 100/list.length+'%' : itemWidth, 
                                    'box-sizing': 'border-box'
                                }" 
                                :class="{
                                    borderDashed: itemWidth === '' ? index !== list.length - 1 : (index+1)%itemNum !== 0, 
                                    borderBottom: itemWidth === '' ? false : index < itemNum
                                }"
                         >
                            <div style="text-align: center; padding: 0 2px;">
                                <p v-if="i.isStrong !== true" style="font-size: 12px">{{i.name}}</p>
                                <p v-else style="font-size: 14px;font-weight:900;":style="{'color': i.isGray ?'#666666 ':'#0F9CDB'}">{{i.name}}</p>
                                <p 
                                    @click="drillDown(index,i.value)" 
                                    :style="{
                                        'font-size': i.isBiggerNum === true ? '20px' : '14px',
                                        'color': chonseColor(i.isRale,i.value),
                                        'font-weight': 'bold'
                                    }"
                                >
                                    <i v-if="i.isRale === true" :class="{'el-icon-caret-top': Number(i.value) >= 0, 'el-icon-caret-bottom': Number(i.value)<0}"></i>
                                    {{i.value | addSpot}}
                                </p>
                            </div>    
                        </div>    
                    </div>
                    <slot></slot>
                </div>`
});

//带下拉的盒子
Vue.component('drillBox', {
    data() {
        return {}
    },
    props: {
        isShowLeft: {
            Boolean,
            default: false
        },
        isShowRight: {
            Boolean,
            default: false
        },
        title: String,
        drillLeft: {
            Array,
            default: () => {
                return []
            }
        },
        drillRight: {
            Array,
            default: () => {
                return []
            }
        },
        defalutLeftLabel: {
            String,
            default: '默认值'
        },
        defalutRightLabel: {
            String,
            default: '默认值'
        },
        backColor: {
            String,
            default: '#D1EAFE'
        },
        boder: {
            Boolean,
            default: false
        },
        isOneTitle: {
            Boolean,
            default: false
        },
        titleSty: {
            Object,
            default: () => {
                return {
                    width: '150px',
                    minHeight: '40px',
                    lineHeight: '20px'
                }
            }
        },
        tipContent: {
            String,
            default: ''
        }
    },
    methods: {
        clickLeftMunu(val) {
            this.$emit('getleftval', val)
        },
        clickRightMunu(val) {
            this.$emit('getrightval', val)
        }
    },
    template: `<div>
                    <div 
                            :class="['drill-box',isOneTitle === false ? 'is-two-title' : 'is-one-title']" 
                            :style="{'background-color': backColor}"
                            style="display: flex; justify-content: center"
                    >
                        <div :style="titleSty" style="display: flex; align-items: center; justify-content: center">
                             <span :style="{'font-weight': 'bold', fontSize: '16px'}">{{title}}</span>
                             <el-tooltip v-if="tipContent !== ''" class="item" effect="light" :content="tipContent" placement="bottom">
                                <i class="el-icon-info" style="color: yellow"></i>
                             </el-tooltip>
                        </div>
                        <div style="position: absolute; left: 15px; top: 0" v-if="isShowLeft">
                            <el-dropdown @command="clickLeftMunu" :trigger="'click'" ref="lll">
                                <span class="el-dropdown-link">
                                    {{defalutLeftLabel}}<i class="el-icon-caret-bottom" style="margin-top: -13px"></i>
                                </span>
                                <el-dropdown-menu slot="dropdown">
                                    <el-dropdown-item v-for="i in drillLeft" :command="i.value">
                                        {{i.name}}
                                    </el-dropdown-item>
                                </el-dropdown-menu>
                            </el-dropdown>
                        </div>
                        <div style="position: absolute; right: 15px; top: 0" v-if="isShowRight">
                            <el-dropdown @command="clickRightMunu" :trigger="'click'" ref="lll">
                                <span class="el-dropdown-link">
                                    {{defalutRightLabel}}<i class="el-icon-caret-bottom" style="margin-top: -13px"></i>
                                </span>
                                <el-dropdown-menu slot="dropdown">
                                    <el-dropdown-item v-for="i in drillRight" :command="i.value">
                                        {{i.name}}
                                    </el-dropdown-item>
                                </el-dropdown-menu>
                            </el-dropdown>
                        </div>
                    </div>
                    <div :class="{ 'base-box': boder }">
                        <slot></slot>    
                    </div>
               </div>`
});

//折线图
Vue.component('lineBox', {
    data() {
        return {}
    },
    props: {
        idName: String,
        isShowDataZoom: {
            Boolean,
            default: false
        },
        unit: {
            String,
            default: '万件'
        }
    },
    methods: {
        initLine(legend, xData, values, legendSet, color) {
            let series = [];
            legend.forEach((e, index) => {
                let setting = {
                    name: '收入',
                    type: 'line',
                    data: [22, 26, 121, 134, 165, 112, 132],
                    symbolSize: 10,
                    symbol: 'circle',
                    itemStyle: {
                        normal: {
                            color: '#1D95F4',
                            barBorderRadius: 1,
                            borderColor: '#fff',
                            borderWidth: 2
                        }
                    },
                    lineStyle: {
                        normal: {
                            color: '#1D95F4',
                            width: 2
                        }
                    },
                    smooth: true
                }
                setting.name = e;
                setting.data = values[index]
                setting.itemStyle.normal.color = color[index];
                setting.lineStyle.normal.color = color[index];
                series.push(setting)
            })
            this.initZheXian(this.idName, legend, xData, series, legendSet)
        },
        initZheXian(id, legend, xData, series, legendSet = [5, 10]) {
            const _this = this;
            let mychart2 = echarts.init(document.getElementById(id))
            mychart2.clear();
            let option2 = {
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    }
                },
                legend: {
                    //type:scroll,
                    data: legend,
                    bottom: legendSet[0],
                    itemGap: legendSet[1],
                    width: legend.length >= 6 ? 360 : 240
                },
                grid: {
                    top: '13%',
                    left: '3%',
                    right: '4%',
                    bottom: legend.length >= 6 ? '30%' : '18%',
                    containLabel: true
                },
                xAxis: [{
                    type: 'category',
                    data: xData,
                    'axisLine': {
                        lineStyle: {
                            color: '#90979c'
                        }
                    },
                    'splitLine': {
                        'show': false
                    },
                    'axisTick': {
                        'show': true
                    },
                    'splitArea': {
                        'show': false
                    },
                    'axisLabel': {
                        'interval': 0
                    }
                }],
                yAxis: [{
                    name: this.unit,
                    type: 'value',
                    //name: '及时数',
                    axisLine: {
                        show: false
                    },
                    'axisTick': {
                        'show': false
                    },

                    axisLabel: {
                        margin: 2,
                        formatter: function (value, index) {
                            if (value >= 10000 && value < 100000000) {
                                value = value / 10000 + '万'
                            } else if (value >= 100000000) {
                                value = value / 10000000 + '亿'
                            }
                            return value
                        }
                    }
                }],
                'dataZoom': [{
                    show: _this.isShowDataZoom,
                    height: 20,
                    bottom: 10,
                    startValue: 0,
                    endValue: xData.length > 6 ? 6 : xData.length - 1,
                    /*maxValueSpan: 6,
                    mixValueSpan: 6,*/
                    handleStyle: { //滚动条样式
                        color: '#d3dee5'
                    },
                    textStyle: { //文本提示样式
                        color: '#1D95F4'
                    },
                    borderColor: '#90979c'
                }],
                series: series
            }

            mychart2.setOption(option2, true)
        }
    },
    template: `<div>
                    <div :id="idName" style="width: 100%; height: 300px">                   
                </div>`
});


//水球图
Vue.component('liquidBox', {
    data() {
        return {}
    },
    methods: {
        drillDown() {
            this.$emit('drilldown')
        },
        initLiquid(curvalue = 0, color = '#1D95F4') {
            document.getElementById(`${this.idName}`).innerHTML = '';
            let chart = new G2.Chart({
                container: this.idName,
                forceFit: true,
                height: Number(this.contains.height.split('p')[0]),
                padding: 0
            });
            chart.source(
                [{
                    gender: 'male',
                    value: curvalue
                }], {
                    value: {
                        min: 0,
                        max: 100
                    }
                });
            chart.legend(false);
            chart.axis(false);
            chart.interval().position('gender*value').color(color)
                .shape('liquid-fill-gauge').style({
                lineWidth: 2,
                opacity: .5,
                padding: 5
            });
            chart.tooltip(false);
            chart.guide().text({
                top: true,
                position: {
                    gender: 'male',
                    value: 50
                },
                content: curvalue ? curvalue + '%' : '--',
                style: {
                    opacity: 0.75,
                    fontSize: '14',
                    textAlign: 'center',
                    fill: curvalue >= 60 ? '#FFF' : '#000'
                }
            });
            chart.render();
        }
    },
    props: {
        idName: String,
        title: {
            String,
            default: ''
        },
        contains: {
            Object,
            default: () => {
                return {
                    height: '100px',
                    width: '100%',
                    'max-width': '150px'
                }
            }
        }
    },
    template: `<div>
                    <div style="display: flex; justify-content: center">
                        <div :style="contains" :id="idName" @click="drillDown" ></div>
                    </div>
                    <p v-if="title">{{title}}</p>
                </div>`
});


//饼图
Vue.component('pieBox', {
    data() {
        return {
            total: 0
        }
    },
    methods: {
        initPie(data = []) {

            const _this = this;
            let obj = {}
            data.forEach(e => {
                obj[e.name] = true
            });
            let nameData = [];
            let valueData = [];
            let dictData = [];
            let colorData = [];
            let mychart = echarts.init(document.getElementById(_this.idName));
            var option = {
                legend: {
                    bottom: 0,

                    data: data.map((e) => {
                        nameData.push(e.name);
                        valueData.push(e.value)
                        colorData.push(e.itemStyle.color)
                        return e.name
                    })
                },

                graphic: [{
                    type: 'text',
                    left: 'center',
                    top: this.marginTop,
                    style: {
                        text: valueData.reduce((i, n) => {
                            return Number(i) + Number(n)
                        }, 0) || '--', // 数值为0时，显示'--'
                        textAlign: 'center',
                        fill: '#0099FF',
                        width: 30,
                        height: 30,
                        fontSize: 20,
                        fontWeight: 700,

                    }
                }, {
                    type: 'text',
                    left: 'center',
                    top: this.marginTop + 25,
                    style: {
                        text: this.centerText,
                        textAlign: 'center',
                        fill: '#000',
                        width: 30,
                        height: 30,
                        fontSize: 13,
                        fontWeight: 700
                    }
                }],
                tooltip: {
                    trigger: 'item',
                    confine: true,
                    formatter: '{a} <br/>{b}: {c} ({d}%)'
                },
                series: [{
                    name: '逾限量',
                    type: 'pie',
                    radius: ['50%', '60%'],
                    center: ['50%', '40%'],
                    label: {
                        show: true,
                        position: 'outside',
                    },
                    color: colorData,
                    data: data,
                    itemStyle: {
                        labelLine: {
                            show: true
                        },
                        normal: {
                            label: {
                                textStyle: {
                                    // color: 'black',
                                    fontSize: 14,
                                    fontWeight: 600
                                },
                                labelLine: {
                                    lineStyle: {
                                        color: 'black'
                                    }
                                },
                                formatter: (param) => {
                                    let font = param.data.name;
                                    let list = font.split('');
                                    let value = param.data.value || '--'
                                    if (list.length <= 3) return list.join('') + '\n' + value;
                                    else {
                                        let list1 = []
                                        let num = list.length / 3
                                        for (let i = 0; i < num; i++) {
                                            list1.push(list.splice(0, 3).join(''))
                                        }
                                        return list1.join('\n') + '\n' + value;
                                    }
                                },
                            },
                        },

                        emphasis: {
                            itemStyle: {
                                shadowBlur: 10,
                                shadowOffsetX: 0,
                                shadowColor: 'rgba(0, 0, 0, 0.5)'
                            }
                        }
                    },
                }]
            };
            mychart.setOption(option, true);
        }
    },
    props: {
        idName: String,
        title: {
            String,
            default: ''
        },
        boxHeight: {
            String,
            default: '250px'
        },
        marginTop: {
            Number,
            default: 85
        },
        centerText: {
            String,
            default: '总量'
        }

    },
    template: `<div style="min-height: 100px; ">
                    <div style="display: flex; justify-content: center">
                        <div :id="idName" :style="{'width': '100%', 'height': boxHeight}"></div>
                    </div>
                    <p>{{title}}</p>
                </div>`
});


//柱形图
Vue.component('barBox', {
    data() {
        return {
            total: 0
        }
    },
    methods: {
        initBar(data = {
            xData: ['2019Q1', '2019Q2', '2019Q3', '2019Q4'],
            legend: '人数',
            values: [40, 80, 20, 16],
            colors: ['#2699F4', '#75C3EC'],
            name: '车辆数',
            xFontSize: 12,
            xRotate: 0
        }) {
            const _this = this;
            let mychart = echarts.init(document.getElementById(_this.idName));
            var option = {
                grid: {
                    top: '15%',
                    left: '3%',
                    right: '4%',
                    bottom: '12%',
                    containLabel: true
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: { // 坐标轴指示器，坐标轴触发有效
                        type: 'shadow' // 默认为直线，可选为：'line' | 'shadow'
                    },
                    formatter: '{b}: {c}'
                },
                legend: {
                    orient: 'horizontal',
                    bottom: 0,
                    itemWidth: 15,
                    itemHeight: 11,
                    itemGap: 20,
                    borderRadius: 4,
                    textStyle: {
                        color: '#262C41',
                        fontSize: 14
                    },
                    data: [data.legend]
                },
                xAxis: [{
                    type: 'category',
                    color: '#59588D',
                    data: data.xData,
                    axisLabel: {
                        rotate: data.xRotate ? data.xRotate : 0,
                        margin: 20,
                        textStyle: {
                            fontSize: data.xFontSize
                        },
                        formatter: (val) => {
                            if (val.length > 6) return val.substring(0, 6) + '...'
                            else return val
                        }
                    },
                    axisTick: {
                        show: true
                    }
                }],
                yAxis: [{
                    name: data.name,
                    axisLabel: {
                        formatter: '{value}',
                        textStyle: {
                            fontSize: 12
                        },
                    },
                    axisLine: {
                        show: false,
                    },
                    axisTick: {
                        show: false
                    },

                }],
                series: [{
                    name: data.legend,
                    type: 'bar',
                    data: data.values || '--',
                    barWidth: '29px',
                    itemStyle: {
                        normal: {
                            color: function (params) { //展示正值的柱子，负数设为透明
                                let colorArr = params.value > 0 ? data.colors : ['rgba(0,0,0,0)', 'rgba(0,0,0,0)']
                                return new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
                                    offset: 0,
                                    color: colorArr[0] // 0% 处的颜色
                                }, {
                                    offset: 1,
                                    color: colorArr[1] // 100% 处的颜色
                                }], false)
                            },
                            barBorderRadius: [30, 30, 0, 0]
                        },
                    }
                }]
            };
            mychart.setOption(option, true);
        }
    },
    props: {
        idName: String,
        title: {
            String,
            default: ''
        }
    },
    template: `<div style="min-height: 100px; ">
                    <div style="display: flex; justify-content: center; padding: 0 5px">
                        <div :id="idName" style="width: 100%; height: 300px;"></div>
                    </div>
                    <p>{{title}}</p>
                </div>`
});

//指标下钻
Vue.component('drillDownBox', {
    data() {
        return {
            style1: {
                color: '#3377FF'
            },
            style2: {
                color: '#333333'
            },
            sortType: true,
            upColor: '#FA2525', // 上升颜色
            downColor: '#009900' // 下降颜色
        }
    },
    props: {
        tablecolumn: {
            Array,
            default: () => {
                return [{
                    label: '封发量',
                    key: 'value',
                    sortable: true,
                    isDrillDown: true,
                    width: 90
                }, {
                    label: '昨天值',
                    key: 'zrz',
                    sortable: false,
                    isDrillDown: false,
                    width: 90
                }, {
                    label: '昨日同比',
                    key: 'zrtb',
                    sortable: false,
                    isDrillDown: false,
                    isRate: true,
                    width: 90
                }]
            }
        },
        title: {
            String,
            default: '省份'
        },
        list: {
            Array,
            default: () => {
                return [{
                    name: '北京市',
                    value: '36',
                    zrtb: 0
                }]
            }
        },
        isDrillDown: {
            Boolean,
            default: true
        },
        isNo: {
            Boolean,
            default: true
        },
        notReverse: {
            Boolean,
            default: true
        },
        defaultSort: {
            Object,
            default: () => {
                return {
                    prop: 'nameCode',
                    order: 'ascending'
                }
            }
        },
        echartName: {
            String,
            default: ''
        },
        valueName: {
        	String,
        	default: ''
        },
        isShowLine: {
            Boolean,
            default: false
        },
        valueMax: {
            String,
            default: null
        },
        specialName: {
            Array,
            default: () => {
                return ['总计','其他']
            }
        }
    },
    computed: {
        x_data() {
            const newList = this.list.sort((i, n) => {
                return Number(i.nameCode) - Number(n.nameCode)
            });
            const arr = this.list.filter(e => e.name !== '总计')
            return arr.map(i => i.name);
        },
        value_data() {
            console.log(this.list);
            const newList = this.list.sort((i, n) => {
                return Number(i.nameCode) - Number(n.nameCode)
            });
            const arr = this.list.filter(e => e.name !== '总计')
            return arr.map(i => i.value);
        }
    },
    methods: {
        getColor(val) {
            if (val === '-' || parseFloat(val) == 0) return '';
            if (this.notReverse) {
                if (parseFloat(val) < 0) return this.downColor;
                if (parseFloat(val) > 0) return this.upColor;
            } else {
                if (parseFloat(val) < 0) return this.upColor;
                if (parseFloat(val) > 0) return this.downColor;
            }
        },
        getValue(val,compareKey) {
            if (val === undefined || val == '' || val == null) {
            	return '-'
            }else{
            	if(compareKey && compareKey < 0){
            		return "-" + val;
            	}
            	return val
            }
        },
        xiazuan(item, key) {
            if (key === 'name') {
                if (!this.isDrillDown || !this.filterDrillDown(item.name)) return;
                this.$emit('drilldown', {
                    item: item,
                    key: key
                })
            } else {
                if (key.isDrillDown && item[key.key] != 0) {
                    this.$emit('drilldown', {
                        item: item,
                        key: key.key
                    })
                }
            }
        },
        zxtSort() {
        	
            if (this.sortType) {
                this.sortType = !this.sortType
                let dataList = [];
                this.x_data.forEach((v, i) => {
                    dataList.push({
                        name: v,
                        value: this.value_data[i]
                    })
                });
                const sortList = dataList.sort((i, n) => {
                    return Number(i.value) - Number(n.value)
                });
                const x_data = sortList.map(i => i.name);
                const value_data = sortList.map(i => i.value);
                this.initEcharts2(x_data, value_data);
            } else {
                this.sortType = !this.sortType
                let dataList = [];
                this.x_data.forEach((v, i) => {
                    dataList.push({
                        name: v,
                        value: this.value_data[i]
                    })
                });
                const sortList = dataList.sort((i, n) => {
                    return Number(i.value) - Number(n.value)
                }).reverse();
                const x_data = sortList.map(i => i.name);
                const value_data = sortList.map(i => i.value);
                this.initEcharts2(x_data, value_data);
            }
        },
        sortMethod(a,b,key,compareKey){
        	let l = a[key];
        	let r = b[key];
        	if(l == undefined || l == null || l == ''){
        		l = -100000000;
        	}else{
            	if(a[compareKey] < 0){
            		l *= -1;
            	}
        	}
        	if(r == undefined || r == null || r == ''){
        		r = -100000000;
        	}else{
            	if(b[compareKey] < 0){
            		r *= -1;
            	}
        	}
        	return r - l;
        },
        initDefault() {
            document.documentElement.scrollIntoView();
            const newList = this.list.sort((i, n) => {
                return Number(i.nameCode) - Number(n.nameCode)
            });
            const arr = newList.filter(e => e.name !== '总计')
            const xData = arr.map(i => i.name);
            const valueData = arr.map(i => i.value);
            this.initEcharts2(xData, valueData)
        },
        initEcharts2(xData, valueData) {
            const _this = this
            let mychart2 = echarts.init(document.getElementById('chart2'));
            let option2 = {
                title: {
                    text: _this.echartName,
                },
                color: ['#0199FF'],
                tooltip: {
                    trigger: 'axis',
                    axisPointer: { // 坐标轴指示器，坐标轴触发有效
                        type: 'shadow' // 默认为直线，可选为：'line' | 'shadow'
                    },
                    formatter: '{b}: {c}'
                },
                grid: {
                    top: '20%',
                    left: '4%',
                    right: '4%',
                    bottom: '15%',
                    containLabel: true
                },
                xAxis: [{
                    type: 'category',
                    nameGap: 30,
                    data: xData,
                    "axisLine": {
                        lineStyle: {
                            color: '#90979c'
                        }
                    },
                    "splitLine": {
                        "show": false
                    },
                    "axisTick": {
                        "show": false
                    },
                    "splitArea": {
                        "show": false
                    },
                    "axisLabel": {
                        interval: 0,
                        rotate: 40,
                        formatter: (val) => {
                            if (val.length > 6) return val.substring(0, 6) + '...'
                            else return val
                        }

                    }
                }],
                yAxis: [{
                    type: 'value',
                    name: _this.valueName,
                    nameTextStyle: {
                    	fontSize: 11,
                    },
                    max: _this.valueMax,
                    axisLine: {
                        show: false
                    },
                    axisTick: {
                        show: false
                    },
                    axisLabel: {
                        formatter: (val) => {
                            if (Number(val) >= 10000) return (Number(val) / 10000).toFixed(1) + '万'
                            else return val
                        }

                    }
                }],

                "dataZoom": [{
                    "show": true,
                    "height": 30,
                    "xAxisIndex": [
                        0
                    ],
                    bottom: 10,
                    startValue: 0,
                    endValue: valueData.length > 6 ? 6 : valueData.length - 1,
                    maxValueSpan: 6,
                    mixValueSpan: 6,
                    handleIcon: 'path://M306.1,413c0,2.2-1.8,4-4,4h-59.8c-2.2,0-4-1.8-4-4V200.8c0-2.2,1.8-4,4-4h59.8c2.2,0,4,1.8,4,4V413z',
                    handleSize: '110%',
                    handleStyle: {
                        color: "#d3dee5",

                    },
                    textStyle: {
                        color: "#0199FF"
                    },
                    borderColor: "#90979c"
                }, {
                    "type": "inside",
                    "show": true,
                    "height": 15,
                    "start": 1,
                    "end": 0
                }],
                series: [{
                    name: _this.valueName,
                    type: 'bar',
                    barWidth: 30,
                    barGap: 20,
                    color: '#0199FF',
                    data: valueData,
                    label: {
                        normal: {
                            show: 'true',
                            position: 'inside',
                            // position:'top',
                            rotate: 45,
                            fontSize: 10,
                            color: "#FFFFFF"
                        }
                    },
                }],
            }
            mychart2.setOption(option2, true);

        },
        setWidth() {
            const width = this.title.length > 2 ? 120 : 80;
            if (this.tablecolumn.length === 1) return null;
            else return width
        },
        setColumnWidth(text){
    		if(!text){
    			return 106;
    		}
    		return 106;
//    		const len = text.length;
//    		if(len <= 2){
//    			return 80;
//    		}else{
//    			return 80 + 12 * (len - 2);
//    		}
        },
        // 对比昨天，获取颜色
        getColorByCompareYest(row, item) {
            // 检验昨日值字段
            if (!item.compareYestKey) {
            	return ''
            }
            if(row[item.compareYestKey] == 0){
            	return ''
            }
            if(this.notReverse){
            	return row[item.compareYestKey] > 0 ? this.upColor : this.downColor
            }else{
            	return row[item.compareYestKey] < 0 ? this.upColor : this.downColor
            }
            
        },
        // 表头换行
        renderHeader(h, { column, $index }) {
        	var lab = column.label;
        	if(lab.indexOf("|") < 0){
        		return h('span',{},lab)
        	}else{
        		var arr = lab.split('|')
        		const list = [];
        		arr.forEach(item => {
        			list.push(h('span', {}, item));
                    list.push(h('br'));
        		})
        		list.pop()
        		return h('span', {}, list)
        	}
        },
        //特殊名字过滤
        filterDrillDown(name){
            if (this.specialName.indexOf(name) < 0) return true;
            else return false
        },
    },
    mounted() {
        const h = document.documentElement.clientHeight || document.body.clientHeight;
        document.getElementById('chart2').style.height = h / 2 + 'px';
    },
    template: `<div>
                <div style="box-sizing: border-box">
                    <div style="padding: 10px 5px; position: relative" v-show="isShowLine">
                        <div class="tip">
                            <el-tooltip class="item" effect="light" hide-after="2000" content="排序" placement="bottom">
                                <span style="font-size: 26px; color: #2d8cf0" class="iconfont icon-paixu" @click="zxtSort"></span>
                            </el-tooltip>
                        </div>
                        <div id="chart2" style="background-color: #FFF; width: 100%"></div>
                    </div>
        
                    <div style="padding: 0 2px">
                        <el-table
                                :data="list"
                                stripe
                                :header-cell-style="{background:'#0199FF',color:'#FFF', height: '30px', 'text-align': 'right', fontSize: '12px', fontWeight: 'normal'}"
                                :row-style="{height:'30px',fontSize: '12px'}"
                                :default-sort="defaultSort"
                                style="width: 100%"
                        >
                            <el-table-column
                                    v-if="isNo"
                                    type="index"
                                    label="序号"
                                    align="center"
                                    fixed
                                    width="50"
                            >
                            </el-table-column>
                            <el-table-column
                                    prop="nameCode"
                                    :label="title"
                                    fixed
                                    sortable
                                    :width="setWidth()"
                                    align="center">
                                <template slot-scope="scope">
                                    <span :style="[isDrillDown && filterDrillDown(scope.row.name) ? style1 : style2 ]"
                                          @click="xiazuan(scope.row, 'name')">{{scope.row.name}}</span>
                                </template>
                            </el-table-column>
                            <el-table-column
                                    v-for="item in tablecolumn"
                                    :key="item.key"
                                    :prop="item.key"
                                    :label="item.label"
                                    label-class-name="headerClass"
                                    :render-header="renderHeader"
                                    :sortable="item.sortable"
                                    :sort-method="(a,b) => sortMethod(a,b,item.key,item.compareYestKey)"	
                                    :width="item.width ? item.width : setColumnWidth(item.label)"
                                    :align="!item.align ? 'right' : item.align">
                                <template slot-scope="scope">
	                                	<!--如果是率-->
	                                    <span v-if="!item.isDrillDown" :class="item.sortable ? 'paddingR24' : ''" :style="{color: getColorByCompareYest(scope.row,item),fontWeight: item.isNumber ? 'normal' : 600}">
	                                        {{getValue(scope.row[item.key],scope.row[item.compareYestKey]) == '-' ? '-' : getValue(scope.row[item.key],scope.row[item.compareYestKey]) + (item.isRate ? "%" : '')}}
	                                    </span>
	                                    <!--如果需要对比昨日值，显示不同颜色--> 
	                                    <!--其他--> 
	                                    <span v-else @click="xiazuan(scope.row, item)"  :class="item.sortable ? 'paddingR24' : ''" :style="[item.isDrillDown && scope.row[item.key] != 0 ? style1 : style2 ]">
	                                        {{getValue(scope.row[item.key],scope.row[item.compareYestKey])}}
	                                    </span>
                                </template>
                            </el-table-column>
                        </el-table>
                    </div>
                </div>
</div>`
});


//
/**
 * 可分页加载的数据列表
 * @author qs
 * @time 20200811
 *
 * @desc 待开发以下内容
 *
 */
Vue.component('pageLoadList', {
    data() {
        return {
            style1: {
                color: '#0199FF',
            },
            style2: {
                color: '#000000'
            }
        }
    },
    props: {
        // 列表数据
        list: {
            Array,
            default: () => {
                return [
                    {name: '--', value: '--'}
                ]
            }
        },
        //
        title: {
            String,
            default: '标题'
        },
        // 表格内容
        tablecolumn: {
            Array,
            default: () => {
                return [
                    {label: '编号', key: 'id', sortable: true, isDrillDown: true, width: 90, show: true},
                    {label: '标题', key: 'title', sortable: true, isDrillDown: true, width: 90},
                    {label: '数值', key: 'value', sortable: true, isDrillDown: true, width: 90},
                ]
            }
        },
        // 是否显示序号
        isNo: {
            Boolean,
            default: false
        },
        // 当前页数
        pageNum: {
            Number,
            default: 1
        },
        // 每页显示数据（最小为25）
        pageSize: {
            Number,
            default: 25
        }
    },
    filters: {
        valueFilter(val) {
            if (!val) return '--'
            return val
        }

    },
    methods: {
        xiazuan(row, column) {
            if (column.isDrillDown) {
                this.$emit('drilldown', {
                    row,
                    column
                })
            }
        },
        // 换行时间
        dealTime(val) {
            if (!val) return '--'
            const arr = val.split(' ')
            return arr.join('<br>')
        }
    },
    mounted() {
        console.log(this.list)
        console.log(this.tablecolumn)
        const selectWrap = document.querySelector('.el-table')

        selectWrap.addEventListener('scroll', () => {
            const scrollDistance = selectWrap.scrollHeight - selectWrap.scrollTop - selectWrap.clientHeight
            // 同时满足以下情况，加载下一页
            // 1.页面滑动到底部，即scrollDistance = 0
            // 2.页面有滑动的情况，即selectWrap.scrollHeight > selectWrap.clientHeight
            if (scrollDistance <= 0 && selectWrap.scrollHeight > selectWrap.clientHeight) {
                // alert(`scrollHeight:${selectWrap.scrollHeight},,scrollTop:${selectWrap.scrollTop},,clientHeight:${selectWrap.clientHeight},`)
                // 加载更多
                this.$emit('more-data')
            }
        })
    },
    template: `
    <div style="box-sizing: border-box;">
        <div style="padding: 0 2px;">
            <el-table
                    :data="list"
                    stripe
                    :header-cell-style="{background:'#0199FF',color:'#FFF', height: '50px'}"
                    :row-style="{height:'30px'}"
                    style="width: 100%;overflow:auto;height:100vh;"
            >
                <el-table-column
                    v-if="isNo"
                    type="index"
                    label="序号"
                    align="center"
                    width="50"
                >
                </el-table-column>
                <el-table-column
                    align="center"
                    v-for="item in tablecolumn"
                    v-if="item.show != false"
                    :key="item.key"
                    :prop="item.key"
                    :label="item.label"
                    :sortable="item.sortable"
                    :width=" item.width ? item.width: '' "
                >
                    <template slot-scope="scope">

                        <span v-if="item.type != 'time'" @click="xiazuan(scope.row, item)" :style="[item.isDrillDown ? style1 : style2 ]">
                            {{ scope.row[item.key] | valueFilter() }}
                        </span>
                        <span v-else v-html="dealTime(scope.row[item.key])"></span>
                    </template>
                </el-table-column>
            </el-table>
        </div>
    </div>
    `
})


//环形图
Vue.component('annularBox', {
    data() {
        return {
            total: 0
        }
    },
    methods: {
        initBar(datas = {
            value: 78,
            company: "%",
            color: 'blue',
            fontSize: 20
        }) {
            const _this = this;
            let mychart = echarts.init(document.getElementById(_this.idName));
            var option = {
                title: {
                    text: datas.value + datas.company,
                    x: 'center',
                    y: 'center',
                    textStyle: {
                        fontWeight: 'bold',
                        color: datas.color,
                        fontSize: datas.fontSize
                    }
                },
                color: ['#e6e6e6'],
                legend: {
                    show: false,
                    data: []
                },

                series: [{
                    name: 'Line 1',
                    type: 'pie',
                    clockWise: true,
                    radius: ['60%', '70%'],
                    itemStyle: {
                        normal: {
                            label: {
                                show: false
                            },
                            labelLine: {
                                show: false
                            }
                        }
                    },
                    hoverAnimation: false,
                    data: [{
                        value: datas.value,
                        name: '',
                        itemStyle: {
                            normal: {
                                color: datas.color,
                                label: {
                                    show: false
                                },
                                labelLine: {
                                    show: false
                                }
                            }
                        }
                    }, {
                        name: '',
                        value: 100 - datas.value
                    }]
                }]
            };
            mychart.setOption(option, true);
        }
    },
    props: {
        idName: String,
        containsSty: {
            Object,
            default: {
                width: '100%',
                height: '100px'
            }
        }
    },
    template: `<div style="min-height: 100px; ">
                    <div style="display: flex; justify-content: center; padding: 0 5px">
                        <div :id="idName" :style="containsSty"></div>
                    </div>
                </div>`
});


//二级标题盒子plus
Vue.component('baseBoxPlus', {
    data() {
        return {}
    },
    props: {
        isShowTitle: {
            Boolean,
            default: true
        },
        isTitle: {
            Boolean,
            default: true
        },
        title: String,
        list: {
            Array,
            default: () => {
                return []
            }
        },
        titleSty: {
            Object,
            default: () => {
                return {}
            }
        },
        isAddSpot: {
            Boolean,
            default: false
        },
        itemNum: {
            Number,
            default: 0
        },
        nameSty: {
            Object,
            default: () => {
                return {}
            }
        }
    },
    filters: {
        addSpot(val) {
            if (!this.isAddSpot) return val;
            let source = val.toString();
            if (source.length < 4) return source;
            let arr = [...source];
            let len = arr.length / 3;
            let newArr = [];
            for (let i = 0; i < len; i++) {
                let start = arr.length - 3 * (i + 1);
                let b = []
                if (start < 0) b = arr.slice(0, arr.length % 3);
                else b = arr.slice(start, arr.length - 3 * i);
                newArr.push(b.join(''));
            }
            return newArr.reverse().join(',');
        }
    },
    methods: {
        drillDown(index, v) {
            if (v == 0) return
            this.$emit('drilldown', index)
        }
    },
    computed: {
        itemWidth() {
            const width = this.itemNum !== 0 ? 100 / this.itemNum + '%' : 100 / this.list.length + '%';
            return width;
        }
    },
    template: `<div>
                    <div 
                        :class="{'base-box-title': true,'base-box-istitle': isTitle}"
                        v-if="isShowTitle" 
                        :style="titleSty">
                        <slot name="icon"></slot>
                        {{title}}
                    </div>
                   
                    <div class="base-box-list">
                        <div 
                                v-for="(i,index) in list"
                                :style="{'width': itemWidth, boxSizing: 'border-box' }"
                                :class="{
                                    borderDashed: itemNum !== 0 ? (index+1)%itemNum !== 0 : (index+1)%list.length !== 0, 
                                    borderBottom: itemNum === 0 ? false : index + 1 <= list.length - itemNum
                                }"
                                @click="drillDown(index,i.value)" 
                        >
                            <div style="text-align: center; padding: 0 2px;">
                                <div style="display: flex; align-items: center; justify-content: center" :style="nameSty">
                                    <p v-if="i.isStrong !== true" style="font-size: 12px">{{i.name}}</p>
                                    <p v-else style="font-size: 14px; font-weight: bold; color:#0F9CDB;">{{i.name}}</p>
                                </div>
                                <p 
                                    :style="{
                                        'font-size': i.isBiggerNum === true ? '20px' : '14px',
                                        'color': i.color !== undefined ? i.color : '#0F9CDB',
                                        'font-weight': 'bold'
                                    }"
                                >
                                    <i v-if="i.isTop !== undefined" :class="{'el-icon-caret-top': i.isTop, 'el-icon-caret-bottom': !i.isTop}"></i>
                                    {{i.value | addSpot}}
                                </p>
                            </div>    
                        </div>    
                    </div>
                    <slot></slot>
                </div>`
});


//横向柱形图
Vue.component('transverseBarBox', {
    data() {
        return {
            containsHeight: '',
            isExtends: false
        }
    },
    props: {
        targeNum: Number,
        list: {
            Array,
            default: () => {
                return [
                    {
                        name: '福建',
                        value: 100
                    }
                ]
            }
        },
        title: {
            String,
            default: '指标名称'
        },
        xName: {
            String,
            default: '%'
        },
        xMax: {
            Number,
            default: null
        }
    },
    computed: {
        arrList() {
            const arr = JSON.parse(JSON.stringify(this.list));
            if (this.list.length < 6) return arr;
            else return arr.splice(0, 5)
        }
    },
    methods: {
        initLine(data = this.arrList) {
            const _this = this;
            this.containsHeight = data.length * 30 + 'px';
            const dataList = data.map(i => {
                return {
                    value: i.value,
                    itemStyle: {
                        color: this.targeNum === undefined ? '#FF7362' : i.value >= this.targeNum ? '#FF7362' : '#4CD997'
                    }
                }
            });
            const provRank = data.map(i => i.name);
            const markLine = this.targeNum === undefined ? null : {
                symbol: "none",
                silent: true,
                lineStyle: {
                    normal: {
                        type: "solid"
                    }
                },
                label: {
                    position: "start"
                },
                data: [{
                    xAxis: this.targeNum,
                    lineStyle: {
                        width: 1.6560000000000001,
                        color: "red"
                    },
                    label: {
                        show: true,
                        position: '',
                    }
                }]
            };
            const mychart = echarts.init(this.$refs.chart2);
            mychart.resize({height: this.containsHeight});
            let option = {
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow'
                    },
                    formatter: (objs, index) => {
                        let obj = objs[0];
                        return `${obj.seriesName}<br/>${obj.marker}${obj.name} : ${obj.value} ${_this.xName}`;
                    },
                    position: (pos, params, dom, rect, size) => {
                        // 鼠标在左侧时 tooltip 显示到右侧，鼠标在右侧时 tooltip 显示到左侧。
                        let obj = {};
                        obj[['left', 'right'][+(pos[0] < size.viewSize[0] / 2)]] = 5;
                        obj.top = pos[1] - 20;
                        return obj;
                    }
                },
                grid: {
                    top: '10',
                    left: '6%',
                    right: this.xName.length * 2 + 10 + '%',
                    bottom: '10',
                    containLabel: true
                },
                xAxis: {
                    name: _this.xName,
                    max: _this.xMax,
                    type: 'value',
                    position: 'top',
                    axisTick: {
                        show: true
                    },
                    axisLine: {
                        show: true
                    },
                    axisLabel: {
                        show: true
                    },
                    splitLine: {
                        show: true
                    }
                },
                yAxis: {
                    type: 'category',
                    boundaryGap: true,
                    inverse: true, //反向
                    axisLine: {
                        show: true
                    },
                    axisTick: {
                        show: false
                    },
                    data: provRank
                },
                series: [{
                    name: _this.title,
                    barWidth: '18px',
                    itemStyle: {
                        normal: {
                            barBorderRadius: [0, 30, 30, 0]
                        },
                    },
                    type: 'bar',
                    label: {
                        normal: {
                            show: true,
                            formatter: '{c}',
                            textStyle: {
                                color: '#FFF'
                            }
                        }
                    },
                    markLine: markLine,
                    data: dataList
                }]
            };
            mychart.setOption(option, true);
            mychart.on('click', (param) => {
                _this.$emit('drilldown', param)
            });
        },
        extendsMore() {
            if (this.isExtends) this.initLine(this.arrList);
            else this.initLine(this.list)
            this.isExtends = !this.isExtends;
        }
    },
    mounted() {
        //this.initLine()
    },
    template: `<div style="height: 100%; background-color: white; width: 100%">
                    <div ref="chart2" style="background-color: #FFF; width: 100%" :style="{height: containsHeight}"></div>
                    <div @click="extendsMore"
                         style="display: flex; justify-content: center; font-size: 25px; line-height: 30px; font-weight: bold"><i
                            :class="[isExtends ? 'el-icon-arrow-up' : 'el-icon-arrow-down']"></i></div>
                </div>`
});

//仪表盘
Vue.component('gaugeBoard', {
    data() {
        return {}
    },
    props: {
        idName: String,
        list: {
            Object,
            default: () => {
                return {
                    title: '符合机构数',
                    thebestnum: '--',
                    thebest_city: '--',
                    theworstnum: '--',
                    theworst_city: '--',
                    aimnum: '85.00',
                    relaitynum: '--',
                    huanbi: '--',
                    issure: true,
                }
            }
        },

    },
    computed: {},
    methods: {
        selectColor(val) {
            if (val === '-') {
                return 'bluecolor'
            } else {
                const a = val.split('%')
                const value = parseFloat(a[0])
                if (value < 0) return 'redcolor';
                if (value === 0) return 'bluecolor'
                if (value > 0) return 'greencolor'
            }
        },
        drillDown(item) {
            //this.$emit('drilldown')
        },
        chartinit(data = {
            title: '符合机构数',
            thebestnum: '90.00%',
            thebest_city: '乌鲁木齐',
            theworstnum: '33.00%',
            theworst_city: '重庆',
            aimnum: '85.00%',
            relaitynum: '92.00%',
            huanbi: '0.90%',
            issure: true,
            jd: 0,
        }) {
            const _this = this;
            let mychart = echarts.init(document.getElementById(_this.idName));
            var option = {
                series: [
                    {
                        name: '业务指标',
                        type: 'gauge',
                        radius: '100%',
                        detail: {
                            show: false,
                            formatter: '{value}%',
                            textStyle: {fontSize: 12},
                            offsetCenter: [0, '60%']
                        },
                        data: [{value: data.relaitynum}],
                        min: 0,
                        max: 100,
                        splitNumber: 4,
                        axisLine: {            // 仪表盘轴线
                            lineStyle: {       // 属性lineStyle控制线条样式
                                width: 9,
                                color:
                                    [
                                        [data.jd2, '#FE6573'],
                                        [1, '#1AE642']

                                    ],
                            }
                        },
                        axisLabel: {            // 刻度小标记
                            distance: 2,
                            textStyle: {       // 属性lineStyle控制线条样式
                                // fontWeight: 'bolder',
                                color: '#000',
                                fontSize: 9,
                                // shadowColor: '#fff', //默认透明
                                // shadowBlur: 10
                            }
                        },
                        axisTick: {            // 刻度样式
                            length: 11,        // 属性length控制线长
                            lineStyle: {       // 属性lineStyle控制线条样式
                                color: 'auto',
                                shadowColor: '#fff', //默认透明
                                // shadowBlur: 10
                            }
                        },
                        splitLine: {           // 分隔线
                            length: 14,         // 属性length控制线长
                            lineStyle: {       // 属性lineStyle（详见lineStyle）控制线条样式
                                width: 2,
                                color: 'auto',
                                // shadowColor: '#fff', //默认透明
                                // shadowBlur: 10
                            }
                        },
                        pointer: {           // 指针
                            width: 3,
                            length: "75%",
                            // color:'#000',
                            shadowColor: '#fff', //默认透明
                            // shadowBlur: 5
                        },
                        title: {    //仪表盘标题
                            offsetCenter: [0, '88%'],
                            textStyle: {       // 其余属性默认使用全局文本样式，详见TEXTSTYLE
                                // fontWeight: 'bolder',
                                fontSize: 12,
                                color: '#000',
                                // shadowColor: '#fff', //默认透明
                                // shadowBlur: 10
                            }
                        },
                    }

                ]
            }
            option.series[0].data[0].value = data.relaitynum.replace('%', '');
            mychart.setOption(option)
        },
    },
    mounted() {

    },
    template: `<div class="box" 
    style="box-sizing: border-box;" >
    <div class="detailbody">
        <div class="notebox fl">
            <div class="notebody"  style="height: 105px; " @click="drillDown(list)">
                <div
                    style="width:max-content; display: flex; justify-content: space-between; align-items: center; ">
                    <div class="boxtitle">{{list.title}}
                    </div>
                </div>

                <div class="greencolor">全网最佳{{list.thebestnum}} ({{list.thebest_city}})</div>
                <div class="redcolor">全网最差{{list.theworstnum}} ({{list.theworst_city}})</div>
                <div class="databox" >
                    <div>
                        实际值 <span>{{list.relaitynum}}</span>
                    </div>
                    <div class>
                        目标值 <span>{{list.aimnum}}</span>
                    </div>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center;flex-direction: column;text-align: center">
            <div class="chartbox " :id="idName" style="top: 5px;width: 100%;height: 100%;"></div>
            <div class="labeltext">
                <span :class='[ selectColor(list.huanbi) ]' style="margin-right: 5px">环比</span>
                <div style=" display: flex; justify-content: space-around;align-items: center;">
                    <span :class='[ selectColor(list.huanbi) ]' style="margin-right: 5px">
                        {{list.huanbi}}</span>
                    <span v-if="list.huanbi !== '0.00' && list.huanbi !== '-'" :class='[list.issure ? "up" :"down" ,"arrow"]'></span><span v-else class="noShow arrow"></span></span>
                </div>
            </div>
        </div>


    </div>
</div>`
});





Vue.component('custom-table', {
    props: {
        orgXzqh: String,
        tableHeight: {
            String,
            default: () => {
                // 获取页面高度
                const h = document.documentElement.clientHeight || document.body.clientHeight
                // 减去上方区域
                return h-37;
            }
        },
        tableColumn: {
            Array,
            default: () => {
                return []
            }
        },
        moduleList: {
            Array,
            default: () => {
                return []
            }
        },
        showTotal: {
            Boolean,
            default: true
        },
        drillDownKeys: {
            Array,
            default: () => {
                return ['name']
            }
        },
        filterName: {
            Array,
            default: () => {
                return []
            }
        },
        defaultSort: Object,
        onlyDrillName: {
            Array,
            default: () => {
                return []
            }
        },
        rowStyle: {
            Object,
            default: () => {
                return {'font-size': '16px', 'line-height': '40px'}
            }
        }
    },
    data(){
        return {
            dataList: [],
            sortList: [],
            fixedLeft: false
        }
    },
    computed: {
        totalValue(){
            return this.moduleList.find(i => i.nameCode==='total');
        }
    },
    watch: {
        moduleList: {
            handler(newValue, oldValue) {
                //排序图标置空
                this.sortList.forEach(item => {
                    const refs = this.$refs[item.key];
                    refs.forEach(i => {
                        i.style.color = '#666666'
                    })
                });

                if(newValue.length == 0) {
                    this.dataList = [];
                    return
                }
                const sort = this.defaultSort;
                const total = newValue.find(i => i.nameCode === 'total');
                let data = newValue.filter(i => i.nameCode !== 'total');
                if (sort){
                    console.log('111');
                    let newdata = sort.sort === 'up' ? data.sort((a,b) => a[sort.key] - b[sort.key]) : data.sort((a,b) => b[sort.key] - a[sort.key])
                    if (total) newdata.unshift(total);
                    this.dataList = newdata;
                }else{
                    if (total) data.unshift(total);
                    this.dataList = data
                };
                this.$refs.dialogTable.bodyWrapper.scrollTop = 0;
                this.$refs.dialogTable.bodyWrapper.scrollLeft = 0;
            },
            immediate: true
        },
        tableColumn: {
            handler(newValue, oldValue) {
                this.sortList = newValue.filter(item => item.sort).map(item => {
                    return {
                        key: item.key,
                        sort: 0
                    }
                });
                this.fixedLeft = newValue.some(item => item.fixed === 'left')
            },
            immediate: true
        }
    },
    methods: {
        getNo(no){
            if (no == 0) return '';
            else return  no
        },
        handleSort(row) {
            if (!row.sort) return;
            //点击列的key
            const key = row.key;
            //0默认排序  1升序 2降序
            this.sortList.forEach(item => {
                const refs = this.$refs[item.key];
                refs.forEach(i => {
                    i.style.color = '#666666';
                });
                if (item.key === key) {
                    const curkey = key === 'name' ? 'nameCode' : key;
                    item.sort++;
                    if (item.sort > 2) item.sort = 0;
                    if (item.sort === 0) {
                        this.sortFun(JSON.parse(JSON.stringify(this.moduleList)))
                    }
                    if (item.sort === 1) {
                        this.sortFun(JSON.parse(JSON.stringify(this.dataList)), {
                            key: curkey,
                            sort: 'up'
                        });
                        if (this.fixedLeft){
                            if (row.fixed == 'left'){
                                this.$refs[item.key][0].style.color = '#FFF';
                                this.$refs[item.key][1].style.color = '#666666'
                            }else{
                                console.log('222');
                                this.$refs[item.key][2].style.color = '#FFF';
                                this.$refs[item.key][3].style.color = '#666666'
                            }
                        }else{
                            this.$refs[item.key][0].style.color = '#FFF';
                            this.$refs[item.key][1].style.color = '#666666'
                        }
                    }
                    if (item.sort === 2) {
                        this.sortFun(JSON.parse(JSON.stringify(this.dataList)), {
                            key: curkey,
                            sort: 'down'
                        });
                        if (this.fixedLeft){
                            if (row.fixed === 'left'){
                                this.$refs[item.key][0].style.color = '#666666';
                                this.$refs[item.key][1].style.color = '#FFF'
                            }else{
                                this.$refs[item.key][2].style.color = '#666666';
                                this.$refs[item.key][3].style.color = '#FFF'
                            }
                        }else{
                            this.$refs[item.key][0].style.color = '#666666';
                            this.$refs[item.key][1].style.color = '#FFF'
                        }
                    }
                    if (this.showTotal) this.dataList.unshift(this.totalValue)
                }
            });
        },
        handleClick(i, row) {
            if (this.drillDownKeys.indexOf(i.key) < 0 || this.filterName.some(i => i === row.name) || row.nameCode === 'total' || (this.onlyDrillName.length != 0 && !this.onlyDrillName.some(i => i === row.nameCode))) return;
            console.log('下钻了',row);
            if(i.key == 'name'){
                if(this.orgXzqh && this.orgXzqh!='000000' && this.orgXzqh !='999999' ){
                    if(row.nameCode !=this.orgXzqh) return;
                }
            }
            // if(this.orgXzqh=='000000' || this.orgXzqh =='999999') return;
            this.$emit('drilldown', {
                key: i.key,
                row: row
            })
        },
        getColor(i, row) {
            if(this.orgXzqh){

                if(this.orgXzqh!='000000' && this.orgXzqh!='999999'){
                    if(i.key == 'name'){
                        if(row.nameCode !== this.orgXzqh) return ''
                    }
                }
            }
            if (row.nameCode === 'total' || this.filterName.some(i => i === row.name) || (this.onlyDrillName.length != 0 && !this.onlyDrillName.some(i => i === row.nameCode))) return '';
            const rateColor = i.fontColor ? i.fontColor(row) : '';
            return this.drillDownKeys.indexOf(i.key) < 0 ? rateColor : 'blue'
        },
        translateTextAlign(val) {
            const obj = {
                left: 'flex-begin',
                center: 'center',
                right: 'flex-end;'
            };
            return val ? obj[val] : 'flex-end';
        },
        sortFun(newValue, sort = this.defaultSort){
            const total = newValue.find(i => i.nameCode === 'total');
            let data = newValue.filter(i => i.nameCode !== 'total');
            if (sort){
                let newdata = sort.sort === 'up' ? data.sort((a,b) => a[sort.key] - b[sort.key]) : data.sort((a,b) => b[sort.key] - a[sort.key])
                //newdata.unshift(total[0]);
                Vue.set(this.dataList,newdata);
                this.dataList = newdata;
            }else{
                Vue.set(this.dataList,data);
                this.dataList = data
            }
        }
    },
    template: `<div style="padding:0 5px;">
                    <el-table
                    ref="dialogTable"
                :data="dataList"
                stripe
                :header-cell-style="{background:'#0199FF',color:'#FFF', height: '30px', 'text-align': 'center'}"
                :row-style="{height:'30px'}"
                :height="tableHeight"
                style="width: 100%; font-size: 16px;"
        >
            <el-table-column
                    v-for="item in tableColumn"
                    :prop="item.key"
                    :align="item.align ? item.align : 'right'"
                    :width="item.width"
                    :fixed="item.fixed"
            >
                <template slot="header" slot-scope="scope">
                    <div class="table-sort" :style="{'justify-content': translateTextAlign(item.align)}"  @click="handleSort(item)" style="width: 100%">
                        <span v-html="item.name" :style="{display: 'block', 'margin-right':  '1px'}"></span>
                        <div v-if="item.sort" class="table-sort-icon">
                            <i class="el-icon-caret-top"  style="position: absolute; top: 3px;" :ref="item.key"></i>
                            <i class="el-icon-caret-bottom"  style="position: absolute; bottom: 3px" :ref="item.key"></i>
                        </div>
                    </div>
                </template>
                <template slot-scope="scope">
                    <div :style="rowStyle" @click="handleClick(item, scope.row)">
                        <span v-if="item.key === 'no'">{{getNo(scope.$index)}}</span>
                        <span v-else style="display: block;" :style="{color: getColor(item, scope.row), 'margin-right': item.sort ? '10px' : '0'}">
                            {{item.filter ? item.filter(scope.row[item.key]) : scope.row[item.key]}}
                        </span>
                    </div>
                </template>
            </el-table-column>
        </el-table>
               </div>`
});


Vue.component('select-list', {
    model: {
        prop: 'msg',
        event: 'change'
    },
    props: {
        msg: String,
        dropdownlist: {
            Array,
            default: () => {
                return []
            }
        }
    },
    computed: {
        title(){
            console.log(this.dropdownlist)
            console.log(this.msg)
            return this.dropdownlist.find(i => i.val === this.msg).name
        }
    },
    methods: {
        handleCommand(command){
            this.$emit('change', command)
        }
    },
    template: `<div>
                    <el-dropdown trigger="click"  @command="handleCommand">
                        <span class="el-dropdown-link">
                            {{title}}<i class="el-icon-arrow-down el-icon--right"></i>
                        </span>
                        <el-dropdown-menu slot="dropdown">
                            <el-dropdown-item v-for="item in dropdownlist" :command="item.val">{{item.name}}</el-dropdown-item>
                        </el-dropdown-menu>
                    </el-dropdown>
                </div>`
});

