/**
 * 多层表头列表设置组件
 * @author baixueru
 * @desc 非本人不允许修改及复制
 * @time  2020-12-30
 */

// 全局注册组件
Vue.component('draggableBox', {
    data() {
        return {
            drag: true,
            disabled: false,
        }
    },
    props: ['list', "rawList", "level"],
    template: `
    <draggable 
        v-model="list"
        :options="{handle: '.isMover', forceFallback: true}"
        animation="300"
        ghostClass="ghostClass"
        dragClass="dragClass"
        :move="onMove"
        @start="onStart" 
        @end="onEnd"
    >
        <template>
            <div v-for="item in list" :key="item.id" :class="level > 1 ? 'dragItemChild' : 'dragItems'">
                <div class="dragItem" @click=showChild(item.id)>
                    <span>{{item.label.replace("|", "")}}</span>
                    <el-switch 
                        width="52"
                        active-color="#4BD662"
                        inactive-color="#E3E3E3"
                        v-model="item.chose"
                        @change="changeSwitch($event, item)"
                    >
                    </el-switch>
                    <img class="isMover" src="../image/drageIcon.png" alt="拖拽" />
                </div>
                <!-- 子级 -->
                <draggable-box 
                    v-if="item.children"
                    :ref="'dragItemChild' + item.id"
                    :list="item.children" 
                    :raw-list="rawList" 
                    :level="level + 1"
                >
                </draggable-box>
                
            </div>
        </template>
    </draggable>
    `,
    mounted() {
    },
    methods: {
        // 折叠子集
        showChild(id) {
            if(this.$refs['dragItemChild' + id]) {
                let domDisplay =  this.$refs['dragItemChild' + id][0].$el.style.display;
                if (domDisplay == 'none') {
                    this.$refs['dragItemChild' + id][0].$el.style.display = 'block';
                } else {
                    this.$refs['dragItemChild' + id][0].$el.style.display = 'none';
                }
            }
        },
        // 更改显隐
        changeSwitch(event, item) {
            // 父级变化时，子级随动
            if (item.children) {
                item.children.forEach(children => {
                    children.chose = event;
                });
                this.rawList.forEach(list => {
                    if (list.id == item.id) {
                        list = item;
                    }
                })
                changeNewList(this.rawList);
                return;
            }
            // 子集全部为false时，父级才显示为false
            let parentId = item.parentId;
            if (parentId) {
                this.rawList.forEach(list => {
                    if (list.id == parentId) {
                        let arr = list.children.filter(child => {
                            return child.chose
                        })
                        list.chose = arr.length > 0 ? true : false;
                    }
                })
            }
            changeNewList(this.rawList);
        },
        onMove({ relatedContext, draggedContext }) {
            const relatedElement = relatedContext.element;
            const draggedElement = draggedContext.element;
            return (
                (!relatedElement || !relatedElement.fixed) && !draggedElement.fixed
            );
        },
        //开始拖拽事件
        onStart() {
            this.drag = true;
        },
        //拖拽结束事件
        onEnd() {
            this.drag = false;
            // 如果有父级id 需将原数组中的子级替换
            if (this.list[0].parentId) {
                this.rawList.forEach(list => {
                    if (list.id == this.list[0].parentId) {
                        list.children = this.list;
                    }
                })
                changeNewList(this.rawList);
            } else {
                changeNewList(this.list);
            }
        }
    },
});