Vue.component('drillDownBox', {
    data() {
        return {
            style1: {
                color: '#0199FF'
            },
            style2: {
                color: '#000000'
            },
            upColor: 'red', // 上升颜色
            downColor: 'green' // 下降颜色
        }
    },
    props: {
        tablecolumn: {
            Array,
            default: () => {
                return []
            }
        },
        title: {
            String,
            default: '省份'
        },
        list: {
            Array,
            default: () => {
                return []
            }
        },
        isDrillDown: {
            Boolean,
            default: false
        },
        isNo: {
            Boolean,
            default: true
        },
        notReverse: {
            Boolean,
            default: true
        },
        defaultSort: {
            Object,
            default: () => {
                return {
                    prop: 'locCode',
                    order: 'ascending'
                }
            }
        },
        echartName: {
            String,
            default: ''
        },
        valueName: {
        	String,
        	default: ''
        },
        isShowLine: {
            Boolean,
            default: false
        },
        valueMax: {
            String,
            default: null
        },
        specialName: {
            Array,
            default: () => {
                return ['总计','其他']
            }
        }
    },
    computed: {
        x_data() {
            const newList = this.list.sort((i, n) => {
                return Number(i.nameCode) - Number(n.nameCode)
            });
            const arr = this.list.filter(e => e.name !== '总计')
            return arr.map(i => i.name);
        },
        value_data() {
            const newList = this.list.sort((i, n) => {
                return Number(i.nameCode) - Number(n.nameCode)
            });
            const arr = this.list.filter(e => e.name !== '总计')
            return arr.map(i => i.value);
        }
    },
    methods: {
        getColor(val) {
            if (val === '-' || parseFloat(val) == 0) return '';
            if (this.notReverse) {
                if (parseFloat(val) < 0) return this.downColor;
                if (parseFloat(val) > 0) return this.upColor;
            } else {
                if (parseFloat(val) < 0) return this.upColor;
                if (parseFloat(val) > 0) return this.downColor;
            }
        },
        getValue(val,compareKey) {
            if (val === undefined || val == '' || val == null) {
            	return '-'
            }else{
            	if(compareKey && compareKey < 0){
            		return "-" + val;
            	}
            	return val
            }
        },
        xiazuan(item, key, index) {
            if (key === 'areaName') {
                if (!this.isDrillDown || !this.filterDrillDown(item.areaName, index)) return;
                this.$emit('drilldown', {
                    item: item,
                    key: key
                })
            } else {
                if (key.isDrillDown && item[key.key] != 0) {
                    this.$emit('drilldown', {
                        item: item,
                        key: key.key
                    })
                }
            }
        },
        sortMethod(a,b,key,compareKey){
        	let l = a[key];
        	let r = b[key];
        	if(l == undefined || l == null || l == ''){
        		l = -100000000;
        	}else{
            	if(a[compareKey] < 0){
            		l *= -1;
            	}
        	}
        	if(r == undefined || r == null || r == ''){
        		r = -100000000;
        	}else{
            	if(b[compareKey] < 0){
            		r *= -1;
            	}
        	}
        	return r - l;
        },
        setWidth() {
            const width = this.title.length > 2 ? 120 : 80;
            if (this.tablecolumn.length === 1) return null;
            else return width
        },
        setColumnWidth(text){
    		if(!text){
    			return 80;
    		}
    		const len = text.length;
    		if(len <= 2){
    			return 80;
    		}else{
    			return 80 + 10 * (len - 2);
    		}
        },
        // 对比昨天，获取颜色
        getColorByCompareYest(row, item) {
            // 检验昨日值字段
            if (!item.compareYestKey) {
            	return ''
            }
            if(row[item.compareYestKey] == 0){
            	return ''
            }
            if(this.notReverse){
            	return row[item.compareYestKey] > 0 ? this.upColor : this.downColor
            }else{
            	return row[item.compareYestKey] < 0 ? this.upColor : this.downColor
            }
            
        },
        // 将值分段，赋给不同颜色
        getColorBySub(row, item) {
            // 检验昨日值字段
            if (!item.subKey) {
            	return ''
            }
            if(row[item.key] <= 0){
            	return '#FA2525'
            }else if(row[item.key] <= row[item.subKey]){
            	return '#333333'
            }else{
            	return '#009900'
            }
        },
        // 表头换行
        renderHeader(h, { column, $index }) {
        	var lab = column.label;
        	if(lab.indexOf("|") < 0){
        		return h('span',{},lab)
        	}else{
        		var arr = lab.split('|')
        		const list = [];
        		arr.forEach(item => {
        			list.push(h('span', {}, item));
                    list.push(h('br'));
        		})
        		list.pop()
        		return h('span', {}, list)
        	}
        },
        //特殊名字过滤
        filterDrillDown(name, index){
            if (this.specialName.indexOf(name) < 0 && index) return true;
            else return false
        },
        headerSet(){
        	alert("sett")
        },
    },
    mounted() {
    },
    template: `<div>
                <div style="box-sizing: border-box">
                    <div style="padding: 0 2px">
                        <el-table
                                :data="list"
                                stripe
                                :header-cell-style="{background:'#0199FF',color:'#FFF', height: '30px', 'text-align': 'center', fontSize: '12px'}"
                                :row-style="{height:'30px'}"
                                :default-sort="defaultSort"
                                style="width: 100%"
                        >
                            <el-table-column
                                    v-if="isNo"
                                    type="index"
                                    label="序号"
                                    align="center"
                                    fixed
                                    width="50"
                            >
                            </el-table-column>
                            <el-table-column
                                    prop="areaName"
                                    :label="title"
                                    fixed
                                    :width="setWidth()"
                                    align="left">
                                <template slot-scope="scope">
                                    <span :style="[isDrillDown && filterDrillDown(scope.row.areaName, scope.$index) ? style1 : style2 ]"
                                          @click="xiazuan(scope.row, 'areaName', scope.$index)">{{scope.row.areaName}}</span>
                                </template>
                            </el-table-column>
                            <el-table-column
                                    v-for="item in tablecolumn"
                                    :key="item.key"
                                    :prop="item.key"
                                    :label="item.label"
                                    label-class-name="headerClass"
                                    :render-header="renderHeader"
                                    :sortable="item.sortable"
                                    :sort-method="(a,b) => sortMethod(a,b,item.key,item.compareYestKey)"	
                                    :width="item.width ? item.width : setColumnWidth(item.label)"
                                    :align="!item.align ? 'center' : item.align">
                                <template slot-scope="scope">
	                                	<!--如果是率-->
	                                    <span v-if="item.isRate || item.isCompareYest" :class="item.sortable ? 'paddingR24' : ''" :style="{color: getColorByCompareYest(scope.row,item)}">
	                                        {{getValue(scope.row[item.key],scope.row[item.compareYestKey]) == '-' ? '-' : getValue(scope.row[item.key],scope.row[item.compareYestKey]) + (item.isRate ? "%" : '')}}
	                                    </span>
	                                    <!--如果需要对比昨日值，显示不同颜色--> 
                                        <span v-else-if="item.isCompareYest" :style="{color: getColorByCompareYest(scope.row,item)}">
                                            {{ getValue(scope.row[item.key]) }}
                                        </span>
                                        <!--如果需要按值分段，显示不同颜色--> 
                                        <span v-else-if="item.isSub" :style="{color: getColorBySub(scope.row,item)}">
                                            {{ getValue(scope.row[item.key]) }}
                                        </span>
	                                    <!--其他--> 
	                                    <span v-else @click="xiazuan(scope.row, item)"  :class="item.sortable ? 'paddingR24' : ''" :style="[item.isDrillDown && scope.row[item.key] != 0 ? style1 : style2 ]">
	                                        {{getValue(scope.row[item.key],scope.row[item.compareYestKey])}}
	                                    </span>
                                </template>
                            </el-table-column>
                            // <el-table-column
	                        //     align="center"
	                        //     width="100">
	                        //     <template slot="header" slot-scope="scope">
		                    //         <el-button
		                    //         size="mini"
		                    //         @click="headerSet(scope.$index, scope.row)">表头设置</el-button>
	                        //     </template>
		                    
		                    // </el-table-column>
                        </el-table>
                    </div>
                </div>
</div>`
});