// 预警客户tab页
var warningTab = {
	props: ['name', 'date', 'tableColumnList'],
    data() {
		return {
			tipShow: false,
			msg: '当前日期的数据暂未更新呢！',
			level: 1,
			maxLevel: 2,
			isMaxLevel: false,
			noData: false,
			tableHeight: null,
			tableData: [],
			// 缓存数据
            cacheData: {},
			// 当前页面地区
            areaCode: '',
            // 上一级页面地区
			beforeAreaCode: '',
		}
	},
	template: `
		<div>
			<table-box
				v-if="!noData"
				ref="tableBox"
				:table-column-list = "tableColumnList"
				:table-data = "tableData"
				:is-setting = false
				:table-height="tableHeight"
				:divide-code = "areaCode"
				:is-max-level="isMaxLevel"
				:provided-drill-down="providedDrillDown"
			>
			</table-box>

			<div v-if="noData">
				<run-text img-url="../../" :msg="msg" :is-show="tipShow" @close="close"></run-text>
				<div class="noData">
					<img src="../../image/nodata.png" alt="暂无数据" />
					<h3>暂无数据</h3>
				</div>
			</div>
		</div>
	`,
	watch: {
		// 监控当时间变化时, 重新请求
		date: function(val) {
        	if (val) {
				if(this.level == 1) {
					let userLevel = getAccountLevel();
					this.maxLevel = userLevel < 3 ? 2 : 1;
					this.isMaxLevel = userLevel < 3 ? false : true;
					this.tableColumnList[0].label = getNameFromPermission(this.level);
				}
                this.getData();
            }
		},
		level: function(val) {
			if(this.tableColumnList && this.tableColumnList.length > 0){
				this.tableColumnList[0].label = getNameFromPermission(val);
			}
		}
	},
	mounted() {
		// 第一次显示的时候
		if (this.date) {
			let userLevel = getAccountLevel();
			this.maxLevel = userLevel < 3 ? 2 : 1;
			this.isMaxLevel = userLevel < 3 ? false : true;
			this.tableColumnList[0].label = getNameFromPermission(this.level);
			this.getData();
		}
		// 计算表格高度
		setTimeout(()=>{
			// 距离body的高度
			let offsetTop = document.getElementsByClassName('van-tabs__content')[0].offsetTop;
			// body的高度
			let windowHeight = document.documentElement.clientHeight || document.body.clientHeight;
			this.tableHeight = windowHeight - offsetTop;
		}, 0)
	},
	methods: {
		// 获取数据
		getData() {
			let params = {
				statDate: this.date,
				areaCode: this.areaCode,
				areaLevel: String(this.level)
			};
			if (this.name == "whole") {
				// 整体预警
				queryWholeWarn(params).then(({data}) => {
					this.setData(data);
				}).catch(err => {
					this.noData = true;
					this.tipShow = true;
				})
			} else if (this.name == "suspected") {
				// 疑似流失
				queryLossCustomer(params).then(({data}) => {
					this.setData(data);
				}).catch(err => {
					this.noData = true;
					this.tipShow = true;
				})
			} else if (this.name == "grade") {
				// 等级预警
				queryLevelWarn(params).then(({data}) => {
					this.setData(data);
				}).catch(err => {
					this.noData = true;
					this.tipShow = true;
				})
			}
		},
		// 整理数据
		setData(data) {
			if(!data || data == '[]' ) {
				this.noData = true;
				this.tipShow = true;
				return;
			}
			this.noData = false;
			this.tipShow = false;
			data = JSON.parse(data);
			// 数据判空
			data.forEach((item, index) => {
				if(index == 0) {
					this.areaCode = this.areaCode ? this.areaCode : item.areaCode;
					this.beforeAreaCode = item.pAreaCode ? item.pAreaCode : '100000';
				}
				this.tableColumnList.forEach(columnItem => {
					let prop = columnItem.prop;
					switch (prop) {
						case 'areaSname':
							item.areaSname = item.areaSname ? (item.areaSname == '其它' ? (item.areaName ? item.areaName : '其它') : item.areaSname) : (item.areaName ? item.areaName : '其它');
							break;
						// 个数
						case 'warnCustomerAmount':
						case 'totalAmount':
						case 'superAmount':
						case 'firstAmount':
						case 'secondAmount':
						case 'thirdAmount':
						case 'microAmount':
							item[prop] = item[prop] === null ? '' : item[prop];
							break;
						// 率
						case 'activeCustomProportion':
						case 'businessAmountRate':
						case 'businessIncomeRate':
							item[prop] = item[prop] === null ? '' : ((item[prop] ? item[prop] : 0) * 100).toFixed(2);
							break;
						default:
							break;
					}
				})
			})
			this.tableData = data;
			// 缓存数据
			this.cacheData[this.areaCode + this.date] = {
				"beforeAreaCode": this.beforeAreaCode,
				"tableData": data
			}
		},
		// 表格下钻
        providedDrillDown(row, prop) {
			if(prop == 'areaSname') {
				this.level = this.level + 1;
				this.areaCode = row.areaCode;
				this.isMaxLevel = this.level == this.maxLevel ? true : false;
				const cacheData = this.cacheData[this.areaCode + this.date];
                // 获取数据，重新渲染页面
                if(cacheData) {
                    this.beforeAreaCode = cacheData.beforeAreaCode;
                    this.tableData = cacheData.tableData;
                } else {
                    this.getData();
				}
				this.$refs.tableBox.$refs.table.clearSort();
			} else {
				let params = {
					date: this.date,
					name: this.name,
					customGrade: 0,
					areaLevel: (this.areaCode == row.areaCode) ? this.level : (this.level + 1),
					areaName: row.areaSname,
					areaCode: row.areaCode
				};
				params = JSON.stringify(params);
				Emp.execute("goToAmount('" + params + "')");
			}
		},
		// 返回上一级
        upLevel() {
            if (this.level == 1) {
                Emp.execute("goBack()");
            } else {
                this.level = this.level - 1;
				this.areaCode = this.beforeAreaCode;
				this.isMaxLevel = this.level == this.maxLevel ? true : false;
				//alert('1000000' + this.date);
                const cacheData = this.cacheData[this.areaCode + this.date];
                // 获取数据，重新渲染页面
                if(cacheData) {
                    this.beforeAreaCode = cacheData.beforeAreaCode;
                    this.tableData = cacheData.tableData;
                } else {
                    this.getData();
				}
				this.$refs.tableBox.$refs.table.clearSort();
            }
		},
		close() {
			this.tipShow = false;
		}
	}
}