/**
 * 表
 * isNo: 是否显示序号列
 * redBy: 是否红图模式[min,max]
 * notReverse: 红绿色显示逻辑是否反转
 * specialName: 不参与排序的特殊行
 * 列
 * subByZero: true数字显示红绿色根据0分割为2段 绿-红
 * subByTarget: key数字显示红绿色根据字段分割为2段 绿-红
 * subByKey: 数字显示红绿色根据0和字段分割为3段 绿-黑-红
 * subDown: 比给定值小的显示红色
 * subUp: 比给定值大的显示绿色
 * isRate: 一般在表头显示%，isRate时单元格显示%
 * isNumber: 表示这一列是数字，需要粗体显示
 * align: 值靠左靠右
 * paddingRight: 值右边距，和align=right组合使用
 */

Vue.component('drillDownBox', {
    data() {
        return {
        	normalColor: '#333333',
            drillColor: '#3377FF',
            upColor: '#009900',
            downColor: '#FA2525',
            toastId: null,
        }
    },
    props: {
        tablecolumn: {
            Array,
            default: () => {
                return [{
                    label: '封发量',
                    key: 'value',
                }]
            }
        },
        tableHeight: {
        	Number,
        	default: null
        },
        list: {
            Array,
            default: () => {
                return [{
                    name: '北京市',
                    value: '36',
                    zrtb: 0
                }]
            }
        },
        isNo: {
            Boolean,
            default: false
        },
        isBorder: {
        	Boolean,
        	default: false
        },
        notReverse: {
            Boolean,
            default: true
        },
        subByZero: {
            Boolean,
        	default: false
        },
        specialName: {
            Array,
            default: () => {
                return []
            }
        },
        redBy: {
            Object,
        	default: null
        },
    },
    computed: {
    },
    methods: {
        getColor(row, item) {
        	if(this.redBy){
        		//红图模式，样式自定
        		return;
        	}
        	
        	if(item.isDrillDown && this.filterDrillDown(row, item)){
        		if(!row.notDrill && row[item.key] != 0){
        			return this.drillColor;
        		}
        	}
        	
        	if(item.compareKey){
                if(row[item.compareKey] != 0){
                	if(this.notReverse){
                		if (row[item.compareKey] > 0) return this.upColor;
                		if (row[item.compareKey] < 0) return this.downColor;
                    }else{
                		if (row[item.compareKey] < 0) return this.upColor;
                		if (row[item.compareKey] > 0) return this.downColor;
                    }
                }
        	}
        	
        	if(item.subByZero){
        		//以0分为2段
        		let val = row[item.key];
                if (val != '-' && parseFloat(val) != 0) {
                    if (this.notReverse) {
                        if (parseFloat(val) < 0) return this.downColor;
                        if (parseFloat(val) > 0) return this.upColor;
                    } else {
                        if (parseFloat(val) < 0) return this.upColor;
                        if (parseFloat(val) > 0) return this.downColor;
                    }
                }
        	}
        	
        	if(item.subByTarget){
        		//以key分为2段
        		let val = row[item.key];
        		let sub = row[item.subByTarget];
                if (val != '-' && parseFloat(val) != 0) {
                    if (this.notReverse) {
                        if (parseFloat(val) < sub) return this.downColor;
                        if (parseFloat(val) > sub) return this.upColor;
                    } else {
                        if (parseFloat(val) < sub) return this.upColor;
                        if (parseFloat(val) > sub) return this.downColor;
                    }
                }
        	}
        	
        	if(item.subByKey){
        		//以0和key分为3段
        		let sub = row[item.subByKey];
        		let val = row[item.key];
        		if (val != '-' && parseFloat(val) != 0) {
                    if(val <= 0){
                    	return this.downColor;
                    }else if(val > sub){
                    	return this.upColor;
                    }else{
                    	return this.normalColor;
                    }
        		}
        	}
        	
        	if(item.subDown || parseFloat(item.subDown) === 0){
        		let val = row[item.key];
        		let sub = item.subDown;
                if (val != '-' && parseFloat(val) != 0) {
                    if (this.notReverse) {
                        if (parseFloat(val) < sub) return this.downColor;
                    } else {
                        if (parseFloat(val) < sub) return this.upColor;
                    }
                }
        	}
        	if(item.subUp || parseFloat(item.subUp) === 0){
        		let val = row[item.key];
        		let sub = item.subUp;
                if (val != '-' && parseFloat(val) != 0) {
                    if (this.notReverse) {
                        if (parseFloat(val) > sub) return this.upColor;
                    } else {
                        if (parseFloat(val) > sub) return this.downColor;
                    }
                }
        	}
        	return this.normalColor;
        },
        getValue(val,compareKey,isRate,is10Thousand) {
        	let res;
            if (val === undefined || val === '' || val == null) {
            	res = '-'
            }else if(compareKey && compareKey < 0){
            	res = "-" + val;
            }else{
            	res = val;
            }
            if(isRate && res != '-'){
            	res = res + "%";
            } else if (is10Thousand && res != '-') {
                res = (res / 10000).toFixed(2);
            }
            return res;
        },
        xiazuan(row, item) {
        	if (!item.isDrillDown || !this.filterDrillDown(row, item)) return;
        	if(row.notDrill) return;
            this.$emit('drilldown', {
                row: row,
                item: item
            });
        },
        sortMethod(a,b,key,compareKey){
        	let l = a[key];
        	let r = b[key];
        	if(l == undefined || l == null || l == ''){
        		l = -100000000;
        	}else{
            	if(a[compareKey] < 0){
            		l *= -1;
            	}
        	}
        	if(r == undefined || r == null || r == ''){
        		r = -100000000;
        	}else{
            	if(b[compareKey] < 0){
            		r *= -1;
            	}
        	}
        	return r - l;
        },
        changeTableSort({column, prop, order}) {
            if(column.sortable !== 'custom') {
                return;
            }
        	let fieldName = prop;
        	let sortingType = order;
        	let list = this.list;
        	let orderList = [];
        	let freeList = [];
        	list.map(it => this.specialName.indexOf(it.name) >= 0 ? freeList.push(it) : orderList.push(it));
        	if (sortingType == 'descending') {
        		list = orderList.sort((a, b) => a[fieldName] - b[fieldName]);
        		freeList.push.apply(freeList,orderList);
        		this.list = freeList;
        	} else if (sortingType == 'ascending') {
        		orderList = orderList.sort((a, b) => b[fieldName] - a[fieldName]);
        	    freeList.push.apply(freeList,orderList);
        	    this.list = freeList;
        	} else {
        		orderList = orderList.sort((a, b) => a.nameCode > b.nameCode ? 1 : -1);
        	    freeList.push.apply(freeList,orderList);
        	    this.list = freeList;
        	}
        	this.$emit('sortList', this.list);
        	this.$emit('sort-list', this.list);
        },
        setColumnWidth(text){
            if (this.tablecolumn.length <= 3) return null;
    		if(!text){
    			return 96;
    		}
    		return 96;
        },
        getPaddingRight(scope, item) {
        	if(item.paddingRight){
        		if(item.paddingRight > 0){
        			return item.paddingRight + 'px';
        		}
        	}
        	if(item.paddingRight < 0 || (!item.width && item.align == 'right')) {
        		let width = (scope.column.realWidth - scope.column.label.length * 12) / 2;
        		if(item.sortable){
        			width += 12;
        		}
        		if(width > 0){
        			return width + 'px';
        		}
        	}
        	if(item.sortable && item.align == 'right') {
        		return '24px';
        	}
        	return '0px';
        },
        // 表头换行
        renderHeader(h, { column, $index }) {
        	var lab = column.label;
        	if(lab.indexOf("|") < 0){
        		return h('span',{},lab)
        	}else{
        		var arr = lab.split('|')
        		const list = [];
        		arr.forEach(item => {
        			list.push(h('span', {}, item));
                    list.push(h('br'));
        		})
        		list.pop()
        		return h('span', {}, list)
        	}
        },
        //特殊名字过滤
        filterDrillDown(row, item){
        	if(this.specialName.indexOf(row.name) >= 0){
        		return false;
        	}
        	return true;
        },
        switchColumn(){
        	this.$emit('switchcolumn', {});
        },
        filterColumn(c){
        	return c.filter(function(item){
        		return item.chose == undefined || item.chose;
        	});
        },
        columnSetConfirm(){
        	Emp.execute("saveColumnSetKnow()");
        },
        getSortIcon(index){
        	if(index == 1){
        		return '../../image/icon_sort_1.png';
        	}else if(index == 2){
        		return '../../image/icon_sort_2.png';
        	}else{
        		return '../../image/icon_sort_3.png';
        	}
        },
        toggleToast(row,item){
        	let views = this.$refs.toast;
        	let pop;
        	if(views){
        		if(views.length > 1){
        			pop = views[1];
        		}else if(views.length > 0){
        			pop = views[0];
        		}
        	}
        	if(!pop) return;
        	console.log(pop);
        	//某个单元格需要点击吐丝提示增加的代码
    		if(this.toastId){
    			clearTimeout(this.toastId);
    		}
        	if(pop.value){
        		pop.value = false;
        	}else{
        		pop.value = true;
        		this.toastId = setTimeout(()=>{
        			pop.value = false;
        			this.toastId = null;
        		},3100);
        	}
        },
        changeCellStyle({row, column, rowIndex, columnIndex}){
        	if(this.redBy){
        		//红图模式
        		 if (columnIndex === 0) {
        			return 'background:#0197FF;color:#fff;text-align:center;';
        		} else {
        			return 'background:' + row.color[columnIndex-1] + ';'
        		}
        	}
        	return null;
        },
    },
    mounted() {

    },
    template: `<div>
                <div style="box-sizing: border-box">
                    <div style="padding: 0 2px">
                        <el-table
                                ref="tableActive"
                                :data="list"
                                stripe
                                :border="isBorder"
                                header-cell-class-name="blue-table-header"
                                row-class-name="blue-table-row"
                                :header-cell-style="{background:'#0199FF',color:'#FFF', height: '30px', 'text-align': 'center', fontSize: '12px', fontWeight: 'normal'}"
                                :row-style="{height:'30px',fontSize: '12px'}"
                                :cell-style="changeCellStyle"
                                style="width: 100%"
                                :height="tableHeight"
                                @sort-change="changeTableSort"
                                >
                            <el-table-column
                                    v-if="isNo"
                                    type="index"
                                    label="序号"
                                    align="center"
                                    fixed
                                    width="50"
                                    >
                            </el-table-column>
                            <el-table-column
                                    v-for="item in filterColumn(tablecolumn)"
                                    :key="item.key"
                                    :prop="item.key"
                                    :fixed="item.fixed ? true : false"
                                    :label="item.label"
                                    label-class-name="headerClass"
                                    :render-header="renderHeader"
                                    :sortable="item.sortable"
                                    :sort-method="(a,b) => sortMethod(a,b,item.key,item.compareYestKey)"	
                                    :width="item.width ? item.width : setColumnWidth(item.label)"
                                    :align="!item.align ? 'center' : item.align">
                                <template slot-scope="scope">
                                	<div v-if="scope.row.toast && item.toast" >
		                                <el-popover ref="toast" :content="scope.row.toast" placement="bottom-start" trigger="manual">
				                        	<span slot="reference" @click="toggleToast(scope.row,item)" :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
				                            	{{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand)}}
				                            </span>
			                            </el-popover>
                                	</div>
		                            <div v-else-if="item.isProgress" :class="scope.row[item.key] > 0 ? 'progressBox positive' : 'progressBox negative'">
			                            <el-progress
			                                :percentage="scope.row[item.key + 'Progress']"
			                                :color="scope.row[item.key] > 0 ? '#00C482' : '#F74627'"
			                                :stroke-width="21"
			                                :show-text="false"
			                            ></el-progress>
			                            <p :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
			                                {{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand)}}
			                            </p>
			                        </div>
                                	<div v-else>
	                        			<img v-if="item.rank && scope.row[item.key] <= 3" style="width:0.16rem; height:0.16rem;" :src="getSortIcon(scope.row[item.key])" >    
		                                <span v-else @click="xiazuan(scope.row, item)" :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
		                                    {{getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand)}}
		                                </span>
                                	</div>
                                </template>
                            </el-table-column>
                        </el-table>
                    </div>
                </div>
</div>`
});