/**
 * 可分页加载的数据列表
 * @author qs
 * @time 20200811
 * @desc
 */
Vue.component('pageLoadList', {
    data() {
        return {
			screenHeight: 500, // 当前屏幕高度
            style1: {
                color: '#0199FF',
            },
            style2: {
                color: '#000000'
            }
        }
    },
    props: {
        // 列表数据
        list: {
            Array,
            default: () => {
                return [
                    {name: '--', value: '--'}
                ]
            }
        },
        //
        title: {
            String,
            default: '标题'
        },
        // 表格内容
        tablecolumn: {
            Array,
            default: () => {
                return [
                    {label: '编号', key: 'id', sortable: true, isDrillDown: true, width: 90, show: true},
                    {label: '标题', key: 'title', sortable: true, isDrillDown: true, width: 90},
                    {label: '数值', key: 'value', sortable: true, isDrillDown: true, width: 90},
                ]
            }
        },
        // 是否显示序号
        isNo: {
            Boolean,
            default: false
        },
        // 当前页数
        pageNum: {
            Number,
            default: 1
        },
        // 每页显示数据（最小为25）
        pageSize: {
            Number,
            default: 25
        }
    },
    filters: {
        valueFilter(val) {
            if (!val) return '0'
            return val
        }

    },
    methods: {
        xiazuan(row, column) {
            if (column.isDrillDown) {
                this.$emit('drilldown', {
                    row,
                    column
                })
            }
        },
        // 换行时间
        dealTime(val) {
            if (!val) return '--'
            const arr = val.split(' ')
            return arr.join('<br>')
        },
        // 表头换行
        renderHeader(h, { column, $index }) {
        	var lab = column.label;
        	if(lab.indexOf("|") < 0){
        		return h('span',{},lab)
        	}else{
        		var arr = lab.split('|')
        		const list = [];
        		arr.forEach(item => {
        			list.push(h('span', {}, item));
                    list.push(h('br'));
        		})
        		list.pop()
        		return h('span', {}, list)
        	}
        },
		loadMore(){
		  // console.log('el-table 已经滚到底部')
		  this.$emit('more-data')
		
		}
    },
    mounted() {
		this.screenHeight = document.documentElement.clientHeight
    },
    template: `
    <div style="box-sizing: border-box;">
        <div style="padding: 0 2px;">
            <el-table
                    :data="list"
                    stripe
                    :header-cell-style="{background:'#0199FF',color:'#FFF', height: '50px'}"
                    :row-style="{height:'30px'}"
					row-key="id"
                    style="width: 100%;"
					:height="screenHeight"
					v-infinite-scroll="loadMore"
            >
                <el-table-column
                    v-if="isNo"
                    type="index"
                    label="序号"
                    align="center"
                    width="65"
                >
                </el-table-column>
                <el-table-column
                    align="center"
                    v-for="item in tablecolumn"
                    v-if="item.show != false"
                    :key="item.key"
                    :prop="item.key"
                    :label="item.label"
                    :render-header="renderHeader"
                    :sortable="item.sortable"
                    :width=" item.width ? item.width: '' "
                >
                    <template slot-scope="scope">
                        <span v-if="item.type != 'time'" @click="xiazuan(scope.row, item)" :style="[item.isDrillDown ? style1 : style2 ]">
                            {{ scope.row[item.key] | valueFilter() }}
                        </span>
                        <span v-else v-html="dealTime(scope.row[item.key])"></span>
                    </template>
                </el-table-column>
            </el-table>
        </div>
    </div>
    `
})

/**
 * 自定义表头的表格
 * @author lwj
 */
Vue.component('custom-table', {
    props: {
        refName: {
            String,
            default: 'dialogTable'
        },
        orgXzqh: String,
        tableHeight: {
            String,
            default: () => {
                // 获取页面高度
                const h = document.documentElement.clientHeight || document.body.clientHeight
                // 减去上方区域
                return h-37;
            }
        },
        tableColumn: {
            Array,
            default: () => {
                return []
            }
        },
        id:String,
        moduleList: {
            Array,
            default: () => {
                return []
            }
        },
        showTotal: {
            Boolean,
            default: true
        },
        drillDownKeys: {
            Array,
            default: () => {
                return ['name']
            }
        },
        filterName: {
            Array,
            default: () => {
                return []
            }
        },
        defaultSort: Object,
        onlyDrillName: {
            Array,
            default: () => {
                return []
            }
        },
        rowStyle: {
            type: Object || Function,
            default: () => {
                return {'font-size': '14px', 'line-height': '30px'}
            }
        },
        headStyle: {
            Object,
            default: () => {
                return {

                }
            }
        },
        activeFontColor: {
            String,
            default: 'blue'
        }
    },
    data(){
        return {
            dataList: [],
            sortList: [],
            fixedLeft: false
        }
    },
    computed: {
        totalValue(){
            return this.moduleList.find(i => i.nameCode==='total');
        }
    },
    watch: {
        moduleList: {
            handler(newValue, oldValue) {
                //排序图标置空
                this.sortList.forEach(item => {
                    const refs = this.$refs[item.key];
                    refs.forEach(i => {
                        i.style.color = '#666666'
                    })
                });
                if(newValue.length == 0) {
                    this.dataList = [];
                    return
                }
                const sort = this.defaultSort;
                const total = newValue.find(i => i.nameCode === 'total');
                let data = this.showTotal ? newValue.filter(i => i.nameCode !== 'total') : JSON.parse(JSON.stringify(newValue));
                if (sort){
                    console.log('111');
                    let newdata = sort.sort === 'up' ? data.sort((a,b) => a[sort.key] - b[sort.key]) : data.sort((a,b) => b[sort.key] - a[sort.key])
                    if (this.showTotal && total) newdata.unshift(total);
                    this.dataList = newdata;
                }else{
                    if (this.showTotal && total) data.unshift(total);
                    this.dataList = data
                };
                this.$refs[this.refName].bodyWrapper.scrollTop = 0;
                this.$refs[this.refName].bodyWrapper.scrollLeft = 0;
            },
            immediate: false
        },
        tableColumn: {
            handler(newValue, oldValue) {
                console.log('更新了');
                this.getSortList(newValue);
                this.fixedLeft = newValue.some(item => item.fixed === 'left')
            },
            immediate: true
        }
    },
    methods: {
        getSortList(newValue){
            this.sortList = newValue.filter(item => item.sort).map(item => {
                return {
                    key: item.key,
                    sort: 0
                }
            });
        },
        getNo(no){
            if (this.showTotal) return no == 0 ? '' : no;
            else return  no + 1
        },
        handleSort(row) {
            if (!row.sort) return;
            //点击列的key
            const key = row.key;
            //0默认排序  1升序 2降序
            this.sortList.forEach(item => {
                const refs = this.$refs[item.key];
                refs.forEach(i => {
                    i.style.color = '#666666';
                });
                if (item.key === key) {
                    const curkey = key === 'name' ? 'nameCode' : key;
                    item.sort++;
                    if (item.sort > 2) item.sort = 0;
                    if (item.sort === 0) {
                        this.sortFun(JSON.parse(JSON.stringify(this.moduleList)))
                    }
                    if (item.sort === 1) {
                        this.sortFun(JSON.parse(JSON.stringify(this.dataList)), {
                            key: curkey,
                            sort: 'up'
                        });
                        if (this.fixedLeft){
                            if (row.fixed == 'left'){
                                this.$refs[item.key][0].style.color = '#FFF';
                                this.$refs[item.key][1].style.color = '#666666'
                            }else{
                                console.log('222');
                                this.$refs[item.key][2].style.color = '#FFF';
                                this.$refs[item.key][3].style.color = '#666666'
                            }
                        }else{
                            this.$refs[item.key][0].style.color = '#FFF';
                            this.$refs[item.key][1].style.color = '#666666'
                        }
                    }
                    if (item.sort === 2) {
                        this.sortFun(JSON.parse(JSON.stringify(this.dataList)), {
                            key: curkey,
                            sort: 'down'
                        });
                        if (this.fixedLeft){
                            if (row.fixed === 'left'){
                                this.$refs[item.key][0].style.color = '#666666';
                                this.$refs[item.key][1].style.color = '#FFF'
                            }else{
                                this.$refs[item.key][2].style.color = '#666666';
                                this.$refs[item.key][3].style.color = '#FFF'
                            }
                        }else{
                            this.$refs[item.key][0].style.color = '#666666';
                            this.$refs[item.key][1].style.color = '#FFF'
                        }
                    }
                    if (this.showTotal) this.dataList.unshift(this.totalValue)
                }
            });
        },
        handleClick(i, row) {
            if (this.drillDownKeys.indexOf(i.key) < 0 || this.filterName.some(i => i === row.name) || row.nameCode === 'total' || (this.onlyDrillName.length != 0 && !this.onlyDrillName.some(i => i === row.nameCode))) return;
            console.log('下钻了',row);
            if(i.key == 'name'){
                if(this.orgXzqh && this.orgXzqh!='000000' && this.orgXzqh !='999999' ){
                    if(row.nameCode !=this.orgXzqh) return;
                }
            }
            // if(this.orgXzqh=='000000' || this.orgXzqh =='999999') return;
            this.$emit('drilldown', {
                key: i.key,
                row: row
            })
        },
        getColor(i, row) {
            if(this.orgXzqh){
                if(this.orgXzqh!='000000' && this.orgXzqh!='999999'){
                    if(i.key == 'name' || i.key == 'End10'){
                        if(row.nameCode !== this.orgXzqh) return ''
                    }
                }
            }
            if (i.key == 'name' || i.key == 'sendRate' || i.key == 'wholeRingRate' || i.key == 'rateEnd') {
                if (row.nameCode == 'total' || this.filterName.some(i => i === row.name) || (this.onlyDrillName.length != 0 && !this.onlyDrillName.some(i => i === row.nameCode))) return '';
            }
            if(i.key == 'name' && this.id != '4' && (row.nameCode == '110000' || row.nameCode == '120000' || row.nameCode == '310000' || row.nameCode == '500000')) return '';
            const rateColor = i.fontColor ? i.fontColor(row) : '';
            return this.drillDownKeys.indexOf(i.key) < 0 ? rateColor : this.activeFontColor
        },
        translateTextAlign(item) {
            const val = item.headAlign ? item.headAlign : item.align;
            const obj = {
                left: 'flex-begin',
                center: 'center',
                right: 'flex-end;'
            };
            return val ? obj[val] : 'flex-end';
        },
        sortFun(newValue, sort = this.defaultSort){
            let data = this.showTotal ? newValue.filter(i => i.nameCode !== 'total') : newValue;
            if (sort){
                let newdata = sort.sort === 'up' ? data.sort((a,b) => a[sort.key] - b[sort.key]) : data.sort((a,b) => b[sort.key] - a[sort.key])
                //newdata.unshift(total[0]);
                //Vue.set(this.dataList,newdata);
                this.dataList = newdata;
            }else{
                //Vue.set(this.dataList,data);
                this.dataList = data
            }
        },
        setRowStyle(align){
            if(Object.prototype.toString.call(this.rowStyle) === '[object Function]'){
                return this.rowStyle(align)
            }else return this.rowStyle
        }
    },
    template: `<div style="padding: 0 5px">
                    <el-table
                    :ref="refName"
                :data="dataList"
                stripe
                :header-cell-style="{background:'#0199FF',color:'#FFF', height: headStyle['line-height'] ? headStyle['line-height'] : '30px', 'text-align': 'center'}"
                :row-style="{height:'30px'}"
                :height="tableHeight"
                style="width: 100%"
        >
            <el-table-column
                    v-for="item in tableColumn"
                    :prop="item.key"
                    :align="item.align ? item.align : 'right'"
                    :min-width="item.width"
                    :fixed="item.fixed"
            >
                <template slot="header" slot-scope="scope">
                    <div class="table-sort" :style="{'justify-content': translateTextAlign(item), ...headStyle}"  @click="handleSort(item)" style="width: 100%">
                        <span v-html="item.name" style="font-size:12px;font-weight:normal;line-height:20px"  :style="item.colHeadStyle"></span>
                        <div v-if="item.sort" class="table-sort-icon">
                            <i class="el-icon-caret-top"  style="position: absolute; top: 3px;" :ref="item.key"></i>
                            <i class="el-icon-caret-bottom"  style="position: absolute; bottom: 3px" :ref="item.key"></i>
                        </div>
                    </div>
                </template>
                <template slot-scope="scope">
                    <div :style="setRowStyle(item.align)" @click="handleClick(item, scope.row)" v-if="item.key !== 'operate'">
                        <span v-if="item.key === 'no'">{{getNo(scope.$index)}}</span>
                        <span v-else style="display: block;" :style="{color: getColor(item, scope.row), 'margin-right': item.sort ? '10px' : '0'}">
                            {{item.filter ? item.filter(scope.row[item.key]) : scope.row[item.key]}}
                        </span>
                    </div>
                    <slot v-else :row="scope.row"></slot>
                </template>
            </el-table-column>
        </el-table>
               </div>`
});